
% a simple code to project the migration rate


clear

parameter

% estimation
options = optimset('Display','off');
x=fsolve('fun_estimation',1.3,options);
adj=x;

% two cases
phi=1; % phi=1 benchmark

%***********
% dynamics
%***********

% urban
pop_u_f_t(:,1)=pop2000(:,3)*adj; % female
pop_u_m_t(:,1)=pop2000(:,1)*adj-pop2000(:,3)*adj; % male
% rural
pop_r_f_t(:,1)=pop2000(:,4)*adj; % female
pop_r_m_t(:,1)=pop2000(:,2)*adj-pop2000(:,4)*adj; % male

% dynamics
for t=2:year_end-year_ini+1
    
    % urban
    % existing (using mortality rates)
    for i=2:age_max-age_min+1
        pop_u_f_t(i,t)=pop_u_f_t(i-1,t-1)*(1-mort2000(i-1,2)/1000); % female
        pop_u_m_t(i,t)=pop_u_m_t(i-1,t-1)*(1-mort2000(i-1,1)/1000); % male
    end
    % urban newly born
    nb_u_t(t)=sum(pop_u_f_t(fert_min:fert_max,t).*fert2000(:,1)/1000);
    % total population
    pop_u_f_t(1,t)=nb_u_t(t)*1/(sex_birth_u+1); % female
    pop_u_m_t(1,t)=nb_u_t(t)-pop_u_f_t(1,t); % male
    
    % rural
    % existing (using mortality rates)
    for i=2:age_max-age_min+1
        pop_r_f_t(i,t)=pop_r_f_t(i-1,t-1)*(1-mort2000(i-1,4)/1000); % female
        pop_r_m_t(i,t)=pop_r_m_t(i-1,t-1)*(1-mort2000(i-1,3)/1000); % male
    end
    % rural newly born
    nb_r_t(t)=sum(pop_r_f_t(fert_min:fert_max,t).*fert2000(:,2)/1000);
    % total population
    pop_r_f_t(1,t)=nb_r_t(t)*1/(sex_birth_r+1); % female
    pop_r_m_t(1,t)=nb_r_t(t)-pop_r_f_t(1,t); % male
    
end

% total population
pop_u_t=(pop_u_f_t+pop_u_m_t);
pop_r_t=(pop_r_f_t+pop_r_m_t);

% aggregation
pop_t=pop_u_t+pop_r_t;


% reporting over/under estimation
xxx(:,1)=[age_min:age_max]';
xxx(:,2)=(pop_t(:,year_end-year_ini+1)-pop2005(:,1)-pop2005(:,2))/1e+5;
% disp(xxx)
% the share of missing young labor force
sum(xxx(17:41,2))*1e+5/(sum(pop_t(17:41,year_end-year_ini+1)));



%************
% migration
%************

% survey error between 2000 and 2005
err=pop2005(:,1)+pop2005(:,2)-pop_t(:,year_end-year_ini+1);
err_f=pop2005(:,3)+pop2005(:,4)-pop_u_f_t(:,year_end-year_ini+1)-pop_r_f_t(:,year_end-year_ini+1);
err_m=err-err_f;
% plot([age_min:age_max],err,'-','color','r','linewidth',2)

% survey error
err_u_f=phi*err_f;
err_u_m=phi*err_m;
err_r_f=err_f-err_u_f;
err_r_m=err_m-err_u_m;

% sum
err_u=err_u_f+err_u_m;
err_r=err_r_f+err_r_m;

% implied migration
diff_u=pop2005(:,1)-pop_u_t(:,year_end-year_ini+1)-err_u;
diff_r=pop_r_t(:,year_end-year_ini+1)-pop2005(:,2)+err_r;

% implied migration by gender
diff_u_f=pop2005(:,3)-pop_u_f_t(:,year_end-year_ini+1)-err_u_f;
diff_u_m=diff_u-diff_u_f;
diff_r_f=pop_r_f_t(:,year_end-year_ini+1)-pop2005(:,4)+err_r_f;
diff_r_m=diff_r-diff_r_f;

% save migration distribution
mig_rate_sum=1-(1-sum(diff_u)/sum(pop_r_t(:,1)))^(1/5);
mig_rate_f_sum=1-(1-sum(diff_u_f)/sum(pop_r_f_t(:,1)))^(1/5);
mig_rate_m_sum=1-(1-sum(diff_u_m)/sum(pop_r_m_t(:,1)))^(1/5);
mig_distribution=diff_u/sum(diff_u);

%***************************
% compute migration rates
%***************************

% initial guess
mig_rate=1-(1-diff_u./pop_r_t(:,1)).^(1/5);
mig_rate_f_test=1-(1-diff_u_f./pop_r_f_t(:,1)).^(1/5);
mig_rate_m_test=1-(1-diff_u_m./pop_r_m_t(:,1)).^(1/5);

% age truncation
index=51;

%*********
% female
%*********
% migration rate equals zero for age > age_k
mr_f(index+1:age_max+1,1)=0;
% age of 100
mr_f(index,1)=diff_u_f(index+5,1)/pop_r_f_t(index,6);
% mr_f(96,1)=diff_u_f(101,1)/pop_r_f_t(96,6);
% age of 99
mr_f(index-1,1)=(diff_u_f(index+4,1)-mr_f(index,1)*pop_r_f_t(index-1,6))/((1-mr_f(index,1))*pop_r_f_t(index-1,6));
% mr_f(95,1)=(diff_u_f(100,1)-mr_f(96,1)*pop_r_f_t(95,6))/((1-mr_f(96,1))*pop_r_f_t(95,6));
% age of 98
mr_f(index-2,1)=(diff_u_f(index+3,1)-(mr_f(index-1,1)+mr_f(index,1)*(1-mr_f(index-1,1)))*pop_r_f_t(index-2,6))/((1-(mr_f(index-1,1)+mr_f(index,1)*(1-mr_f(index-1,1))))*pop_r_f_t(index-2,6));
% mr_f(94,1)=(diff_u_f(99,1)-(mr_f(95,1)+mr_f(96,1)*(1-mr_f(95,1)))*pop_r_f_t(94,6))/((1-(mr_f(95,1)+mr_f(96,1)*(1-mr_f(95,1))))*pop_r_f_t(94,6));
% age of 97
mr_f(index-3,1)=(diff_u_f(index+2,1)-(mr_f(index-2,1)+mr_f(index-1,1)*(1-mr_f(index-2,1))+mr_f(index,1)*(1-mr_f(index-1,1))*(1-mr_f(index-2,1)))*pop_r_f_t(index-3,6))/((1-(mr_f(index-2,1)+mr_f(index-1,1)*(1-mr_f(index-2,1))+mr_f(index,1)*(1-mr_f(index-1,1))*(1-mr_f(index-2,1))))*pop_r_f_t(index-3,6));
% mr_f(93,1)=(diff_u_f(98,1)-(mr_f(94,1)+mr_f(95,1)*(1-mr_f(94,1))+mr_f(96,1)*(1-mr_f(95,1))*(1-mr_f(94,1)))*pop_r_f_t(93,6))/((1-(mr_f(94,1)+mr_f(95,1)*(1-mr_f(94,1))+mr_f(96,1)*(1-mr_f(95,1))*(1-mr_f(94,1))))*pop_r_f_t(93,6));
% age of 96
mr_f(index-4,1)=(diff_u_f(index+1,1)-(mr_f(index-3,1)+mr_f(index-2,1)*(1-mr_f(index-3,1))+mr_f(index-1,1)*(1-mr_f(index-2,1))*(1-mr_f(index-3,1))+mr_f(index,1)*(1-mr_f(index-1,1))*(1-mr_f(index-2,1))*(1-mr_f(index-3,1)))*pop_r_f_t(index-4,6))/((1-(mr_f(index-3,1)+mr_f(index-2,1)*(1-mr_f(index-3,1))+mr_f(index-1,1)*(1-mr_f(index-2,1))*(1-mr_f(index-3,1))+mr_f(index,1)*(1-mr_f(index-1,1))*(1-mr_f(index-2,1))*(1-mr_f(index-3,1))))*pop_r_f_t(index-4,6));
% mr_f(92,1)=(diff_u_f(97,1)-(mr_f(93,1)+mr_f(94,1)*(1-mr_f(93,1))+mr_f(95,1)*(1-mr_f(94,1))*(1-mr_f(93,1))+mr_f(96,1)*(1-mr_f(95,1))*(1-mr_f(94,1))*(1-mr_f(93,1)))*pop_r_f_t(92,6))/((1-(mr_f(93,1)+mr_f(94,1)*(1-mr_f(93,1))+mr_f(95,1)*(1-mr_f(94,1))*(1-mr_f(93,1))+mr_f(96,1)*(1-mr_f(95,1))*(1-mr_f(94,1))*(1-mr_f(93,1))))*pop_r_f_t(92,6));
% age <= 95
for i=1:index-5
    k=index-4-i; % index
    mr_f(k,1)=(diff_u_f(k+5,1)-(mr_f(k+1,1)+mr_f(k+2,1)*(1-mr_f(k+1,1))+mr_f(k+3,1)*(1-mr_f(k+2,1))*(1-mr_f(k+1,1))+mr_f(k+4,1)*(1-mr_f(k+3,1))*(1-mr_f(k+2,1))*(1-mr_f(k+1,1)))*pop_r_f_t(k,6))/((1-(mr_f(k+1,1)+mr_f(k+2,1)*(1-mr_f(k+1,1))+mr_f(k+3,1)*(1-mr_f(k+2,1))*(1-mr_f(k+1,1))+mr_f(k+4,1)*(1-mr_f(k+3,1))*(1-mr_f(k+2,1))*(1-mr_f(k+1,1))))*pop_r_f_t(k,6));
    % mr_f(k,1)=(diff_u_f(k+5,1)-mr_f(k+1,1)*(1-mr_f(k+1,1))*pop_r_f_t(k+1,1)-mr_f(k+2,1)*(1-mr_f(k+2,1))^2*pop_r_f_t(k+2,1)-mr_f(k+3,1)*(1-mr_f(k+3,1))^3*pop_r_f_t(k+3,1)-mr_f(k+4,1)*(1-mr_f(k+4,1))^4*pop_r_f_t(k+4,1))/pop_r_f_t(k,1);
end

%*******
% male
%*******
% migration rate equals zero for age > age_k
mr_m(index+1:age_max+1,1)=0;
% age of 100
mr_m(index,1)=diff_u_m(index+5,1)/pop_r_m_t(index,6);
% mr_m(96,1)=diff_u_m(101,1)/pop_r_m_t(96,6);
% age of 99
mr_m(index-1,1)=(diff_u_m(index+4,1)-mr_m(index,1)*pop_r_m_t(index-1,6))/((1-mr_m(index,1))*pop_r_m_t(index-1,6));
% mr_m(95,1)=(diff_u_m(100,1)-mr_m(96,1)*pop_r_m_t(95,6))/((1-mr_m(96,1))*pop_r_m_t(95,6));
% age of 98
mr_m(index-2,1)=(diff_u_m(index+3,1)-(mr_m(index-1,1)+mr_m(index,1)*(1-mr_m(index-1,1)))*pop_r_m_t(index-2,6))/((1-(mr_m(index-1,1)+mr_m(index,1)*(1-mr_m(index-1,1))))*pop_r_m_t(index-2,6));
% mr_m(94,1)=(diff_u_m(99,1)-(mr_m(95,1)+mr_m(96,1)*(1-mr_m(95,1)))*pop_r_m_t(94,6))/((1-(mr_m(95,1)+mr_m(96,1)*(1-mr_m(95,1))))*pop_r_m_t(94,6));
% age of 97
mr_m(index-3,1)=(diff_u_m(index+2,1)-(mr_m(index-2,1)+mr_m(index-1,1)*(1-mr_m(index-2,1))+mr_m(index,1)*(1-mr_m(index-1,1))*(1-mr_m(index-2,1)))*pop_r_m_t(index-3,6))/((1-(mr_m(index-2,1)+mr_m(index-1,1)*(1-mr_m(index-2,1))+mr_m(index,1)*(1-mr_m(index-1,1))*(1-mr_m(index-2,1))))*pop_r_m_t(index-3,6));
% mr_m(93,1)=(diff_u_m(98,1)-(mr_m(94,1)+mr_m(95,1)*(1-mr_m(94,1))+mr_m(96,1)*(1-mr_m(95,1))*(1-mr_m(94,1)))*pop_r_m_t(93,6))/((1-(mr_m(94,1)+mr_m(95,1)*(1-mr_m(94,1))+mr_m(96,1)*(1-mr_m(95,1))*(1-mr_m(94,1))))*pop_r_m_t(93,6));
% age of 96
mr_m(index-4,1)=(diff_u_m(index+1,1)-(mr_m(index-3,1)+mr_m(index-2,1)*(1-mr_m(index-3,1))+mr_m(index-1,1)*(1-mr_m(index-2,1))*(1-mr_m(index-3,1))+mr_m(index,1)*(1-mr_m(index-1,1))*(1-mr_m(index-2,1))*(1-mr_m(index-3,1)))*pop_r_m_t(index-4,6))/((1-(mr_m(index-3,1)+mr_m(index-2,1)*(1-mr_m(index-3,1))+mr_m(index-1,1)*(1-mr_m(index-2,1))*(1-mr_m(index-3,1))+mr_m(index,1)*(1-mr_m(index-1,1))*(1-mr_m(index-2,1))*(1-mr_m(index-3,1))))*pop_r_m_t(index-4,6));
% mr_m(92,1)=(diff_u_m(97,1)-(mr_m(93,1)+mr_m(94,1)*(1-mr_m(93,1))+mr_m(95,1)*(1-mr_m(94,1))*(1-mr_m(93,1))+mr_m(96,1)*(1-mr_m(95,1))*(1-mr_m(94,1))*(1-mr_m(93,1)))*pop_r_m_t(92,6))/((1-(mr_m(93,1)+mr_m(94,1)*(1-mr_m(93,1))+mr_m(95,1)*(1-mr_m(94,1))*(1-mr_m(93,1))+mr_m(96,1)*(1-mr_m(95,1))*(1-mr_m(94,1))*(1-mr_m(93,1))))*pop_r_m_t(92,6));
% age <= 95
for i=1:index-5
    k=index-4-i; % index
    mr_m(k,1)=(diff_u_m(k+5,1)-(mr_m(k+1,1)+mr_m(k+2,1)*(1-mr_m(k+1,1))+mr_m(k+3,1)*(1-mr_m(k+2,1))*(1-mr_m(k+1,1))+mr_m(k+4,1)*(1-mr_m(k+3,1))*(1-mr_m(k+2,1))*(1-mr_m(k+1,1)))*pop_r_m_t(k,6))/((1-(mr_m(k+1,1)+mr_m(k+2,1)*(1-mr_m(k+1,1))+mr_m(k+3,1)*(1-mr_m(k+2,1))*(1-mr_m(k+1,1))+mr_m(k+4,1)*(1-mr_m(k+3,1))*(1-mr_m(k+2,1))*(1-mr_m(k+1,1))))*pop_r_m_t(k,6));
    % mr_m(k,1)=(diff_u_m(k+5,1)-mr_m(k+1,1)*(1-mr_m(k+1,1))*pop_r_m_t(k+1,1)-mr_m(k+2,1)*(1-mr_m(k+2,1))^2*pop_r_m_t(k+2,1)-mr_m(k+3,1)*(1-mr_m(k+3,1))^3*pop_r_m_t(k+3,1)-mr_m(k+4,1)*(1-mr_m(k+4,1))^4*pop_r_m_t(k+4,1))/pop_r_m_t(k,1);
end

%******
% all
%******
% migration rate equals zero for age > age_k
mr(index+1:age_max+1,1)=0;
% age of 100
mr(index,1)=diff_u(index+5,1)/pop_r_t(index,6);
% mr(96,1)=diff_u(101,1)/pop_r_t(96,6);
% age of 99
mr(index-1,1)=(diff_u(index+4,1)-mr(index,1)*pop_r_t(index-1,6))/((1-mr(index,1))*pop_r_t(index-1,6));
% mr(95,1)=(diff_u(100,1)-mr(96,1)*pop_r_t(95,6))/((1-mr(96,1))*pop_r_t(95,6));
% age of 98
mr(index-2,1)=(diff_u(index+3,1)-(mr(index-1,1)+mr(index,1)*(1-mr(index-1,1)))*pop_r_t(index-2,6))/((1-(mr(index-1,1)+mr(index,1)*(1-mr(index-1,1))))*pop_r_t(index-2,6));
% mr(94,1)=(diff_u(99,1)-(mr(95,1)+mr(96,1)*(1-mr(95,1)))*pop_r_t(94,6))/((1-(mr(95,1)+mr(96,1)*(1-mr(95,1))))*pop_r_t(94,6));
% age of 97
mr(index-3,1)=(diff_u(index+2,1)-(mr(index-2,1)+mr(index-1,1)*(1-mr(index-2,1))+mr(index,1)*(1-mr(index-1,1))*(1-mr(index-2,1)))*pop_r_t(index-3,6))/((1-(mr(index-2,1)+mr(index-1,1)*(1-mr(index-2,1))+mr(index,1)*(1-mr(index-1,1))*(1-mr(index-2,1))))*pop_r_t(index-3,6));
% mr(93,1)=(diff_u(98,1)-(mr(94,1)+mr(95,1)*(1-mr(94,1))+mr(96,1)*(1-mr(95,1))*(1-mr(94,1)))*pop_r_t(93,6))/((1-(mr(94,1)+mr(95,1)*(1-mr(94,1))+mr(96,1)*(1-mr(95,1))*(1-mr(94,1))))*pop_r_t(93,6));
% age of 96
mr(index-4,1)=(diff_u(index+1,1)-(mr(index-3,1)+mr(index-2,1)*(1-mr(index-3,1))+mr(index-1,1)*(1-mr(index-2,1))*(1-mr(index-3,1))+mr(index,1)*(1-mr(index-1,1))*(1-mr(index-2,1))*(1-mr(index-3,1)))*pop_r_t(index-4,6))/((1-(mr(index-3,1)+mr(index-2,1)*(1-mr(index-3,1))+mr(index-1,1)*(1-mr(index-2,1))*(1-mr(index-3,1))+mr(index,1)*(1-mr(index-1,1))*(1-mr(index-2,1))*(1-mr(index-3,1))))*pop_r_t(index-4,6));
% mr(92,1)=(diff_u(97,1)-(mr(93,1)+mr(94,1)*(1-mr(93,1))+mr(95,1)*(1-mr(94,1))*(1-mr(93,1))+mr(96,1)*(1-mr(95,1))*(1-mr(94,1))*(1-mr(93,1)))*pop_r_t(92,6))/((1-(mr(93,1)+mr(94,1)*(1-mr(93,1))+mr(95,1)*(1-mr(94,1))*(1-mr(93,1))+mr(96,1)*(1-mr(95,1))*(1-mr(94,1))*(1-mr(93,1))))*pop_r_t(92,6));
% age <= 95
for i=1:index-5
    k=index-4-i; % index
    mr(k,1)=(diff_u(k+5,1)-(mr(k+1,1)+mr(k+2,1)*(1-mr(k+1,1))+mr(k+3,1)*(1-mr(k+2,1))*(1-mr(k+1,1))+mr(k+4,1)*(1-mr(k+3,1))*(1-mr(k+2,1))*(1-mr(k+1,1)))*pop_r_t(k,6))/((1-(mr(k+1,1)+mr(k+2,1)*(1-mr(k+1,1))+mr(k+3,1)*(1-mr(k+2,1))*(1-mr(k+1,1))+mr(k+4,1)*(1-mr(k+3,1))*(1-mr(k+2,1))*(1-mr(k+1,1))))*pop_r_t(k,6));
    % mr(k,1)=(diff_u(k+5,1)-mr(k+1,1)*(1-mr(k+1,1))*pop_r_t(k+1,1)-mr(k+2,1)*(1-mr(k+2,1))^2*pop_r_t(k+2,1)-mr(k+3,1)*(1-mr(k+3,1))^3*pop_r_t(k+3,1)-mr(k+4,1)*(1-mr(k+4,1))^4*pop_r_t(k+4,1))/pop_r_t(k,1);
end

mig_rate_f=smooth(mr_f,'moving');
mig_rate_m=smooth(mr_m,'moving');
mig_rate=smooth(mr,'moving');

% total imgration
sum(diff_u);

% urban growth rate
(sum(pop2005(:,1))/sum(pop_u_t(:,1)))^(1/5)-1;
% contribution
sum(diff_u)/(sum(pop2005(:,1))-sum(pop_u_t(:,1)));

% current rural population
sum(pop2005(:,2));

% age 18 and 19
sum(diff_u(19:20));
% college enrollment ratio
19.2*1e+6*0.18/sum(diff_u(19:20));

% discrete migration age structure
dist(1)=sum(diff_u(1:15))/sum(diff_u);
dist(2)=sum(diff_u(16:30))/sum(diff_u);
dist(3)=sum(diff_u(31:45))/sum(diff_u);
dist(4)=sum(diff_u(45:60))/sum(diff_u);
dist(5)=sum(diff_u(61:101))/sum(diff_u);
% disp(dist)

mig_rate_young(1)=sum(diff_u(15+1:18+1))/sum(diff_u);
mig_rate_young(2)=sum(diff_u(15+1:20+1))/sum(diff_u);
mig_rate_young(3)=sum(diff_u(15+1:22+1))/sum(diff_u);
mig_rate_young(4)=sum(diff_u(15+1:25+1))/sum(diff_u);
mig_rate_young(5)=sum(diff_u(15+1:30+1))/sum(diff_u);
disp(mig_rate_young)

% save migration rate for computation
mig_age_min=15; mig_age_max=30;
mig_rate_young=1-(1-sum(diff_u(mig_age_min+1:mig_age_max+1))/sum(pop_r_t(mig_age_min+1:mig_age_max+1,1)))^(1/5);
mig_rate_f_young=1-(1-sum(diff_u_f(mig_age_min+1:mig_age_max+1))/sum(pop_r_f_t(mig_age_min+1:mig_age_max+1,1)))^(1/5);
mig_rate_m_young=1-(1-sum(diff_u_m(mig_age_min+1:mig_age_max+1))/sum(pop_r_m_t(mig_age_min+1:mig_age_max+1,1)))^(1/5);
save data_migration mig_distribution mig_rate_f_sum mig_rate_m_sum mig_rate mig_rate_f mig_rate_m mig_rate_young mig_rate_f_young mig_rate_m_young mig_age_min mig_age_max pop2005 pop_u_f_t pop_r_f_t pop_u_m_t pop_r_m_t year_ini year_end age_min age_max



