

% project the population from 2000

%  notice that age is from 22 to 100
%  and mort from 0 to 100


clear
close all

index_fig=0;
i_fig=0;


%% ------------------- Data -------------------

% some basic parameter from the census 2000 and 2005, mortality rate is useful
parameter;



% ages 
age_min=0;
age_ini=22;
age_max=100;
age_end=age_max-age_ini+1;
time_max=800;

% initial year
year_ini=2000;
t_2005=2005-year_ini+1;
t_2010=2010-year_ini+1;
t_2020=2020-year_ini+1;
t_2050=2050-year_ini+1;
t_2080=2080-year_ini+1;
t_2100=2100-year_ini+1;

% transition year
year_tra=2100;
t_tra=year_tra-year_ini+1;

% population reform, increase fertility rate
year_popreform=2013;
t_popreform=year_popreform-year_ini+1;

% ending year
year_end=year_ini+time_max-1+age_max-1;
t_end=year_end-year_ini+1;


%% ----------------- Mortality Rate and Life Expectation ----------------------
% from Zeng 2005
% urban male: 72@2000, 74@2020, 77@2050
% urban female: 76@2000, 78@2020, 81@2050
% rural male: 68@2000, 70.2@2020, 73.5@2050
% rural female: 72@2000, 74.2@2020, 77.5@2050
life_2000=[72,76,68,72];
life_2020=[74,78,70.2,74.2];
life_2050=[77,81,73.5,77.5];
% sex difference still 4
life_2080=[79.9,83.9,79.9,83.9];

% the 2000 and 2005 mortality rates are calculated in parameter.m
mort_2000=mort2000;
mort_2005=mort2005;


% adjust the mortality rate such that 2020, 2050, and 2080 life
% expectancies match the data
for i=1:4
    options=optimset('Display','off');
    fun_life_ratio=@(ratio_life) fun_life(ratio_life,squeeze(mort2000(:,i))/1000)-life_2020(i);
    ratio_2020(i)=fsolve(fun_life_ratio, 1,options);
    mort_2020(:,i)=mort2000(:,i)*ratio_2020(i);
end
for i=1:4
    fun_life_ratio=@(ratio_life) fun_life(ratio_life,squeeze(mort2000(:,i))/1000)-life_2050(i);
    ratio_2050(i)=fsolve(fun_life_ratio, 1,options);
    mort_2050(:,i)=mort2000(:,i)*ratio_2050(i);
end
for i=1:4
    fun_life_ratio=@(ratio_life) fun_life(ratio_life,squeeze(mort2000(:,i))/1000)-life_2080(i);
    ratio_2080(i)=fsolve(fun_life_ratio, 1,options);
    mort_2080(:,i)=mort2000(:,i)*ratio_2080(i);
end


% mortality rates decreases linearly between 2000 and 2020
for t=1:t_2020
    mort_t(:,:,t)=mort2000+(t-1)/(t_2020-1)*(mort_2020-mort2000);
end
% mortality rates decreases linearly between 2020 and 2050
for t=t_2020+1:t_2050
    mort_t(:,:,t)=mort_2020+(t-t_2020)/(t_2050-t_2020)*(mort_2050-mort_2020);
end
% mortality rates decreases linearly between 2050 and 2080
for t=t_2050+1:t_2080
    mort_t(:,:,t)=mort_2050+(t-t_2050)/(t_2080-t_2050)*(mort_2080-mort_2050);
end
% mortality rates stays constant after 2080
for t=t_2080+1:t_end
    mort_t(:,:,t)=mort_2080;
end


%% ------------------------ Sex Ratio at Birth ----------------------
% projections from Zeng 2006
sex_birth_u_raw=1.142; % start with high ratio
sex_birth_r_raw=1.187;
sex_birth_u_zengyi3=1.05; % converges to the lower ratio in 2030
sex_birth_r_zengyi3=1.06;
 
% sex
t_2030=2030-year_ini+1;
for t=1:t_2030
    sex_birth_u_t(t)=sex_birth_u_raw+(t-1)/(t_2030-1)*(sex_birth_u_zengyi3-sex_birth_u_raw);
    sex_birth_r_t(t)=sex_birth_r_raw+(t-1)/(t_2030-1)*(sex_birth_r_zengyi3-sex_birth_r_raw);
end
for t=t_2030+1:t_end
     sex_birth_u_t(t)=sex_birth_u_zengyi3;
     sex_birth_r_t(t)=sex_birth_r_zengyi3;
end 




%% ------------------------ Find the Long-run Fertility Rate  ------------------------
% such that the population is constant

iter=0;
fert_constant=2.0763; % guess the fertility rate that keeps population constant
dev=1;

% update until finding the right fert_constant
while iter<100 && abs(dev)>1e-9

iter=iter+1;
case_fert=2.2; % this case takes the fertility rate from scenario 2 of Zeng 2007, and assumes that it goes up to fert_constant
if case_fert==1
    fert_u_reform=1.2;    fert_r_reform=1.98;
    fert_u_end=fert_u_reform; fert_r_end=fert_r_reform; 
elseif   case_fert==2
    fert_u_reform=1.8;    fert_r_reform=1.98;
    fert_u_end=fert_u_reform; fert_r_end=fert_r_reform; 
elseif case_fert==4
    fert_u_reform=1.8;    fert_r_reform=2.27;
    fert_u_end=fert_u_reform; fert_r_end=fert_r_reform; 
elseif case_fert==5
    fert_u_reform=fert_constant;    fert_r_reform=fert_constant;
    fert_u_end=fert_u_reform; fert_end=fert_r_reform; 
elseif case_fert==2.2; % zengyi 2, increase to fert_constant from 2050 to 2100
    fert_u_reform=1.8;    fert_r_reform=1.98;
    fert_u_end=fert_constant; fert_r_end=fert_constant; 
elseif case_fert==6; % 1.8 in Chen and Liu
    fert_u_reform=1.8;    fert_r_reform=1.8;
    fert_u_end=fert_u_reform; fert_r_end=fert_r_reform; 
end


% fertility
% from Zeng 2007
fert_total_2000=[1.15,1.90];
fert_2000(:,1)=fert2000(:,1)*fert_total_2000(1)*1000/sum(fert2000(:,1));
fert_2000(:,2)=fert2000(:,2)*fert_total_2000(2)*1000/sum(fert2000(:,2));
fert_2005=fert2005;
fert_total_reform=[fert_u_reform, fert_r_reform]; 
fert_reform(:,1)=fert_2000(:,1)*fert_total_reform(1)*1000/sum(fert_2000(:,1));
fert_reform(:,2)=fert_2000(:,2)*fert_total_reform(2)*1000/sum(fert_2000(:,2));
fert_total_end=[fert_u_end, fert_r_end];
fert_end(:,1)=fert_reform(:,1)*fert_total_end(1)*1000/sum(fert_reform(:,1));
fert_end(:,2)=fert_reform(:,2)*fert_total_end(2)*1000/sum(fert_reform(:,2));

for t=1:t_2005
    fert_t(:,:,t)=fert_2000+(t-1)/(t_2005-1)*(fert_2005-fert_2000);
end
for t=t_2005+1:t_popreform-1
%     fert_t(:,:,t)=fert_2005+(t-t_2005)/(t_popreform-t_2005)*(fert_reform-fert_2005);
    fert_t(:,:,t)=fert_2005;
end
for t=t_popreform:t_2050
    fert_t(:,:,t)=fert_reform;
end
for t=t_2050:t_2100
    fert_t(:,:,t)=fert_reform+(t-t_2050)/(t_2100-t_2050)*(fert_end-fert_reform);
end
for t=t_2100:t_end
    fert_t(:,:,t)=fert_end;
end






% ---------------  Without Migration ------------------

% urban
pop_u_f_t(:,1)=pop2000(:,3); % female
pop_u_m_t(:,1)=pop2000(:,1)-pop2000(:,3); % male
% rural
pop_r_f_t(:,1)=pop2000(:,4); % female
pop_r_m_t(:,1)=pop2000(:,2)-pop2000(:,4); % male

% migration
mig_index=1; % 0 shutting down migration


% dynamics
for t=2:year_end-year_ini+1

    % urban
    % existing (using mortality rates)
    for i=2:age_max-age_min+1
        pop_u_m_t(i,t)=pop_u_m_t(i-1,t-1)*(1-mort_t(i-1,1,t)/1000); % male
        pop_u_f_t(i,t)=pop_u_f_t(i-1,t-1)*(1-mort_t(i-1,2,t)/1000); % female
        % from this equation, it looks like that mort(i) is the mortality
        % rate of age group i to age i+1, whose age is i-1
        
    end
    % urban newly born
    nb_u_t(t)=sum(pop_u_f_t(fert_min:fert_max,t).*fert_t(:,1,t)/1000);
    % total population
    pop_u_f_t(1,t)=nb_u_t(t)*1/(sex_birth_u_t(t)+1); % female
    pop_u_m_t(1,t)=nb_u_t(t)-pop_u_f_t(1,t); % male
    
    % rural
    % existing (using mortality rates)
    for i=2:age_max-age_min+1
        pop_r_m_t(i,t)=pop_r_m_t(i-1,t-1)*(1-mort_t(i-1,3,t)/1000); % male
        pop_r_f_t(i,t)=pop_r_f_t(i-1,t-1)*(1-mort_t(i-1,4,t)/1000); % female
        
    end
    % rural newly born
    nb_r_t(t)=sum(pop_r_f_t(fert_min:fert_max,t).*fert_t(:,2,t)/1000);
    % total population
    pop_r_f_t(1,t)=nb_r_t(t)*1/(sex_birth_r_t(t)+1); % female
    pop_r_m_t(1,t)=nb_r_t(t)-pop_r_f_t(1,t); % male
    
end

% total population
pop_u_t=pop_u_f_t+pop_u_m_t;
pop_r_t=pop_r_f_t+pop_r_m_t;


% aggregation
pop_t=pop_u_t+pop_r_t;

% time series
for t=1:year_end-year_ini+1
    pop_u_t_sum(t)=sum(pop_u_t(:,t));
    pop_r_t_sum(t)=sum(pop_r_t(:,t));
    pop_t_sum(t)=sum(pop_t(:,t));
end

% ------------------  With Migration ---------------

% load data_migration

% the rate that michael gets in demography7
load('../Demography1_MigrationProjection/data_migration','mig_distribution', 'mig_rate_f_sum', 'mig_rate_m_sum', 'mig_rate', 'mig_rate_f', 'mig_rate_m', 'mig_rate_young', 'mig_rate_f_young', 'mig_rate_m_young')
% load '..\Demography1_MigrationProjection\data_migration'

% only look at the migration between age 11 and 50
age_mig_min=10;
age_mig_max=50;
mig_rate_m(1:age_mig_min+1)=0; mig_rate_m(age_mig_max+2:age_max+1)=0;
mig_rate_f(1:age_mig_min+1)=0; mig_rate_f(age_mig_max+2:age_max+1)=0;
mig_rate_sum=sum(pop_r_f_t(1:age_max+1,1).*mig_rate_f(1:age_max+1)+pop_r_m_t(1:age_max+1,1).*mig_rate_m(1:age_max+1))/sum(pop_r_f_t(1:age_max+1,1)+pop_r_m_t(1:age_max+1,1));

mig_rate_target=0.023; % migration rate 2.3% per year
mig_rate_m=mig_rate_m*mig_rate_target/mig_rate_sum;
mig_rate_f=mig_rate_f*mig_rate_target/mig_rate_sum;
mig_rate_sum=sum(pop_r_f_t(1:age_max+1,1).*mig_rate_f(1:age_max+1)+pop_r_m_t(1:age_max+1,1).*mig_rate_m(1:age_max+1))/sum(pop_r_f_t(1:age_max+1,1)+pop_r_m_t(1:age_max+1,1));


case_mig=1; % 1: age-specific migration 2: total migration rate 3: adjusted total migration rate

% initial 
pop_u_t_mig(:,1)=pop_u_t(:,1);
pop_r_t_mig(:,1)=pop_r_t(:,1);
pop_u_t_mig_sum(1)=sum(pop_u_t_mig(:,1));
pop_r_t_mig_sum(1)=sum(pop_r_t_mig(:,1));

% initial by gender
pop_u_f_t_mig(:,1)=pop_u_f_t(:,1);
pop_u_m_t_mig(:,1)=pop_u_m_t(:,1);
pop_r_f_t_mig(:,1)=pop_r_f_t(:,1);
pop_r_m_t_mig(:,1)=pop_r_m_t(:,1);
pop_u_f_t_mig_sum(1)=sum(pop_u_f_t_mig(:,1));
pop_u_m_t_mig_sum(1)=sum(pop_u_m_t_mig(:,1));
pop_r_f_t_mig_sum(1)=sum(pop_r_f_t_mig(:,1));
pop_r_m_t_mig_sum(1)=sum(pop_r_m_t_mig(:,1));



% migration stops after t_tra (2100)
for t=2:t_tra
    mig_rate_m_t(:,t)=mig_rate_m;
    mig_rate_f_t(:,t)=mig_rate_f;
end
for t=t_tra+1:t_end
    mig_rate_m_t(:,t)=0;
    mig_rate_f_t(:,t)=0;
end



% migrants to urban
for t=2:t_end
    age_nomig=age_max;
    
    % urban
    % existing (using mortality rates)
    for i=2:age_max-age_min+1
        pop_u_m_t_mig(i,t)=pop_u_m_t_mig(i-1,t-1)*(1-mort_t(i-1,1,t)/1000); % male
        pop_u_f_t_mig(i,t)=pop_u_f_t_mig(i-1,t-1)*(1-mort_t(i-1,2,t)/1000); % female
    end
    % urban newly born
    nb_u_t_mig(t)=sum(pop_u_f_t_mig(fert_min:fert_max,t).*fert_t(:,1,t)/1000);
    % total population
    % all new born in the urban area are original
    pop_u_f_t_mig(1,t)=nb_u_t_mig(t)*1/(sex_birth_u_t(t)+1); % female
    pop_u_m_t_mig(1,t)=nb_u_t_mig(t)-pop_u_f_t_mig(1,t); % male
        
    % rural
    % existing (using mortality rates)
    for i=2:age_max-age_min+1
        pop_r_m_t_mig(i,t)=pop_r_m_t_mig(i-1,t-1)*(1-mort_t(i-1,3,t)/1000); % male
        pop_r_f_t_mig(i,t)=pop_r_f_t_mig(i-1,t-1)*(1-mort_t(i-1,4,t)/1000); % female        
    end
    % rural newly born
    nb_r_t_mig(t)=sum(pop_r_f_t_mig(fert_min:fert_max,t).*fert_t(:,2,t)/1000);
    % total population
    pop_r_f_t_mig(1,t)=nb_r_t_mig(t)*1/(sex_birth_r_t(t)+1); % female
    pop_r_m_t_mig(1,t)=nb_r_t_mig(t)-pop_r_f_t_mig(1,t); % male
    
    % ----------  age_ini+1 means age_ini because the pop(1,t) is for age 0
    if case_mig==1
        % age specific migration rate
        mig_f_t(:,t)=pop_r_f_t_mig(:,t).*mig_rate_f_t(:,t);
        mig_m_t(:,t)=pop_r_m_t_mig(:,t).*mig_rate_m_t(:,t);
    elseif case_mig==2 % case_mig==2
        mig_f_t(:,t)=pop_r_f_t_mig(:,t)*mig_rate_sum_t(t);
        mig_m_t(:,t)=pop_r_m_t_mig(:,t)*mig_rate_sum_t(t);
    elseif case_mig==3;
        adjust_mig=0.85; % for 2050
        adjust_mig=0.775; % for 2020a
        mig_f_t(:,t)=pop_r_f_t_mig(:,t)*mig_rate_sum_t(t)*adjust_mig;
        mig_m_t(:,t)=pop_r_m_t_mig(:,t)*mig_rate_sum_t(t)*adjust_mig;
    end
    % including migrants
    pop_u_f_t_mig(:,t)=pop_u_f_t_mig(:,t)+mig_f_t(:,t);
    pop_u_m_t_mig(:,t)=pop_u_m_t_mig(:,t)+mig_m_t(:,t);
    % excluding migrants
    pop_r_f_t_mig(:,t)=pop_r_f_t_mig(:,t)-mig_f_t(:,t);
    pop_r_m_t_mig(:,t)=pop_r_m_t_mig(:,t)-mig_m_t(:,t);


end


% computing aggregates

pop_u_t_mig=pop_u_f_t_mig+pop_u_m_t_mig;
pop_r_t_mig=pop_r_f_t_mig+pop_r_m_t_mig;
pop_t_mig=pop_u_t_mig+pop_r_t_mig;

for  t=1:year_end-year_ini+1

    pop_u_t_mig_sum(t)=sum(pop_u_t_mig(:,t));
    pop_r_t_mig_sum(t)=sum(pop_r_t_mig(:,t));
    pop_t_mig_sum(t)=sum(pop_t_mig(:,t));

    pop_u_f_t_mig_sum(t)=sum(pop_u_f_t_mig(:,t));
    pop_u_m_t_mig_sum(t)=sum(pop_u_m_t_mig(:,t));
    pop_r_f_t_mig_sum(t)=sum(pop_r_f_t_mig(:,t));
    pop_r_m_t_mig_sum(t)=sum(pop_r_m_t_mig(:,t));
    
    % urban labor force
    labor_u_t_mig_sum(t)=sum(pop_u_f_t_mig(1+age_labor_f_min:1+age_labor_f_max,t))+sum(pop_u_m_t_mig(1+age_labor_m_min:1+age_labor_m_max,t));
    labor_u_t_sum(t)=sum(pop_u_f_t(1+age_labor_f_min:1+age_labor_f_max,t))+sum(pop_u_m_t(1+age_labor_m_min:1+age_labor_m_max,t));
    
    % urban old
    old_u_t_mig_sum(t)=sum(pop_u_f_t_mig(1+age_labor_f_max+1:1+age_max,t))+sum(pop_u_m_t_mig(1+age_labor_m_max+1:1+age_max,t));
    old_u_t_sum(t)=sum(pop_u_f_t(1+age_labor_f_max+1:1+age_max,t))+sum(pop_u_m_t(1+age_labor_m_max+1:1+age_max,t));
    
    % rural labor force
    labor_r_t_mig_sum(t)=sum(pop_r_f_t_mig(1+age_labor_f_min:1+age_labor_f_max,t))+sum(pop_r_m_t_mig(1+age_labor_m_min:1+age_labor_m_max,t));
    labor_r_t_sum(t)=sum(pop_r_f_t(1+age_labor_f_min:1+age_labor_f_max,t))+sum(pop_r_m_t(1+age_labor_m_min:1+age_labor_m_max,t));
    
    % rural old
    old_r_t_mig_sum(t)=sum(pop_r_f_t_mig(1+age_labor_f_max+1:1+age_max,t))+sum(pop_r_m_t_mig(1+age_labor_m_max+1:1+age_max,t));
    old_r_t_sum(t)=sum(pop_r_f_t(1+age_labor_f_max+1:1+age_max,t))+sum(pop_r_m_t(1+age_labor_m_max+1:1+age_max,t));

end

dev=pop_t_mig_sum(t_end)/pop_t_mig_sum(t_end-1)-1;
fert_constant=fert_constant*(1-dev);



end % end of iter_fert_con


iter
dev
fert_constant


clear pop_r_f_t pop_r_m_t pop_u_f_t pop_u_m_t


% urban population growth rate from 1993 to 2000
N_growth=[0.031017871
0.030024417
0.029412625
0.060556093
0.057500536
0.05472889
0.051432417
0.049327969
0.047009106
];



%% -------------------------- Check Variables ------------------------
fert_u_t=squeeze(fert_t(:,1,:));
fert_r_t=squeeze(fert_t(:,2,:));

% mort_t

% life expectation
for t=1:t_end
    life_u_m_t(t)=fun_life(1,squeeze(mort_t(:,1,t))/1000);
    life_u_f_t(t)=fun_life(1,squeeze(mort_t(:,2,t))/1000);
    life_r_m_t(t)=fun_life(1,squeeze(mort_t(:,3,t))/1000);
    life_r_f_t(t)=fun_life(1,squeeze(mort_t(:,4,t))/1000);
end

life_t=(life_r_f_t.*pop_r_f_t_mig_sum+life_r_m_t.*pop_r_m_t_mig_sum+life_u_f_t.*pop_u_f_t_mig_sum+life_u_m_t.*pop_u_m_t_mig_sum)./(pop_r_f_t_mig_sum+pop_r_m_t_mig_sum+pop_u_f_t_mig_sum+pop_u_m_t_mig_sum);


ratio_sex_t=sum(pop_u_m_t_mig+pop_r_m_t_mig,1)./sum(pop_u_f_t_mig+pop_r_f_t_mig,1);

% new born in peroid 1
    t=1;
    nb_u_t_mig(t)=sum(pop_u_f_t_mig(fert_min:fert_max,t).*fert_t(:,1,t)/1000);
    nb_r_t_mig(t)=sum(pop_r_f_t_mig(fert_min:fert_max,t).*fert_t(:,2,t)/1000);
% ex-post fertility rate
for t=1:t_end
    fert_u_t_expost(t)=nb_u_t_mig(t)/(fert_u_t(:,t)'/sum(fert_u_t(:,t))*(pop_u_f_t_mig(fert_min:fert_max,t)-mig_f_t(fert_min:fert_max,t)));
    fert_r_t_expost(t)=nb_r_t_mig(t)/(fert_r_t(:,t)'/sum(fert_r_t(:,t))*(pop_r_f_t_mig(fert_min:fert_max,t)+mig_f_t(fert_min:fert_max,t)));
    fert_ur_t_expost(t)=(nb_u_t_mig(t)+nb_r_t_mig(t))/(fert_u_t(:,t)'/sum(fert_u_t(:,t))*(pop_u_f_t_mig(fert_min:fert_max,t)-mig_f_t(fert_min:fert_max,t))+fert_r_t(:,t)'/sum(fert_r_t(:,t))*(pop_r_f_t_mig(fert_min:fert_max,t)+mig_f_t(fert_min:fert_max,t)));
end



%% ------------------ Working Population ----------------
age_work=22;
age_retire_m=60;
age_retire_f=55;
for t=1:100
    pop_work_u_t_22(t)=sum(pop_u_f_t_mig(age_work+1:age_retire_f,t))+sum(pop_u_m_t_mig(age_work+1:age_retire_m,t));
    pop_work_r_t_22(t)=sum(pop_r_f_t_mig(age_work+1:age_retire_f,t))+sum(pop_r_m_t_mig(age_work+1:age_retire_m,t));
end

% filename='pop_work';
% xlswrite(filename,pop_work_u_t_22,1)
% xlswrite(filename,pop_work_r_t_22,2)



%% ------------------ Urban and Rural Mortality Rate including both Female and Male --------------------

% before 1
t=1;
% from pop age 0-age_max-1 to age 1-age_max
mort_u_jt(1:age_max,t)=(mort_t(1:age_max,1,t).*pop_u_m_t_mig(1:age_max,t)+mort_t(1:age_max,2,t).*pop_u_f_t_mig(1:age_max,t))./(pop_u_m_t_mig(1:age_max,t)+pop_u_f_t_mig(1:age_max,t));
mort_r_jt(1:age_max,t)=(mort_t(1:age_max,3,t).*pop_r_m_t_mig(1:age_max,t)+mort_t(1:age_max,4,t).*pop_r_f_t_mig(1:age_max,t))./(pop_r_m_t_mig(1:age_max,t)+pop_r_f_t_mig(1:age_max,t));
for t=2:t_end
    mort_u_jt(1:age_max,t)=(mort_t(1:age_max,1,t).*pop_u_m_t_mig(1:age_max,t-1)+mort_t(1:age_max,2,t-1).*pop_u_f_t_mig(1:age_max,t-1))./(pop_u_m_t_mig(1:age_max,t-1)+pop_u_f_t_mig(1:age_max,t-1));
    mort_r_jt(1:age_max,t)=(mort_t(1:age_max,3,t).*pop_r_m_t_mig(1:age_max,t-1)+mort_t(1:age_max,4,t-1).*pop_r_f_t_mig(1:age_max,t-1))./(pop_r_m_t_mig(1:age_max,t-1)+pop_r_f_t_mig(1:age_max,t-1));
end
% life expectation
for t=1:t_end
    life_u_t(t)=fun_life(1,squeeze(mort_u_jt(:,t))/1000);
    life_r_t(t)=fun_life(1,squeeze(mort_r_jt(:,t))/1000);
end
save data_mort2 mort_u_jt mort_r_jt


%% --------------------- Aggregate Migration ------------------------------
mig_f_t_sum=sum(mig_f_t,1);
mig_m_t_sum=sum(mig_m_t,1);
mig_t_sum=mig_f_t_sum+mig_m_t_sum;



%% ----------------- Old Age Dependency Ratio ----------------
% ------------- old age dependency ratio

old1=65;
old2=80;
old3=60;
age3=15;
age4=64;
age5=18;
age6=59;
t_fig2=401;
for t=1:t_fig2
    per_60_t(t)=sum(pop_t_mig(old3+1:101,t))/pop_t_mig_sum(t);
    per_60_u_t(t)=sum(pop_u_t_mig(old3+1:101,t))/pop_u_t_mig_sum(t);
    per_60_r_t(t)=sum(pop_r_t_mig(old3+1:101,t))/pop_r_t_mig_sum(t);
    
    per_60_t_nomig(t)=sum(pop_t(old3+1:101,t))/pop_t_sum(t);
    per_60_u_t_nomig(t)=sum(pop_u_t(old3+1:101,t))/pop_u_t_sum(t);
    per_60_r_t_nomig(t)=sum(pop_r_t(old3+1:101,t))/pop_r_t_sum(t);
    
    per_65_t(t)=sum(pop_t_mig(old1+1:101,t))/pop_t_mig_sum(t);
    per_65_u_t(t)=sum(pop_u_t_mig(old1+1:101,t))/pop_u_t_mig_sum(t);
    per_65_r_t(t)=sum(pop_r_t_mig(old1+1:101,t))/pop_r_t_mig_sum(t);
    
    per_80_t(t)=sum(pop_t_mig(old2+1:101,t))/pop_t_mig_sum(t);
    per_80_u_t(t)=sum(pop_u_t_mig(old2+1:101,t))/pop_u_t_mig_sum(t);
    per_80_r_t(t)=sum(pop_r_t_mig(old2+1:101,t))/pop_r_t_mig_sum(t);
    
    pop_15_64_t(t)=sum(pop_t_mig(age3+1:age4+1,t));
    pop_15_64_u_t(t)=sum(pop_u_t_mig(age3+1:age4+1,t));
    pop_15_64_r_t(t)=sum(pop_r_t_mig(age3+1:age4+1,t));
    
    per_15_64_t(t)=sum(pop_t_mig(age3+1:age4+1,t))/pop_t_mig_sum(t);
    per_15_64_u_t(t)=sum(pop_u_t_mig(age3+1:age4+1,t))/pop_u_t_mig_sum(t);
    per_15_64_r_t(t)=sum(pop_r_t_mig(age3+1:age4+1,t))/pop_r_t_mig_sum(t);
    
    per_18_59_t(t)=sum(pop_t_mig(age5+1:age6+1,t))/pop_t_mig_sum(t);
    per_18_59_u_t(t)=sum(pop_u_t_mig(age5+1:age6+1,t))/pop_u_t_mig_sum(t);
    per_18_59_r_t(t)=sum(pop_r_t_mig(age5+1:age6+1,t))/pop_r_t_mig_sum(t);
    
    per_18_59_t_nomig(t)=sum(pop_t(age5+1:age6+1,t))/pop_t_sum(t);
    per_18_59_u_t_nomig(t)=sum(pop_u_t(age5+1:age6+1,t))/pop_u_t_sum(t);
    per_18_59_r_t_nomig(t)=sum(pop_r_t(age5+1:age6+1,t))/pop_r_t_sum(t);
    
    
    dep_ratio_t(t)=(1-per_15_64_t(t))/per_15_64_t(t);
    dep_ratio_u_t(t)=(1-per_15_64_u_t(t))/per_15_64_u_t(t);
    dep_ratio_r_t(t)=(1-per_15_64_r_t(t))/per_15_64_r_t(t);
    
    dep_ratio_t_fz(t)=per_60_t(t)/per_18_59_t(t);
    dep_ratio_u_t_fz(t)=per_60_u_t(t)/per_18_59_u_t(t);
    dep_ratio_r_t_fz(t)=per_60_r_t(t)/per_18_59_r_t(t);
    
    dep_ratio_t_fz_nomig(t)=per_60_t_nomig(t)/per_18_59_t_nomig(t);
    dep_ratio_u_t_fz_nomig(t)=per_60_u_t_nomig(t)/per_18_59_u_t_nomig(t);
    dep_ratio_r_t_fz_nomig(t)=per_60_r_t_nomig(t)/per_18_59_r_t_nomig(t);
       
    dep_ratio_old_t(t)=per_65_t(t)/per_15_64_t(t);
    dep_ratio_old_u_t(t)=per_65_u_t(t)/per_15_64_u_t(t);
    dep_ratio_old_r_t(t)=per_65_r_t(t)/per_15_64_r_t(t);
end


%% -----------------------  Save to Data, normalize N and pop by N_1 -----------------
% first save the original data before normalization
save data_NoNormalization
% N is for urban, Nr is for rural
% mean(N_growth)=0.0457
N_growth(1:9,1)=0.03;


N_1_sum=sum(pop_u_t_mig(1+age_ini:1+age_max,1)); % normalize the first period urban population to 1

% urban population since 2001
for  t=1:year_end-year_ini+1
    N_t_mig(t,1:age_end)=pop_u_t_mig(1+age_ini:1+age_max,t)/N_1_sum*100;
    N_t_no_mig(t,1:age_end)=pop_u_t(1+age_ini:1+age_max,t)/N_1_sum*100;
    Nr_t_mig(t,1:age_end)=pop_r_t_mig(1+age_ini:1+age_max,t)/N_1_sum*100;
end



% test
tt=80;
N_t=sum(N_t_mig');
Nr_t=sum(Nr_t_mig');
for t=1:tt
    if t > 1
       NG_t(t)=N_t(t)/N_t(t-1)-1;
    end
    Nw_t(t)=sum(N_t_mig(t,1:60-age_ini));
    Nwr_t(t)=sum(N_t_mig(t,60-age_ini+1:age_end));
    Nw_t_no(t)=sum(N_t_no_mig(t,1:60-age_ini));
    Nwr_t_no(t)=sum(N_t_no_mig(t,60-age_ini+1:age_end));
end


% pop_t scale down as the same rate as N_t
pop_u_t_mig=pop_u_t_mig/N_1_sum*100;
pop_r_t_mig=pop_r_t_mig/N_1_sum*100;
pop_t_mig_sum=pop_t_mig_sum/N_1_sum*100;
pop_u_t_mig_sum=pop_u_t_mig_sum/N_1_sum*100;
pop_r_t_mig_sum=pop_r_t_mig_sum/N_1_sum*100;






% save for the pension calculation
save data_demography N_t_mig Nr_t_mig pop_u_t_mig pop_r_t_mig pop_t_mig_sum pop_u_t_mig_sum pop_r_t_mig_sum N_t_no_mig age_ini age_end age_max






