% pension base is cohort-year or age-year specific
% calculate the tax, pension payment, and debt


%% --------------------- 1. tax ----------------------
tax_total_t(1:t_dyn)=tau_e_t(1:t_dyn).*me_t(1:t_dyn).*Ne_labor_t(1:t_dyn)+...
                                tau_w_t(1:t_dyn).*w_t(1:t_dyn).*H_p_t(1:t_dyn);
% steady state value, use t_dyn and multiply by 1+N_growth_ss, and grows at
% the rate of 1+N_growth_ss
tax_total_ss=tax_total_t(t_dyn)*(1+N_growth_ss);

% life time tax (may need to add the steady state continuation value)
tax_lifetime=tax_total_t(1); 
for t=2:t_dyn
    tax_lifetime=tax_lifetime+tax_total_t(t)*((1+g)/(1+r))^(t-1);
end
% continuation value from steady state
tax_lifetime=tax_lifetime+tax_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));



%% ------------------- 2. Pension Payment -----------------


% -------------------- 2.1 If No Need to Clear Debt ------------------
% use the replace_w defined in pensionsystem_xxx.m 
if index_debtclear==0
    % replace_w_jt should be given before 
%     replace_w_coh(J+t_reform-1:t_dyn)=replace_w_coh2; % born after t_reform
%     module_replace_w_coh2jt;
    for t=1:t_dyn
            pension_total_t(t)=sum(replace_w_jt(Jw:J,t).*p_base_jt(Jw:J,t).*Nw_p_t(Jw:J,t));
            pension_base_total_t(t)=sum(p_base_jt(Jw:J,t).*Nw_p_t(Jw:J,t)); % for replacement 1
    end
    pension_total_ss=pension_total_t(t_dyn)*(1+N_growth_ss); % and then grows at the rate of 1+N_growth_ss
    pension_base_total_ss=pension_base_total_t(t_dyn)*(1+N_growth_ss);
    pension_lifetime=0;
    pension_base_lifetime=0;
    for t=1:t_dyn
        pension_lifetime=pension_lifetime+pension_total_t(t)*((1+g)/(1+r))^(t-1);
        pension_base_lifetime=pension_base_lifetime+pension_base_total_t(t)*((1+g)/(1+r))^(t-1);
    end
    pension_lifetime=pension_lifetime+pension_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
    pension_base_lifetime=pension_base_lifetime+pension_base_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
    gov_debt_lifetime=pension_debt_lifetime_r-(1+r)*Ag_transfer_real_value_ini+(1+r)*gov_debt_t(1)+pension_lifetime-tax_lifetime;
    % pension base after t_reform
    pension_base_t_reform=0; 
    for t=t_reform:t_dyn
        pension_base_t_reform=pension_base_t_reform+pension_base_total_t(t)*((1+g)/(1+r))^(t-1);
    end
    pension_base_t_reform=pension_base_t_reform+pension_base_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
            
    
else
% --------------------- 2.2 If Change replace_w_coh for those born after t_reform, in Order to Clear Debt ---------------

    % find out replace_w_coh3 using bisection
    iter_replace=1;
    dev_replace=1;
    replace_w_coh3_min=-1;
    replace_w_coh3_max=1;
    while iter_replace<100 && abs(dev_replace)>1e-10;
        replace_w_coh3=(replace_w_coh3_min+replace_w_coh3_max)/2;
        if index2==1 % entering 2013 as cut off
            replace_w_coh(J+t_reform-1:t_dyn)=replace_w_coh3;
        elseif index2==2 % retiring 2013 as cut off
            replace_w_coh(J+t_reform-1-(Jw-1):t_dyn)=replace_w_coh3; % J+t_reform-1 aged 1 in t_reform
        end
        
        module_replace_w_coh2jt;
        for t=1:t_dyn
            pension_total_t(t)=sum(replace_w_jt(Jw:J,t).*p_base_jt(Jw:J,t).*Nw_p_t(Jw:J,t));
            pension_base_total_t(t)=sum(p_base_jt(Jw:J,t).*Nw_p_t(Jw:J,t)); % for replacement 1
        end
        pension_total_ss=pension_total_t(t_dyn)*(1+N_growth_ss); % and then grows at the rate of 1+N_growth_ss
        pension_base_total_ss=pension_base_total_t(t_dyn)*(1+N_growth_ss);
        pension_lifetime=0;
        pension_base_lifetime=0;
        for t=1:t_dyn
            pension_lifetime=pension_lifetime+pension_total_t(t)*((1+g)/(1+r))^(t-1);
            pension_base_lifetime=pension_base_lifetime+pension_base_total_t(t)*((1+g)/(1+r))^(t-1);
        end
        pension_lifetime=pension_lifetime+pension_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
        pension_base_lifetime=pension_base_lifetime+pension_base_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
            % pension base after t_reform
        pension_base_t_reform=0; 
        for t=t_reform:t_dyn
            pension_base_t_reform=pension_base_t_reform+pension_base_total_t(t)*((1+g)/(1+r))^(t-1);
        end
        pension_base_t_reform=pension_base_t_reform+pension_base_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));

  
        % remember to add the transfer value
        gov_debt_lifetime=pension_debt_lifetime_r-(1+r)*Ag_transfer_real_value_ini+(1+r)*gov_debt_t(1)+pension_lifetime-tax_lifetime;
        
        dev_replace=gov_debt_lifetime;
        if dev_replace>0
            % replacement too high
            replace_w_coh3_max=replace_w_coh3;
        else
            replace_w_coh3_min=replace_w_coh3;
        end
        iter=iter+1;
%         replace_w_coh3
%         dev_replace
    end
    display('equilibrium pension replacement rate')
    replace_w_coh3
end


%% --------------------- 3. Government Debt, including rural and urban -------------------
% gov_debt_t(1) is defined in initialstate.m

for t=1:t_transfer-2
    gov_debt_t(t+1)=((1+r)*gov_debt_t(t)+pension_total_t(t)-tax_total_t(t)+pension_total_r_t(t)-tax_total_r_t(t))/(1+g);
end
% get transfer in period t_transfer
t=t_transfer-1;
gov_debt_t(t+1)=-Ag_transfer_real+((1+r)*gov_debt_t(t)+pension_total_t(t)-tax_total_t(t)+pension_total_r_t(t)-tax_total_r_t(t))/(1+g);
for t=t_transfer:t_dyn
    gov_debt_t(t+1)=((1+r)*gov_debt_t(t)+pension_total_t(t)-tax_total_t(t)+pension_total_r_t(t)-tax_total_r_t(t))/(1+g);
end

for t=t_dyn+1:1000
    gov_debt_t(t+1)=((1+r)*gov_debt_t(t)+(pension_total_ss-tax_total_ss)*(1+N_growth_ss)^(t-t_dyn-1)+(pension_total_r_ss-tax_total_r_ss)*(1+N_growth_ss)^(t-t_dyn-1))/(1+g);
end


%% ----------- 4. Calculate the Total Consumption, useful for the adjustment of Lagr --------

for t=1:t_dyn
    cw_p_total_t(t)=sum(Nw_p_t(1:J,t).*cw_p_t(1:J,t));
    yw_p_total_t(t)=sum(Nw_p_t(1:J,t).*yw_p_t(1:J,t));
end
cw_p_total_ss=cw_p_total_t(t_dyn)*(1+N_growth_ss);
yw_p_total_ss=yw_p_total_t(t_dyn)*(1+N_growth_ss);

cw_p_lifetime=0;
yw_p_lifetime=0;
for t=1:t_dyn
    cw_p_lifetime=cw_p_lifetime+cw_p_total_t(t)*((1+g)/(1+r))^(t-1);
    yw_p_lifetime=yw_p_lifetime+yw_p_total_t(t)*((1+g)/(1+r))^(t-1);
end

cw_p_lifetime=cw_p_lifetime+cw_p_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
yw_p_lifetime=yw_p_lifetime+yw_p_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));

error_lifetime=(1+r)*sum(Nw_p_t(1:J,1).*aw_p_t(1:J,1))+yw_p_lifetime-cw_p_lifetime-(1+r)*gov_debt_t(1);

