% it's kpr
% sig==1, log utility
% notice: distinguish Jw and Lw
% assume that the transfer is given when the household retires or t=1 if
% she is already retired

function [Con, Labor, Inc, Asset, Transfer]=...
    fun_c_a_j_Ramsey_FB(Beta, Prod_Beta_hat_l1 , Length, Interest, Prod_R_hat_l1, Wage, Surv, Asset_ini, Lagr)


Surv(1)=1; % make sure that there's no error
% Length is the length of the life left
% Lw is the peroid of retirement
% Interest is the interest rate sequence 
% Surv(j) is the survival rate to period j from period j-1
% the returned c and a are both adjusted by the growth
% Asset if Transfer in the last period
% Asset_withTran if Transfer in the first period
 
global sig g J Jw nu phi

Growth=g;
Asset(1)=Asset_ini;

% redefine Beta_hat and R_hat

Prod_Beta_hat_l(1)=Prod_Beta_hat_l1;
Prod_R_hat_l(1)=Prod_R_hat_l1;
% R_hat_l(1)=Interest(1);

for l=2:Length
    Beta_hat_l(l)=Beta*Surv(l);
    Prod_Beta_hat_l(l)=Prod_Beta_hat_l(l-1)*Beta_hat_l(l);
    
    R_hat_l(l)=Interest(l)/(Surv(l)*(1+Growth));
    Prod_R_hat_l(l)=Prod_R_hat_l(l-1)*R_hat_l(l);
end

% retire period Lw
Lw=Length-(J-Jw);


% start calculating consumption

if sig~=1 || nu~=1
    disp('Not log utility or nu~=1! Not working with the current code')
    pause;
end



if Lw<=1 % already retired
    %% -------------------- Case 1: Retired Already ----------------------
%     Ratio_c_l(1)=1; % ratio of cl and c1
%     for l=2:Length
%         Ratio_c_l(l)=Prod_Beta_hat_l(l)*Prod_R_hat_l(l)/(Prod_Beta_hat_l(1)*Prod_R_hat_l(1));
%     end
%     
    Con(1:Length)=1/Lagr*Prod_Beta_hat_l(1:Length).*Prod_R_hat_l(1:Length);
%     Con2(2:Length)=Con(1)*Ratio_c_l(2:Length);
    Labor(1:Length)=0;
    Inc(1:Length)=0;
    
    % lifetime Consumption from l=1
    % notice that we don't need to discount to j=1, only to l=1
    Con_sum=sum(Con(1:Length)./(Prod_R_hat_l(1:Length)/Prod_R_hat_l(1)));
    % transfer is given in l=1
    Transfer_l1=Con_sum-Interest(1)*Asset(1)-sum(Inc(1:Length)./(Prod_R_hat_l(1:Length)/Prod_R_hat_l(1))); 
    Transfer=Transfer_l1;
    Inc(1)=Transfer;
    
else 
    %% ------------------- Case 2: Not retired in l=1 ---------------------
    
    % before retirement, the non-linear equation to solve c1
%     Ratio_c_l(1)=1; % ratio of cl and c1
%     for l=2:Length
%         Ratio_c_l(l)=Prod_Beta_hat_l(l)*Prod_R_hat_l(l)/(Prod_Beta_hat_l(1)*Prod_R_hat_l(1));
%     end
    
    Con(1:Length)=Lagr^(-1)*Prod_Beta_hat_l(1:Length).*Prod_R_hat_l(1:Length);
%     Con2(2:Length)=Con(1)*Ratio_c_l(2:Length);
    Labor(1:Lw-1)=Lagr^phi*Prod_Beta_hat_l(1:Lw-1).^(-phi).*Prod_R_hat_l(1:Lw-1).^(-phi).*Wage(1:Lw-1).^phi;
    Labor(Lw:Length)=0;
%     Labor2(1:Lw-1)=Con(1)^(-sig)*Prod_Beta_hat_l(1:Lw-1).^(-phi).*Prod_R_hat_l(1:Lw-1).^(-phi).*Wage(1:Lw-1).^phi;
    Inc(1:Length)=Wage(1:Length).*Labor(1:Length);
    
    % lifetime Consumption
    Con_sum=sum(Con(1:Length)./(Prod_R_hat_l(1:Length)/Prod_R_hat_l(1)));
    % transfer is given in l=Lw
    Transfer_l1=Con_sum-Interest(1)*Asset(1)-sum(Inc(1:Length)./(Prod_R_hat_l(1:Length)/Prod_R_hat_l(1)));
    Transfer=Prod_R_hat_l(Lw)/Prod_R_hat_l(1)*Transfer_l1;
    Inc(Lw)=Transfer;
    
    
end % end of Lw<=1

for l=1:Length-1
    Asset(l+1)=1/(Surv(l+1)*(1+Growth))*(Interest(l)*Asset(l)+Inc(l)-Con(l));
end
l=Length;
Asset(l+1)=1/(1+Growth)*(Interest(l)*Asset(l)+Inc(l)-Con(l));



