
function [Con,Asset]=fun_c_a_j_fixlabor(Beta, Length, Interest, Inc, Surv, Asset_ini)

% fixed labor

% Length is the length of the period
% Interest is the interest rate sequence 
% Surv(j) is the survival rate to period j from period j-1
% the returned c and a are both adjusted by the growth
 
 

global sig g 

Growth=g;

% set Labor to 0 because it's inelastic
Labor=zeros(1,Length);


Asset(1)=Asset_ini;
% at every period i, solve the problem once
% to make sure Asset(Length+1)=0
% otherwise there will be huge errors when Length is large
for i=1:Length
    % 1 dollar in period i becomes Interest_prod(j) dollars in period j
    Interest_prod(i)=1;
    for j=i+1:Length
        Interest_prod(j)=prod(Interest(i+1:j));
    end
    % population 1 in period i becomes Surv_prod(j) in period j
    Surv_prod(i)=1;
    for j=i+1:Length
        Surv_prod(j)=prod(Surv(i+1:j));
    end
    
    % wealth discounted to period i
    Wealth_sum=Interest(i)*Asset(i);
    for j=i:Length
        Wealth_sum=Wealth_sum+Surv_prod(j)*(1+Growth)^(j-i)*Inc(j)/(Interest_prod(j));
    end
    
    Laborcost_sum=0;
    
    % Denominator, ratio of consumption discounted to period i
    Ratio_sum=0;
    for j=i:Length
        Ratio_sum=Ratio_sum+Surv_prod(j)*Beta^((j-i)/sig)*Interest_prod(j)^(1/sig-1);
    end
    % consumption

    Con(i)=(Wealth_sum-Laborcost_sum)/Ratio_sum;
    % savings
    if i<Length
        Asset(i+1)=1/(Surv(i+1)*(1+Growth))*(Interest(i)*Asset(i)+Inc(i)-Con(i));
    else
        Asset(i+1)=1/(1+Growth)*(Interest(i)*Asset(i)+Inc(i)-Con(i));
    end
end
 






