% solve an agent's life-cycle decisions
% sig==1, log utility
% notice: distinguish Jw and Lw

function [Con, Labor, Inc, Asset]=fun_c_a_j_kpr(Beta, Length, Interest, WagePension, Surv, Asset_ini)

Surv(1)=1; 
% Length is the length of the life left
% Lw is the peroid of retirement
% Interest is the interest rate sequence 
% Surv(j) is the survival rate to period j from period j-1
% the returned variables: c and a are both adjusted by the growth
 
global sig g J Jw nu phi

Growth=g;
Asset(1)=Asset_ini;

% adjust discount and interest rate by the survival rate: Beta_hat and R_hat
Prod_Beta_hat_l(1)=1;
Prod_R_hat_l(1)=1;
for l=2:Length
    Beta_hat_l(l)=Beta*Surv(l);
    Prod_Beta_hat_l(l)=Prod_Beta_hat_l(l-1)*Beta_hat_l(l);
    
    R_hat_l(l)=Interest(l)/(Surv(l)*(1+Growth));
    Prod_R_hat_l(l)=Prod_R_hat_l(l-1)*R_hat_l(l);
end
Lw=Length-(J-Jw);
% retire period Lw

if Lw<=1 % already retired
    %% -------------------- Case 1: Retired Already ----------------------
    Ratio_c_l(1)=1; % ratio of cl and c1
    for l=2:Length
        Ratio_c_l(l)=Prod_Beta_hat_l(l)*Prod_R_hat_l(l);
    end
    % denominator, basically sum of cj/c1/prod_R(j)
    Denom_c1=sum(Ratio_c_l(1:Length)./Prod_R_hat_l(1:Length));
    
    % lifetime wealth
    Wealth_sum=Interest(1)*Asset(1)+sum(WagePension(1:Length)./Prod_R_hat_l(1:Length));
    
    Con(1)=Wealth_sum/Denom_c1;
    
    Con(2:Length)=Con(1)*Ratio_c_l(2:Length);
    Labor(1:Length)=0;
    Inc(1:Length)=WagePension(1:Length);
    
else 
    %% ------------------- Case 2: Not retired in l=1 ---------------------
    
    % before retirement, the non-linear equation to solve c1
    Coeff_c1(1)=sum(Prod_Beta_hat_l(1:Length));
    Power_c1(1)=1;
    Coeff_c1(2)=-sum(Prod_Beta_hat_l(1:Lw-1).^(-phi).*Prod_R_hat_l(1:Lw-1).^(-phi-1).*WagePension(1:Lw-1).^(1+phi)*nu^(-phi));
    Power_c1(2)=-phi;
    
    RHS=Interest(1)*Asset(1)+sum(WagePension(Lw:Length)./Prod_R_hat_l(Lw:Length));
    
    % initial guess, suppose labor supply=1
    Wealth_sum=Interest(1)*Asset(1)+sum(WagePension(1:Length)./Prod_R_hat_l(1:Length));
    C1_ini=Wealth_sum/Coeff_c1(1); % solution for log utility, power_c_l(l)==1 so we have analytical solution

    % what if C1_ini<0?
    if C1_ini<0
        C1_ini=0.1;
    end
    
    % solve for the first period consumption
    fun_err_c1=@(C1) fun_err_poly(C1,2,Coeff_c1,Power_c1,RHS);
    options = optimset('Display','off');
    Con(1)=fsolve(fun_err_c1,C1_ini,options);

    % given the first period consumption, get the later consumptions with
    % Euler Equation
    Con(2:Length)=(Con(1)*Prod_Beta_hat_l(2:Length).*Prod_R_hat_l(2:Length));
    % the labor supply and income can be also backed out by the FOCs
    Labor(1:Lw-1)=(WagePension(1:Lw-1)./Con(1:Lw-1)/nu).^phi;
    Labor(Lw:Length)=0;
    Inc(1:Lw-1)=WagePension(1:Lw-1).*Labor(1:Lw-1);
    Inc(Lw:Length)=WagePension(Lw:Length);
    
end % end of Lw<=1

% given income and consumption, we can calculate the asset over the life
% cycle
for l=1:Length-1
    Asset(l+1)=1/(Surv(l+1)*(1+Growth))*(Interest(l)*Asset(l)+Inc(l)-Con(l));
end
l=Length;
Asset(l+1)=1/(1+Growth)*(Interest(l)*Asset(l)+Inc(l)-Con(l));
