% Calculate the General Equilibrium Model from 2000 on, 
% by loading the parameters from the calibration, which is done in
% main_GE2000_calibration.m


clear;
clear global;
close all;
tic

%% ----------------- 0. Model Setup ---------------------------------m

% global variables
global_claim;  

% set some useful indexes to control how to solve the model
index_setting;

% the names of data and figures
names_data_fig; 

% model parameters that are constant over time
parameters_basic;

% set the parameters (e.g. population, death rate) if the economy starts from 2000
parameters_t_2000; 

% parameters for the pension system
pensionsystem_2000; 

% rural model
parameters_rural;
pensionsystem_rural_2000;

% moments that we want to match or get from the data, e.g., foreign surplus
parameters_data_2000;




%% -------------- 1. Rural model --------------

solve_Hr_update; % update Hr until it converges to solve the rural model

pension_debt_coh_rural;



%% ---------------- 2. Solve the Urban Model  --------------
t_reform=2013-year_start+1; % pension reform in year 2013, year_start is defined in parameters_t_yyyy.m

name_exp='benchmark'; % this is the benchmark experiment - draconian reform in 2013


% set the tolerance level of convergece to the "accurate" level: 1e-4
tol_setting_accurate;


% solve the equilibrium
% since we don't know the entrepreneur asset in year 2000, which is an
% endogenous varialbe, we need to update until it converges
solve_ae1_update;




%% -------------- 3. Benchmark Reform Experiment ------------

experiment_benchmark;

save(name_data_exp);





%% ------------- 4. More Figures and Statistics ----------------

index_fig=0;
if index_fig==1
    figures_GDP;
    figures_sz;
end

save(name_data_exp)


