% parameters over time, related to the starting year 2000



%% -------------- Year -------------------
year_data=2000; % data starts from year 2000
year_start=2000; % our general equilibrium model starts from year 2000
% initial assets of workers and entrepreneurs start from 1995
year_pre_wr_start=1995; 
year_pre_w_start=year_pre_wr_start; 
year_pre_e_start=year_pre_wr_start;

% period numbers for year 2000, 2010, and so on
t_2000=2000-year_start+1;
t_2010=2010-year_start+1;
t_2013=2013-year_start+1;
t_2030=2030-year_start+1;
t_2031=2031-year_start+1;
t_2038=2038-year_start+1;
t_2040=2040-year_start+1;
t_2050=2050-year_start+1; 
t_2100=2100-year_start+1; 

t_dyn=500;  % 500 periods of dynamics
t_end=t_dyn+100; % from t_dyn to t_end, all variables are in the steady state


%% --------- Demography ------------
% load demogarphic data
load('../Demography2_PopulationProjection/data_demography')
age_start=22; % agents enter market at age 22
age_end=100; % last period of life
J=age_end-age_start+1; % agents live for J periods
Jw=60-age_start+1; % workers retire at age 60
Je=47-age_start+1;  % entrepreneurs start to own E firms at age 47, before that they work as managers



%% ------- Transition of Economic Parameters --------
% in this section, we set the variables and parameters that change over
% time

% beta may change for later cohorts
% in the baseline model, we assume that it doesn't change at all
coh_betachange=J+t_2013-1;
for coh=1:coh_betachange-1
    bet_e_coh(coh)=bet_e_ini;
    bet_w_coh(coh)=bet_w_ini;
end
for coh=coh_betachange:J+t_dyn-1
    bet_e_coh(coh)=bet_e_ss;
    bet_w_coh(coh)=bet_w_ss;
end

% parameters for E firm technologies
psai_ini=0.26714; % the share of the revenue accruing to managers
psai_ss=psai_ini; % steady state level equals the initial level, in the baseline model
eta_ini=0.43; % credit constraint of E firms
eta_ss=eta_ini; % steady state level equals the initial level, in the baseline model
chi_ini=2.729; % ratio of E firm and F firm TFP
chi_ss=chi_ini; % steady state level

% in the baseline scenario, they are constant over time
for t=1:t_2050
    psai_t(t)=psai_ini;
    eta_t(t)=eta_ini;
end
for t=t_2050+1:t_2100
    psai_t(t)=psai_ini+(psai_ss-psai_ini)/(t_2100-t_2050)*(t-t_2050);
    eta_t(t)=eta_ss; % no borrowing constaint
end
for t=t_2100+1:t_end
    psai_t(t)=psai_ss;
    eta_t(t)=eta_ss; % no borrowing constaint
end
chi_t=chi_ini*ones(1,t_end);


% F firm TFP over time
Z_ini=1; 
Z_t(1)=Z_ini;

load(name_data_load,'g_extra_ini','T_g_extra')  % TFP growth rate, data saved from the calibration
% high initial TFP growth until 2010
for t=2:t_2010
    g_extra_t(t)=g_extra_ini;
end
% no extra growth after period T_g_extra
g_extra_t(T_g_extra)=0; 
% TFP growth rate slows down from 2010 to period T_g_extra
for t=t_2010+1:T_g_extra
    g_extra_t(t)=g_extra_t(t_2010)+(g_extra_t(T_g_extra)-g_extra_t(t_2010))/(T_g_extra-t_2010)*(t-t_2010);
end
for t=T_g_extra+1:t_end
    g_extra_t(t)=0;
end
for t=2:t_end
    Z_t(t)=Z_t(t-1)*(1+g_extra_t(t));
end
Z_ss=Z_t(t_end);


%% --------------------- More about the Demography ----------------
% load motality data
load('../Demography2_PopulationProjection/data_mort2')
% lam_jt(j,t) is the survival rate from age j-1 to age j in period t in the
% urban area
% lamr_jt is the counterpart in the rural area
for t=1:t_end
lam_jt(1,t)=1; % no need for survival rate to the first period of life
lam_jt(2:J,t)=1-mort_u_jt(age_start+1:age_start+J-1,t)/1000; % survivial rate from age j-1 to age j
lamr_jt(1,t)=1;
lamr_jt(2:J,t)=1-mort_r_jt(age_start+1:age_start+J-1,t)/1000;
end
lam_jss=lam_jt(1:J,t_end);

% population 
% N_t(j,t) is the population of age j in period t
index_N_t_data=1; % 1, load from data; 0, some test on the data
index_N_t_mig=1; % 1, migration; 0, without migration
if index_N_t_data==0
    pop_simu_simple;
else % load from data
    if index_N_t_mig==1 % data with migration
        for t=1:t_dyn
            N_t(1:J,t)=N_t_mig(t,1:J);
            Nr_t(1:J,t)=Nr_t_mig(t,1:J);
        end
    else
        for t=1:t_dyn
            N_t(1:J,t)=N_t_no_mig(t,1:J);
            Nr_t(1:J,t)=Nr_t_no_mig(t,1:J);
        end
    end
end
N_total_t(1)=sum(N_t(1:J,1));
for t=2:t_dyn
    N_total_t(t)=sum(N_t(1:J,t));
    N_growth_t(t)=N_total_t(t)/N_total_t(t-1)-1;
end 

% steady state population (normalized to 1) given the survival rate
N_con=fun_N_con(lam_jss);
Nw_t=N_t; % all the people are workers
Ne_t=N_con'*ones(1,t_dyn)*0.05*sum(N_t(:,1))/sum(N_con); % entrepreneur population is very very small, but we still assign them some numbers

% 60% covered by pension
Perc_w_p_ini=0.6;
Perc_w_p_ss=Perc_w_p_ini; % in the baseline model, no change to the coverage rate

% pension coverage rates for the existing cohorts in 2000 is Perc_w_p_ini
for j=1:J
    coh=J-j+1;
    Perc_w_p_coh(coh)=Perc_w_p_ini;
end
% pension coverage rates for cohorts born before 2013 is Perc_w_p_ini
for t=2:t_2013-1
    coh=J+t-1;
    Perc_w_p_coh(coh)=Perc_w_p_ini;
end
% pension coverage rate for cohorts born between 2013 and 2050 steadily
% increase to Perc_w_p_ss
for t=t_2013:t_2050 % 2052
    coh=J+t-1;
    Perc_w_p_coh(coh)=Perc_w_p_ini+(t-(t_2013-1))/(t_2050-(t_2013-1))*(Perc_w_p_ss-Perc_w_p_ini);
end
% after 2052, Perc_w_p_ss
for t=t_2050+1:t_dyn
    coh=J+t-1;
    Perc_w_p_coh(coh)=Perc_w_p_ss;
end
% percentage of population not covered
Perc_w_np_coh=1-Perc_w_p_coh;


% given the population dynamics, we can calculate some statistics of the
% population
for t=1:t_dyn
    Nw_total_t(t)=sum(Nw_t(1:J,t)); % total worker population in each year
   
    Ne_labor_t(t)=sum(Ne_t(1:Je-1,t)); % entrepreneurs working as managers
    Nw_labor_t(t)=sum(Nw_t(1:Jw-1,t)); % workers before retirement
   
    Ne_retire_t(t)=sum(Ne_t(Je:J,t)); % entreprenerus owning E firms
    Nw_retire_t(t)=sum(Nw_t(Jw:J,t)); % retirees

    % rural population
    Nr_total_t(t)=sum(Nr_t(1:J,t));
    Nr_labor_t(t)=sum(Nr_t(1:Jw-1,t));
    Nr_retire_t(t)=sum(Nr_t(Jw:J,t));
end


for t=1:t_dyn
    for j=1:J
        % for different age
        Nw_p_t(j,t)=Nw_t(j,t)*Perc_w_p_coh(J-j+t);
        Nw_np_t(j,t)=Nw_t(j,t)*Perc_w_np_coh(J-j+t);
    end
    Nw_labor_p_t(t)=sum(Nw_p_t(1:Jw-1,t));
    Nw_labor_np_t(t)=sum(Nw_np_t(1:Jw-1,t));
    Nw_retire_p_t(t)=sum(Nw_p_t(Jw:J,t));
    Nw_retire_np_t(t)=sum(Nw_np_t(Jw:J,t));
end

Nur_t=N_t+Nr_t; % rural and urban population dynamics
Nur_total_t(1:t_dyn)=Nw_total_t(1:t_dyn)+Nr_total_t(1:t_dyn); % total rural and urban population in each year
Nur_labor_t(1:t_dyn)=Nw_labor_t(1:t_dyn)+Nr_labor_t(1:t_dyn); % rural and urban workers before retirement

% N_ss is the steady state distribution (normalized to 1), diffrent from sum(N_t(t)))
% the population growth in the baseline model converges to 0 in the long
% run
N_growth_ss=sum(N_t(1:J,t_dyn))/sum(N_t(1:J,t_dyn-1))-1; % should be very close to 0
scale_N_ss=sum(N_t(1:J,t_dyn)); % scale the steady state population down such that sum(N_ss)=1
N_ss=N_t(1:J,t_dyn)'/scale_N_ss;
Nw_ss=N_ss;
Ne_ss=Ne_t(1:J,t_dyn)'/scale_N_ss; % also need to scale down the entrepreneurs

Ne_labor_ss=sum(Ne_ss(1:Je-1)); % percentage of entrepreneurs working as managers
Nw_labor_ss=sum(Nw_ss(1:Jw-1)); % percentage of workers before retirement

Ne_retire_ss=sum(Ne_ss(Je:J)); % percentage of entrepreneurs owning E firms
Nw_retire_ss=sum(Nw_ss(Jw:J)); % percentage of workers after retirement

% workers covered by the pension system
Nw_p_ss=Nw_ss*Perc_w_p_ss; 
Nw_np_ss=Nw_ss*(1-Perc_w_p_ss);
Nw_labor_p_ss=Nw_labor_ss*Perc_w_p_ss;
Nw_labor_np_ss=Nw_labor_ss*(1-Perc_w_p_ss);
Nw_retire_p_ss=Nw_retire_ss*Perc_w_p_ss;
Nw_retire_np_ss=Nw_retire_ss*(1-Perc_w_p_ss);


% N_t shows only the population above age 22 
% pop_t keeps all the population, including babies
% divide pop by 1e6, so it's about 1200 in 2000
pop_t=pop_u_t_mig/1e6; % pop_u_t_mig is the urban population, read from the population simulation
pop_r_t=pop_r_t_mig/1e6;
pop_ur_t=pop_t+pop_r_t;
pop_total_t=sum(pop_t); % urban
pop_labor_t=sum(pop_t(age_ini+1:age_ini+Jw-1,:));
pop_r_total_t=sum(pop_r_t); % rural
pop_r_labor_t=sum(pop_r_t(age_ini+1:age_ini+Jw-1,:));
pop_ur_total_t=sum(pop_ur_t);
pop_ur_labor_t=sum(pop_ur_t(age_ini+1:age_ini+Jw-1,:));



%% ----------- Productivity Profile -----------------

% productivity age profile: 0.5% increase per year before retirement
step_prod=0.005;
for j=1:Jw-1
    prod_j(j)=1+step_prod*(j-1);
end

% productivity cohort profile: depending on education
load data_edu_coh edu_coh  % edu_coh(2,:) saves the education from the cohort born in 1900, which is the first cohort in our model
n_coh=J-1+t_dyn;
% use 9 years education as a benchmark
for coh=1:n_coh
    prod_coh(coh)=1.1^(edu_coh(2,coh)-9); % 1 year more education means 10% higher productivity
end

% include education into productivity
for t=1:t_dyn
    for j=1:Jw-1
        coh_jt(j,t)=J-j+t;
        prod_jt(j,t)=prod_j(j)*prod_coh(coh_jt(j,t));
    end
end

prod_jss(1:Jw-1)=prod_jt(1:Jw-1,t_dyn);


% above we calculate the relative productivities across cohorts and ages
% now we set the absolute value of the productivities 

% we pick the cohort age 45 in 2000 as the cohort with productivity "1"
% with log utility, it doesn't matter. Should just be scale effect

scale_prod=1/prod_jt(24,1);
prod_jt=prod_jt*scale_prod;
prod_jss=prod_jss*scale_prod;
prod_coh=prod_coh*scale_prod;



%% ----- iceberg cost xi_t ------

% xi_ini=0.07;
xi_ini=0.062; % to match 9.3% aggregate capital return
t_xi=25; % at t_xi the cost coverges to 0
for t=1:t_xi
    xi_t(t)=xi_ini+(xi_ss-xi_ini)*((t-1)/(t_xi-1))^1; % xi_t linear
end
xi_t(t_xi+1:t_dyn)=xi_ss;
rl_t=(1+r)./(1-xi_t)-1;


%% ------- variables before 2000 ---------
% our general equilibrium starts from 2000, but we still calculate the
% workers problems before that, to provide the lifetime utility for those
% cohorts who lived for years before 2000

year_pre_start=2000-J+1; % the year the oldest cohort in 2000 entered the market
T_pre=year_start-1-year_pre_start+1;

% survival rate, assumed to be the same as 2000
% j for age, t for period, counting from year_pre_start
% coh for cohort, the oldest cohort in 2000 is cohort 1
% rural
lamr_pre_jt(1:J,1:T_pre)=lamr_jt(1:J,1)*ones(1,T_pre);
lamr_pre_jt(1:J,T_pre+1:T_pre+t_end)=lamr_jt(1:J,1:t_end);

for coh=1:J+t_dyn
    Length=J;
    for len=1:Length
        lamr_jcoh(len,coh)=lamr_pre_jt(len,coh+len-1);
    end  
end
% urban
lam_pre_jt(1:J,1:T_pre)=lam_jt(1:J,1)*ones(1,T_pre);
lam_pre_jt(1:J,T_pre+1:T_pre+t_end)=lam_jt(1:J,1:t_end);
for coh=1:J+t_dyn
    Length=J;
    for len=1:Length
        lam_jcoh(len,coh)=lam_pre_jt(len,coh+len-1);
    end  
end

