% pension base is cohort-year or age-year specific
% calculate the tax, pension payment, and debt
% in the ramsey problem, tax is cohort specific 


%% --------------------- 1. tax ----------------------
% translate cohort specific tax to tau_w_jt

for t=1:t_dyn
    tax_total_t(t)=tau_e_t(t)*me_t(t)*Ne_labor_t(t)+...
        sum(tau_w_jt(1:Jw-1,t).*(ones(Jw-1,1)*w_t(t)).*prod_jt(1:Jw-1,t).*h_p_t(1:Jw-1,t).*Nw_p_t(1:Jw-1,t));
%     tax_total_t2(t)=tau_e_t(t)*me_t(t)*Ne_labor_t(t)+...
%         sum(tax_w_jt(1:Jw-1,t).*Nw_p_t(1:Jw-1,t));
end

% steady state value, use t_dyn and multiply by 1+N_growth_ss, and grows at
% the rate of 1+N_growth_ss
tax_total_ss=tax_total_t(t_dyn)*(1+N_growth_ss);

% life time tax (may need to add the steady state continuation value)
tax_lifetime=tax_total_t(1); 
for t=2:t_dyn
    tax_lifetime=tax_lifetime+tax_total_t(t)*((1+g)/(1+r))^(t-1);
end
% continuation value from steady state
tax_lifetime=tax_lifetime+tax_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));



%% ------------------- 2. Pension Payment -----------------


% -------------------- 2.1 If No Need to Clear Debt ------------------
% use the replace_w defined in pensionsystem_xxx.m 
if index_debtclear==0
    % replace_w_jt should be given before 
%     replace_w_coh(J+t_reform-1:t_dyn)=replace_w_coh2; % born after t_reform
%     module_replace_w_coh2jt;
    for t=1:t_dyn
            pension_total_t(t)=sum(Nw_p_t(Jw:J,t).*pw_jt(Jw:J,t));
    end
    pension_total_ss=pension_total_t(t_dyn)*(1+N_growth_ss); % and then grows at the rate of 1+N_growth_ss
    pension_lifetime=0;
    for t=1:t_dyn
        pension_lifetime=pension_lifetime+pension_total_t(t)*((1+g)/(1+r))^(t-1);
    end
    pension_lifetime=pension_lifetime+pension_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
    gov_debt_lifetime=pension_debt_lifetime_r-(1+r)*Ag_transfer_real_value_ini+(1+r)*gov_debt_t(1)+pension_lifetime-tax_lifetime;
end

%% --------------------- 2.5 Another way of calculating government debt, using net_transfer ----------------------

    % replace_w_jt should be given before 
%     replace_w_coh(J+t_reform-1:t_dyn)=replace_w_coh2; % born after t_reform
%     module_replace_w_coh2jt;
% %     for t=1:t_dyn
% %             net_transfer_p_total_t(t)=sum(Nw_p_t(1:J,t).*net_transfer_p_t(1:J,t));
% %     end
% %     net_transfer_p_total_ss=net_transfer_p_total_t(t_dyn)*(1+N_growth_ss); % and then grows at the rate of 1+N_growth_ss
% %     net_transfer_p_lifetime=0;
% %     for t=1:t_dyn
% %         net_transfer_p_lifetime=net_transfer_p_lifetime+net_transfer_p_total_t(t)*((1+g)/(1+r))^(t-1);
% %     end
% %     net_transfer_p_lifetime=net_transfer_p_lifetime+net_transfer_p_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
% %     
%     
%     gov_debt_lifetime2=pension_debt_lifetime_r-(1+r)*Ag_transfer_value_ini+(1+r)*gov_debt_t(1)+net_transfer_p_lifetime;
    
%     gov_debt_lifetime=gov_debt_lifetime2;



%% --------------------- 3. Government Debt, including rural and urban -------------------
% gov_debt_t(1) is defined in initialstate.m

for t=1:t_transfer-2
    gov_debt_t(t+1)=((1+r)*gov_debt_t(t)+pension_total_t(t)-tax_total_t(t)+pension_total_r_t(t)-tax_total_r_t(t))/(1+g);
end
% get transfer in period t_transfer
t=t_transfer-1;
gov_debt_t(t+1)=-Ag_transfer_real+((1+r)*gov_debt_t(t)+pension_total_t(t)-tax_total_t(t)+pension_total_r_t(t)-tax_total_r_t(t))/(1+g);
for t=t_transfer:t_dyn
    gov_debt_t(t+1)=((1+r)*gov_debt_t(t)+pension_total_t(t)-tax_total_t(t)+pension_total_r_t(t)-tax_total_r_t(t))/(1+g);
end

for t=t_dyn+1:1000
    gov_debt_t(t+1)=((1+r)*gov_debt_t(t)+(pension_total_ss-tax_total_ss)*(1+N_growth_ss)^(t-t_dyn-1)+(pension_total_r_ss-tax_total_r_ss)*(1+N_growth_ss)^(t-t_dyn-1))/(1+g);
end


%% ----------- 4. Calculate the Total Consumption, useful for the adjustment of Lagr --------

for t=1:t_dyn
    cw_p_total_t(t)=sum(Nw_p_t(1:J,t).*cw_p_t(1:J,t));
    yw_p_total_t(t)=sum(Nw_p_t(1:J,t).*yw_p_t(1:J,t));
end
cw_p_total_ss=cw_p_total_t(t_dyn)*(1+N_growth_ss);
yw_p_total_ss=yw_p_total_t(t_dyn)*(1+N_growth_ss);

cw_p_lifetime=0;
yw_p_lifetime=0;
for t=1:t_dyn
    cw_p_lifetime=cw_p_lifetime+cw_p_total_t(t)*((1+g)/(1+r))^(t-1);
    yw_p_lifetime=yw_p_lifetime+yw_p_total_t(t)*((1+g)/(1+r))^(t-1);
end

cw_p_lifetime=cw_p_lifetime+cw_p_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));
yw_p_lifetime=yw_p_lifetime+yw_p_total_ss*((1+g)/(1+r))^t_dyn/(1-(1+N_growth_ss)*(1+g)/(1+r));

error_lifetime=(1+r)*sum(Nw_p_t(1:J,1).*aw_p_t(1:J,1))+yw_p_lifetime-cw_p_lifetime-(1+r)*gov_debt_t(1);



