% What happens before 2000, which is the year that the transition dynamics
% starts?
% agents have some wealth in 1995, and they optimally save, which generates
% the 2000 wealth

% pension for the working population is 0
pw_jt(1:Jw-1,1:t_dyn)=0;

% helpful for finding the equilibrium variables faster
w_t=real(w_t);
p_base_t=real(p_base_t);
me_t=real(me_t);
RE_t=real(RE_t);



%% ---------------- Wage and Management Income between 1995 and 2000 --------------
% after 2000, the growth rates of wage and manager income can be computed
for t=1:50
    growth_w_t(t+1)=w_t(t+1)/w_t(t)-1;
    growth_p_base_t(t+1)=p_base_t(t+1)/p_base_t(t)-1; % growth of pension base
    growth_me_t(t+1)=me_t(t+1)/me_t(t)-1;
    growth_RE_t(t+1)=RE_t(t+1)/RE_t(t)-1; % growth of entrepreneur asset return
end

% assume that before 2000, the growth rate of these variables are
% the same as the first two years after 2000
growth_w_pre=mean(growth_w_t(2:3));
growth_p_base_pre=mean(growth_p_base_t(2:3));
growth_me_pre=mean(growth_me_t(2:3));
growth_RE_pre=mean(growth_RE_t(2:3));

% before 1980, the growth is 0
growth_p_base_pre_t(1:t_pre_1980-1)=-g;
growth_p_base_pre_t(t_pre_1980:T_pre+1)=growth_p_base_pre;
growth_w_pre_t(1:t_pre_1980-1)=-g;
growth_w_pre_t(t_pre_1980:T_pre+1)=growth_w_pre;


% recall that T_pre is 1999
% now we can backout the variables before 2000, using the growth rates we
% assumed above
w_pre_t(T_pre+1)=w_t(1);
p_base_pre_t(T_pre+1)=p_base_t(1);
for t=T_pre:-1:1
    w_pre_t(t)=w_pre_t(t+1)/(1+growth_w_pre_t(t+1));
    p_base_pre_t(t)=p_base_pre_t(t+1)/(1+growth_p_base_pre_t(t+1));
    me_pre_t(t)=me_t(1)/((1+growth_me_pre)^(T_pre-t+1));
    RE_pre_t(t)=RE_t(1)/((1+growth_RE_pre)^(T_pre-t+1));
end




%% ----------------- To get the wealth in 2000, we solve agents' problem from 1995 ------------------

% prepare the variables from 1922
w_pre_t(T_pre+1:T_pre+J)=w_t(1:J);
p_base_pre_t(T_pre+1:T_pre+J)=p_base_t(1:J);
me_pre_t(T_pre+1:T_pre+J)=me_t(1:J); % manager income
RE_pre_t(T_pre+1:T_pre+J)=RE_t(1:J); % entrepreneur asset return

pe_pre_t(1:T_pre+J)=0; % entrepreneur pension

tau_w_pre_t(1:T_pre+J)=tau_w_t(1);
tau_e_pre_t(1:T_pre+J)=tau_e_t(1);



% ------------- Workers

% age-year specific pension base
t=1;
for j=Jw:J
        t_retire=t-j+Jw;
        if t_retire<=1 % retired before 1922, actually those cohorts won't matter as they died before 2000
            p_base_pre_jt(j,t)=p_base_pre_t(1); % can't go further
        else
            % the pension base is average wage before retirement, indexed by the average wage growth
            p_base_pre_jt(j,t)=(1-indexation)*p_base_pre_t(t_retire-1)/(1+g)^(j-Jw+1)+indexation*p_base_pre_t(t-1)/(1+g); 
        end
end
for t=2:T_pre+J
    for j=Jw:J
        t_retire=t-j+Jw;
        if t_retire<=1
            p_base_pre_jt(j,t)=(1-indexation)*p_base_pre_t(1)/(1+g)^(t-1)+indexation*p_base_pre_t(t-1)/(1+g); % can not track back to earlier, just use the growth rate
        else
            p_base_pre_jt(j,t)=(1-indexation)*p_base_pre_t(t_retire-1)/(1+g)^(j-Jw+1)+indexation*p_base_pre_t(t-1)/(1+g); % from last year
        end
    end
end

% age-year specific replacement rate
for t=1:T_pre 
    coh=J+t-1+year_pre_start-year_start;
    Length=J;
    for l=1:Length
        replace_w_pre_jt(l,t+l-1)=(j+l-1>=Jw)*replace_w_coh(coh);
    end
end
replace_w_pre_jt(Jw:J,T_pre+1:T_pre+J)=replace_w_jt(Jw:J,1:J);
replace_w_pre_jt(1:Jw-1,1:T_pre+J)=0;

% age-year specific pension income
pw_pre_jt(Jw:J,1:T_pre+J)=p_base_pre_jt(Jw:J,1:T_pre+J).*replace_w_pre_jt(Jw:J,1:T_pre+J);



%----------------  workers with pension
% wage and pension 
for t=1:T_pre+J
    for j=1:Jw-1
        wagepension_p_pre_t(j,t)=(1-tau_w_pre_t(t))*w_pre_t(t)*prod_pre_jt(j,t);
    end
    for j=Jw:J
        wagepension_p_pre_t(j,t)=pw_pre_jt(j,t);
    end
end


% solve workers' problem from 1995
% before 1995 they supply 1 unit of labor and consume all the income
h_adjust=1; % labor supply before 1995 is assumed to be 1
t=t_pre_w_start;
aw_p_pre_t(1:t_pre_w_start,t)=aw_t_pre_w_start(1:t_pre_w_start); 
for j=1:J+(t-T_pre-1) % j is the age in the starting period, the first cohort's age is J+(t-T_pre-1)
    Length=J-j+1;
    coh=1+(t-T_pre-1)+(J-j); % age J in t=T_pre+1 is cohort 1
    Interest(1:Length)=1+r;
    for l=1:Length
        WagePension(l)=wagepension_p_pre_t(j+l-1,t+l-1);
    end
    Surv(1:Length)=lam_jcoh(j:j+Length-1,coh);
    Asset_ini=aw_p_pre_t(j,t);
    Beta=bet_w_coh(coh);
    [cw_p_j,h_p_j,yw_p_j,aw_p_j]=fun_c_a_j_kpr(Beta,Length, Interest, WagePension, Surv, Asset_ini);
    
    % put cw_j, aw_j into cw_t, aw_t, cw_coh
    for l=1:Length
        cw_p_pre_t(j+l-1,t+l-1)=cw_p_j(l);
        h_p_pre_t(j+l-1,t+l-1)=h_p_j(l);
        yw_p_pre_t(j+l-1,t+l-1)=yw_p_j(l);
        aw_p_pre_t(j+l-1,t+l-1)=aw_p_j(l);
        
        cw_p_coh(j+l-1,coh)=cw_p_j(l);  
        h_p_coh(j+l-1,coh)=h_p_j(l);  
        yw_p_coh(j+l-1,coh)=yw_p_j(l);  
        aw_p_coh(j+l-1,coh)=aw_p_j(l);  


        uw_p_coh(j+l-1,coh)=fun_u_kpr(cw_p_coh(j+l-1,coh),h_p_coh(j+l-1,coh));
        
        % before 1995, her labor supply, income and consumption
        for len=1:j-1
            if len<Jw
                h_p_coh(len,coh)=h_adjust;
                yw_p_coh(len,coh)=wagepension_p_pre_t(len,t+len-j)*h_adjust;
                cw_p_coh(len,coh)=yw_p_coh(len,coh);
                yw_p_pre_t(len,t+len-j)=yw_p_coh(len,coh);
                cw_p_pre_t(len,t+len-j)=cw_p_coh(len,coh);
            else
                h_p_coh(len,coh)=0;
                yw_p_coh(len,coh)=wagepension_p_pre_t(len,t+len-j);
                cw_p_coh(len,coh)=yw_p_coh(len,coh);
                yw_p_pre_t(len,t+len-j)=yw_p_coh(len,coh);
                cw_p_pre_t(len,t+len-j)=cw_p_coh(len,coh);
            end
            
            uw_p_coh(len,coh)=fun_u_kpr(cw_p_coh(len,coh),h_p_coh(len,coh));
            
        end
    
    end
end


% those born in period t>t_pre_w_start
j=1;  % start with age 1
for t=t_pre_w_start+1:T_pre
    Length=J;
    coh=J+(t-T_pre-1); % born in T_pre+1 is cohort J
    Interest(1:Length)=1+r;
    for l=1:Length
        WagePension(l)=wagepension_p_pre_t(l,t+l-1); % year l, age depends positively on j
    end
    Surv(1:Length)=lam_jcoh(1:Length,coh);
    Asset_ini=0;
    Beta=bet_w_coh(coh);
    [cw_p_j,h_p_j,yw_p_j,aw_p_j]=fun_c_a_j_kpr(Beta,Length, Interest, WagePension, Surv, Asset_ini);
    % put cw_j, aw_j into cw_t, aw_t
    uw_p_sum_coh(coh)=0;
    for l=1:Length
        cw_p_pre_t(l,t+l-1)=cw_p_j(l);
        h_p_pre_t(l,t+l-1)=h_p_j(l);
        yw_p_pre_t(l,t+l-1)=yw_p_j(l);
        aw_p_pre_t(l,t+l-1)=aw_p_j(l);
        
        cw_p_coh(l,coh)=cw_p_j(l); 
        h_p_coh(l,coh)=h_p_j(l); 
        yw_p_coh(l,coh)=yw_p_j(l);
        aw_p_coh(l,coh)=aw_p_j(l); 

        uw_p_coh(l,coh)=fun_u_kpr(cw_p_coh(l,coh),h_p_coh(l,coh));
        
    end
end
aw_p_pre_t(1,T_pre+1)=0;
aw_p_t(1:J,1)=aw_p_pre_t(1:J,T_pre+1);



% ---------------  Workers without Pension

for t=1:T_pre+J
    for j=1:Jw-1
        wagepension_np_pre_t(j,t)=w_pre_t(t)*prod_pre_jt(j,t);
    end
    for j=Jw:J
        wagepension_np_pre_t(j,t)=0;
    end
end

t=t_pre_w_start;
aw_np_pre_t(1:t_pre_w_start,t)=aw_t_pre_w_start(1:t_pre_w_start);
for j=1:J+(t-T_pre-1) % j is the age in the starting period, the first cohort's age is J+(t-T_pre-1)
    Length=J-j+1;
    coh=1+(t-T_pre-1)+(J-j); % age J in t=T_pre+1 is cohort 1
    Interest(1:Length)=1+r;
    for l=1:Length
        WagePension(l)=wagepension_np_pre_t(j+l-1,t+l-1); % year l, age depends positively on j
    end
    Surv(1:Length)=lam_jcoh(j:j+Length-1,coh);
    Asset_ini=aw_np_pre_t(j,t);
    Beta=bet_w_coh(coh);
    [cw_np_j,h_np_j,yw_np_j,aw_np_j]=fun_c_a_j_kpr(Beta,Length, Interest, WagePension, Surv, Asset_ini);
    
    % put cw_j, aw_j into cw_t, aw_t, cw_coh
    % l means the lth period 
    for l=1:Length
        cw_np_pre_t(j+l-1,t+l-1)=cw_np_j(l);
        h_np_pre_t(j+l-1,t+l-1)=h_np_j(l);
        yw_np_pre_t(j+l-1,t+l-1)=yw_np_j(l);
        aw_np_pre_t(j+l-1,t+l-1)=aw_np_j(l);
        
        cw_np_coh(j+l-1,coh)=cw_np_j(l);  
        h_np_coh(j+l-1,coh)=h_np_j(l);  
        yw_np_coh(j+l-1,coh)=yw_np_j(l);  
        aw_np_coh(j+l-1,coh)=aw_np_j(l);  

        uw_np_coh(j+l-1,coh)=fun_u_kpr(cw_np_coh(j+l-1,coh),h_np_coh(j+l-1,coh));
        
    end
    
        % life before t_w_start
        for len=1:j-1
            if len<Jw
                h_np_coh(len,coh)=h_adjust;
                yw_np_coh(len,coh)=wagepension_np_pre_t(len,t+len-j)*h_adjust;
                cw_np_coh(len,coh)=yw_np_coh(len,coh);
                yw_np_pre_t(len,t+len-j)=yw_np_coh(len,coh);
                cw_np_pre_t(len,t+len-j)=cw_np_coh(len,coh);
            else
                h_np_coh(len,coh)=0;
                yw_np_coh(len,coh)=wagepension_np_pre_t(len,t+len-j);
                cw_np_coh(len,coh)=yw_np_coh(len,coh);
                yw_np_pre_t(len,t+len-j)=yw_np_coh(len,coh);
                cw_np_pre_t(len,t+len-j)=cw_np_coh(len,coh);
            end
            uw_np_coh(len,coh)=fun_u_kpr(cw_np_coh(len,coh),h_np_coh(len,coh));
            

        end
end


% those born in period t>t_pre_w_start
j=1;  % start with age 1
for t=t_pre_w_start+1:T_pre
    Length=J;
    coh=J+(t-T_pre-1); % born in T_pre+1 is cohort J
    Interest(1:Length)=1+r;
    for l=1:Length
        WagePension(l)=wagepension_np_pre_t(l,t+l-1); % year l, age depends positively on j
    end
    Surv(1:Length)=lam_jcoh(1:Length,coh);
    Asset_ini=0;
    Beta=bet_w_coh(coh);
    [cw_np_j,h_np_j,yw_np_j,aw_np_j]=fun_c_a_j_kpr(Beta,Length, Interest, WagePension, Surv, Asset_ini);
    % put cw_j, aw_j into cw_t, aw_t
    uw_np_sum_coh(coh)=0;
    for l=1:Length
        cw_np_pre_t(l,t+l-1)=cw_np_j(l);
        h_np_pre_t(l,t+l-1)=h_np_j(l);
        yw_np_pre_t(l,t+l-1)=yw_np_j(l);
        aw_np_pre_t(l,t+l-1)=aw_np_j(l);
        
        cw_np_coh(l,coh)=cw_np_j(l); 
        h_np_coh(l,coh)=h_np_j(l); 
        yw_np_coh(l,coh)=yw_np_j(l);
        aw_np_coh(l,coh)=aw_np_j(l); 

        uw_np_coh(l,coh)=fun_u_kpr(cw_np_coh(l,coh),h_np_coh(l,coh));
        
    end
end
aw_np_pre_t(1,T_pre+1)=0;
aw_np_t(1:J,1)=aw_np_pre_t(1:J,T_pre+1);





% ------------------- Entrepreneurs 
% entrepreneurs' problems start in 1995
t=t_pre_e_start;
ae_pre_t(Je:J,t)=ones(J-Je+1,1)*ae_t_pre_e_start;
for j=1:t % cohort 1 to t_pre_e_start, older cohorts doesn't matter
    coh=t_pre_e_start-j+1;
    Length=J-j+1;
     if j<Je
        Interest(1:Je-j)=1+r;
        Interest(Je-j+1:J-j+1)=RE_pre_t(t+Je-j:t+J-j);
        Inc(1:Je-j)=(1-tau_e_pre_t(t:t+Je-j-1)).*me_pre_t(t:t+Je-j-1);
        Inc(Je-j+1:J-j+1)=pe_pre_t(t+Je-j:t+J-j);
     else
        Interest(1:J-j+1)=RE_pre_t(t:t+J-j);
        Inc(1:J-j+1)=pe_pre_t(t:t+J-j);
     end
    Labor=zeros(1,Length);
    Surv(1:Length)=lam_jcoh(j:j+Length-1,coh);
    Asset_ini=ae_pre_t(j,t);
    [ce_j,ae_j]=fun_c_a_j_fixlabor(bet_e_ini,Length, Interest, Inc, Surv, Asset_ini);
    % put cw_j, aw_j into cw_t, aw_t
    for l=1:Length
        ce_pre_t(j+l-1,t+l-1)=ce_j(l);
        ae_pre_t(j+l-1,t+l-1)=ae_j(l);
        ye_pre_t(j+l-1,t+l-1)=Inc(l);
    end
end


% those born in period t>1
for t=t_pre_e_start+1:T_pre
    coh=t;
    j=1;
    Length=J;
    Interest(1:Je-1)=1+r;
    Interest(Je:J)=RE_pre_t(t+Je-1:t+J-1);
    Inc(1:Je-1)=(1-tau_e_pre_t(t:t+Je-2)).*me_pre_t(t:t+Je-2);
    Inc(Je:J)=pe_pre_t(t+Je-1:t+J-1);
    Surv(1:Length)=lam_jcoh(1:Length,coh);
    Asset_ini=0;
    Labor=zeros(1,J);
    [ce_j,ae_j]=fun_c_a_j_fixlabor(bet_e_ini,Length, Interest, Inc, Surv, Asset_ini);
    % put ce_j, ae_j into ce_t, ae_t
    for l=1:Length
        ce_pre_t(j+l-1,t+l-1)=ce_j(l);
        ae_pre_t(j+l-1,t+l-1)=ae_j(l);
        ye_pre_t(j+l-1,t+l-1)=Inc(l);
    end
end
ae_pre_t(1,T_pre+1)=0;

