% workers' problem starts from year_pre_wr, with initial asset
% awr_t_pre_wr_start=0

t_pre_wr_start=year_pre_wr_start-year_pre_start+1; % year_pre_start is the year the oldest cohort in 2000 was born
awr_t_pre_wr_start=0;


%% ----------------- Prepare Variables for Workers' Problem -------------------
% ------- wage
g_wr_t(2:t_dyn)=wr_t(2:t_dyn)./wr_t(1:t_dyn-1)-1;
g_wr_pre=mean(g_wr_t(2:3)); % wage growth before 2000 is taken as the initial wage growth after 2000
g_wr_t(1)=g_wr_pre;

t_pre_1980=1980-year_pre_start+1; % the wage starts growing in 1980
g_wr_pre_t(1:t_pre_1980-1)=-g; % before 1980, it was 0
g_wr_pre_t(t_pre_1980:T_pre+1)=g_wr_pre; % 1980 to 2000, it is constant

wr_pre_t(T_pre+1:T_pre+J)=wr_t(1:J);
for t=T_pre:-1:1
    wr_pre_t(t)=wr_pre_t(t+1)/(1+g_wr_pre_t(t+1));
end

% ------------ productivity
for t=1:T_pre+J
    coh=t;
    for j=1:Jw-1
        prod_pre_jt(j,t+j-1)=prod_j(j)*prod_coh(coh); % productivity age profile and cohort profile
    end
end


% ------------ wage rate and pension
for t=1:T_pre+J-1
    for j=1:Jw-1
        wagepension_r_pre_t(j,t)=wr_pre_t(t)*prod_pre_jt(j,t);
    end
    for j=Jw:J
        wagepension_r_pre_t(j,t)=0; % no pension
    end
end


%% ----------------------- Workers' Problem ---------------
t=t_pre_wr_start;  % start from 1995
awr_pre_t(1:J,t)=ones(J,1)*awr_t_pre_wr_start;
% cohorts with j=1 to j=t_pre_e_start in 1995.  Older cohorts die already in 20000, so we don't need to calculate their problem
for j=1:t 
    coh=t-j+1; % cohort number, oldest cohort is 1
    Length=J-j+1; % length of life from 1995
    Interest(1:Length)=1+r; % interest rate she faces in the life-cycle
    Inc=zeros(1,Length); % normalize income
    for l=1:Length
        WagePension(l)=wagepension_r_pre_t(j+l-1,t+l-1); % wage and pension
    end
    Surv(1:Length)=lamr_jcoh(j:j+Length-1,coh); % survival rate
    Asset_ini=awr_pre_t(j,t);
    % solve the life-cycle problem with KPR utility
    [cwr_j,hr_j,ywr_j,awr_j]=fun_c_a_j_kpr(bet_w_ini,Length, Interest,  WagePension, Surv, Asset_ini);
    % save the individual's solution cw_j, aw_j into the big matrix for all
    % cohorts: cw_t, aw_t, and cw_coh, aw_coh
    for l=1:Length
        cwr_pre_t(j+l-1,t+l-1)=cwr_j(l); % age j+l-1 in period t+l-1
        hr_pre_t(j+l-1,t+l-1)=hr_j(l); % labor supply
        ywr_pre_t(j+l-1,t+l-1)=ywr_j(l); % final income
        awr_pre_t(j+l-1,t+l-1)=awr_j(l); % asset
        
        cwr_coh(j+l-1,coh)=cwr_j(l);        % age j+l-1 for cohort coh
        hr_coh(j+l-1,coh)=hr_j(l);        
        ywr_coh(j+l-1,coh)=Inc(l);
        awr_coh(j+l-1,coh)=awr_j(l);
        
       uwr_coh(j+l-1,coh)=fun_u_kpr(cwr_coh(j+l-1,coh),hr_coh(j+l-1,coh)); % utility of cohort coh at age j+l-1
        
    end
    
    % before 1995, she provides 1 unit of labor and consumes the income
    % every period
    for len=1:j-1
        if len<Jw
            hr_coh(len,coh)=hr_adjust;
            ywr_coh(len,coh)=wagepension_r_pre_t(len,t+len-j)*hr_adjust;
        else
            hr_coh(len,coh)=0;
            ywr_coh(len,coh)=wagepension_r_pre_t(len,t+len-j);
        end
        cwr_coh(len,coh)=ywr_coh(len,coh);
        ywr_pre_t(len,t+len-j)=ywr_coh(len,coh);
        cwr_pre_t(len,t+len-j)=cwr_coh(len,coh);
        uwr_coh(len,coh)=fun_u_kpr(cwr_coh(len,coh),hr_coh(len,coh));
    end
        
end


% those born in period t>t_pre_w_start, after 1995
j=1; % start from j=1
for t=t_pre_wr_start+1:T_pre
    coh=t;
    
    Length=J;
    Interest(1:Length)=1+r;
    Inc=zeros(1,Length);
    for l=1:Length
        WagePension(l)=wagepension_r_pre_t(j+l-1,t+l-1); % year l, age depends positively on j
    end
    Surv(1:Length)=lamr_jcoh(j:j+Length-1,coh);
    Asset_ini=0;
    [cwr_j,hr_j,ywr_j,awr_j]=fun_c_a_j_kpr(bet_w_ini,Length, Interest, WagePension, Surv, Asset_ini);
    % put ce_j, ae_j into ce_t, ae_t
    for l=1:Length
        cwr_pre_t(j+l-1,t+l-1)=cwr_j(l);
        hr_pre_t(j+l-1,t+l-1)=hr_j(l);
        ywr_pre_t(j+l-1,t+l-1)=ywr_j(l);
        awr_pre_t(j+l-1,t+l-1)=awr_j(l);
        
        cwr_coh(j+l-1,coh)=cwr_j(l);        
        hr_coh(j+l-1,coh)=hr_j(l);        
        ywr_coh(j+l-1,coh)=Inc(l);
        awr_coh(j+l-1,coh)=awr_j(l);
                
        
        uwr_coh(j+l-1,coh)=fun_u_kpr(cwr_coh(j+l-1,coh),hr_coh(j+l-1,coh));
        
    end
end
awr_pre_t(1,T_pre+1)=0; % initial asset at age j=1 (age=22) is 0
