
% compute the equilibrium outcome in the rural area


%% ---------------- Rural Worker's problem after 2000 -----------

% the pension base in each year is the average wage income
p_base_r_t(1:t_dyn)=wr_t(1:t_dyn).*Hr_t(1:t_dyn)./Nr_labor_t(1:t_dyn);


% wage and pension
for t=1:t_dyn
    for j=1:Jw-1
        wagepension_r_t(j,t)=(1-tau_wr)*wr_t(t)*prod_jt(j,t);
    end
    for j=Jw:J
        wagepension_r_t(j,t)=replace_wr*p_base_r_t(t);
    end
end

% after t_dyn, variables reach the steady state level
wagepension_r_t(1:J,t_dyn+1:t_end)=wagepension_r_t(1:J,t_dyn)*ones(1,t_end-t_dyn);



% those cohorts already existing in period 1
% the meanings of the variables below are the same as noted in
% initialstate_rural.m
t=1;
for j=1:J % j is the age in period 1
    Length=J-j+1;
    coh=J-j+1;
    Interest(1:Length)=1+r;
    for l=1:Length
        WagePension(l)=wagepension_r_t(j+l-1,l); % year l, age depends positively on j
    end
    Surv(1:Length)=lamr_jcoh(j:j+Length-1,coh);
    Asset_ini=awr_t(j,1);
    Beta=bet_w_coh(coh);
    [cwr_j,hr_j,ywr_j,awr_j]=fun_c_a_j_kpr(Beta,Length, Interest, WagePension,  Surv, Asset_ini);
    
    for l=1:Length
        cwr_t(j+l-1,l)=cwr_j(l);
        hr_t(j+l-1,l)=hr_j(l);
        ywr_t(j+l-1,l)=ywr_j(l);
        awr_t(j+l-1,l)=awr_j(l);
        ywr_disp_t(j+l-1,l)=ywr_j(l)+(Interest(l)-1)*awr_j(l);


        cwr_coh(j+l-1,coh)=cwr_j(l);        
        hr_coh(j+l-1,coh)=hr_j(l);        
        ywr_coh(j+l-1,coh)=ywr_j(l);
        awr_coh(j+l-1,coh)=awr_j(l);
        
        uwr_coh(j+l-1,coh)=fun_u_kpr(cwr_coh(j+l-1,coh),hr_coh(j+l-1,coh));
 
    end
end
uwr_sum_coh=zeros(1,t_dyn+J-1);
% their lifetime utility 
for coh=1:J
    Surv=lamr_jcoh(1:J,coh);
    for j=1:J % look at their whole life
        uwr_sum_coh(coh)=uwr_sum_coh(coh)+prod(Surv(1:j))*(bet_w_coh(coh)*(1+g)^(1-sig))^(j-1)*uwr_coh(j,coh);
    end
end



% those born in period t>1
j=1;
for t=2:t_dyn
    Length=J;
    coh=J+t-1;
    Interest(1:Length)=1+r;
    for l=1:Length
        WagePension(l)=wagepension_r_t(l,t+l-1); % year l, age depends positively on j
    end
    Surv(1:J)=lamr_jcoh(1:J,coh);
    Asset_ini=0;
    Beta=bet_w_coh(coh);
    [cwr_j,hr_j,ywr_j,awr_j]=fun_c_a_j_kpr(Beta,Length, Interest, WagePension,  Surv, Asset_ini);
    % put cw_j, aw_j into cw_t, aw_t
    
    uwr_sum_coh(coh)=0;
    for l=1:Length
        cwr_t(l,t+l-1)=cwr_j(l);
        hr_t(l,t+l-1)=hr_j(l);
        ywr_t(l,t+l-1)=ywr_j(l);
        awr_t(l,t+l-1)=awr_j(l);
        ywr_disp_t(l,t+l-1)=ywr_j(l)+(Interest(l)-1)*awr_j(l);

        cwr_coh(l,coh)=cwr_j(l);
        hr_coh(l,coh)=hr_j(l);
        ywr_coh(l,coh)=ywr_j(l);
        awr_coh(l,coh)=awr_j(l);
        

        uwr_coh(l,coh)=fun_u_kpr(cwr_coh(j+l-1,coh),hr_coh(j+l-1,coh));
        % lifetime utility
        uwr_sum_coh(coh)=uwr_sum_coh(coh)+prod(Surv(1:l))*(bet_w_coh(coh)*(1+g)^(1-sig))^(l-1)*uwr_coh(l,coh);
    end
end




%% --------------------- Aggregate Variables ----------------------

% aggregate asset, consumption and labor
for t=1:t_dyn
    Awr_t(t)=awr_t(1:J,t)'*Nr_t(1:J,t);
    Awr_young_t(t)=awr_t(1:Jw-1,t)'*Nr_t(1:Jw-1,t);
end

Awr_ss=Awr_t(t_dyn);

for t=1:t_dyn-1
    Cwr_t(t)=cwr_t(1:J,t)'*Nr_t(1:J,t);
end

for t=1:t_dyn
    Hr_t(t)=sum(prod_jt(1:Jw-1,t).*hr_t(1:Jw-1,t).*Nr_t(1:Jw-1,t)); 
end