% variables of the economy, including urban and rural sectors

%% ------------ 1. Output, Growth and other Macro Variables --------------
Yur_t=Y_t+Yr_t; % GDP
yur_t(1:t_dyn)=Yur_t(1:t_dyn)./pop_ur_total_t(1:t_dyn); % GDP per capita
yur_pw_t(1:t_dyn)=Yur_t(1:t_dyn)./pop_ur_labor_t(1:t_dyn); % GDP per worker

% growth rates
for t=2:t_dyn
    growth_Yur_t(t)=Yur_t(t)/Yur_t(t-1)-1;
    growth_yur_t(t)=yur_t(t)/yur_t(t-1)-1;
    growth_yur_pw_t(t)=yur_pw_t(t)/yur_pw_t(t-1)-1;
end

% moving average smoothing
span_ma=11;
growth_Yur_t_ma(2:t_dyn)=smooth(growth_Yur_t(2:t_dyn),span_ma,'moving');
growth_yur_t_ma(2:t_dyn)=smooth(growth_yur_t(2:t_dyn),span_ma,'moving');
growth_yur_pw_t_ma(2:t_dyn)=smooth(growth_yur_pw_t(2:t_dyn),span_ma,'moving');

% aggregate investment
I_t(1:t_dyn-1)=(1+g)*K_t(2:t_dyn)-(1-dep)*K_t(1:t_dyn-1);
% iceberg cost of lending
iceberg_t(1:t_dyn)=(rl_t(1:t_dyn)-r*ones(1,t_dyn)).*(KF_t(1:t_dyn)+KE_t(1:t_dyn)-AE_t(1:t_dyn));
iceberg_r_t(1:t_dyn)=(rl_t(1:t_dyn)-r*ones(1,t_dyn)).*Kr_t(1:t_dyn);






%% ----------- 2. Government asset, Capital, Contribution to Foreign Reserve --------------
Kg_t(1)=0;  % government capital
Ig_t(1:t_dyn)=IgYur_t(1:t_dyn).*Yur_t(1:t_dyn);
Yg_t(1:t_dyn)=tau_g*Y_t(1:t_dyn)+tau_gr*Y_t(1:t_dyn); % government income from VAT tax


for t=2:t_dyn
    Kg_t(t)=((1-dep)*Kg_t(t-1)+Ig_t(t-1))/(1+g);
end

% initial asset is pinned down by the gap between private saving and total
% saving needed to match the foreign surplus in the first period
t=1;
Aw_t(1:t_dyn)=sum(aw_p_t(1:J,1:t_dyn).*Nw_p_t(1:J,1:t_dyn)+aw_np_t(1:J,1:t_dyn).*Nw_np_t(1:J,1:t_dyn),1);
Awr_t(1:t_dyn)=sum(awr_t(1:J,1:t_dyn).*Nr_t(1:J,1:t_dyn),1);
saving_bank_ur_t(1)=Ae_t(1)-AE_t(1)+Aw_t(1)+Awr_t(1)+KE_stor_t(1); % manager saving, worker saving, E firm extra capital go to bank
loan_ur_t(1)=KF_t(1)+KE_prod_t(1)-AE_t(1)+Kr_t(1); % loan to F firm and part of E firm's capital
Bp_t(1)=saving_bank_ur_t(1)-loan_ur_t(1); % government debt are issued as bonds


if year_start==2000
    % calibrate to 12% GDP foreign surplus in 2000
    Ag_pen_t(1)=-gov_debt_t(1); % the debt or asset in the pension system
    Ag_pen_transfer_t(1)=-gov_debt_t(1); % pension system asset, taking into account the potential transfer from the government budget
    % government hold the rest of asset such that the foreign surplus meets
    % the target
    Ag_extra_netKg_t(1)=BYur_target_t(1)*Yur_t(1)-Bp_t(1)-Ag_pen_t(1); % no Kg because government capital is just "useless" bridges
else
    % already load from name_data_2000
end

% government saving in each period
Sg_extra_t(1:t_dyn)=SgYur_t(1:t_dyn).*Yur_t(1:t_dyn); % except t=t_transfer

for t=2:t_transfer-1
    Ag_extra_netKg_t(t)=(Ag_extra_netKg_t(t-1)+Sg_extra_t(t-1)-Ig_t(t-1))/(1+g); % Sg-Ig is the real saving into financial asset
    Ag_pen_transfer_t(t)=-gov_debt_t(t)+Ag_transfer_real*((1+r)/(1+g))^(t-t_transfer);
end

% save the old values
% transfer to the pension system
Ag_transfer_old=Ag_transfer; % transfer to the pension system
Ag_transfer_value_ini_old=Ag_transfer_value_ini; % the value of transfer calculated from period 1
Ag_transfer_real_old=Ag_transfer_real;  % the real transfer that is made
Ag_transfer_real_value_ini_old=Ag_transfer_real_value_ini;
% potentially Ag_transfer can be different from Ag_transfer_real
% but we have them the same in the baseline model

   
if t_transfer~=99 % 99 is the index that the transfer was made before period 1, so there is no transfer 
    Ag_transfer=0.01*Yur_t(1)*((1+r)/(1+g))^(t_transfer-1);
    Ag_transfer_real=0.01*Yur_t(1)*((1+r)/(1+g))^(t_transfer-1);
end
    
% in period t_transfer, give Ag_transfer_real to the pension system
t=t_transfer; Ag_extra_netKg_t(t)=(Ag_extra_netKg_t(t-1)+Sg_extra_t(t-1)-Ig_t(t-1))/(1+g) - Ag_transfer_real; 

for t=t_transfer+1:t_dyn
    Ag_extra_netKg_t(t)=(Ag_extra_netKg_t(t-1)+Sg_extra_t(t-1)-Ig_t(t-1))/(1+g);
    Ag_pen_transfer_t(t)=-gov_debt_t(t);
end
% for the government asset excluding the pension fund, it's dissaving
Sg_extra_t(t_transfer-1)=SgYur_t(t_transfer-1).*Yur_t(t_transfer-1)-Ag_transfer_real*(1+g);

% discount the value of the transfer to the initial period
Ag_transfer_value_ini=Ag_transfer*(1+g)^(t_transfer-1)/(1+r)^(t_transfer-1);
Ag_transfer_real_value_ini=Ag_transfer_real*(1+g)^(t_transfer-1)/(1+r)^(t_transfer-1);


%% ---------------------- 3. Household Saving Rate ---------------------------

% urban workers
Yw_disp_t=sum(yw_disp_p_t(1:J,1:t_dyn).*Nw_p_t(1:J,1:t_dyn)+yw_disp_np_t(1:J,1:t_dyn).*Nw_np_t(1:J,1:t_dyn),1); % disposible income
Cw_t=sum(cw_p_t(1:J,1:t_dyn).*Nw_p_t(1:J,1:t_dyn)+cw_np_t(1:J,1:t_dyn).*Nw_np_t(1:J,1:t_dyn),1);
Sw_t(1:t_dyn)=Yw_disp_t(1:t_dyn)-Cw_t(1:t_dyn);
Sw2_t(1:t_dyn-1)=(1+g)*Aw_t(2:t_dyn)-Aw_t(1:t_dyn-1); % an alternative way of calculating the saving 
Sav_rate_w_t(1:t_dyn-1)=Sw_t(1:t_dyn-1)./Yw_disp_t(1:t_dyn-1);

% rural workers
Ywr_disp_t=sum(ywr_disp_t(1:J,1:t_dyn).*Nr_t(1:J,1:t_dyn),1);
Cwr_t=sum(cwr_t(1:J,1:t_dyn).*Nr_t(1:J,1:t_dyn),1);
Swr_t(1:t_dyn)=Ywr_disp_t(1:t_dyn)-Cwr_t(1:t_dyn);
Swr2_t(1:t_dyn-1)=(1+g)*Awr_t(2:t_dyn)-Awr_t(1:t_dyn-1);
Sav_rate_wr_t(1:t_dyn-1)=Swr_t(1:t_dyn-1)./Ywr_disp_t(1:t_dyn-1);

% entrepreneur
Ye_disp_t=sum(ye_disp_t(1:J,1:t_dyn).*Ne_t(1:J,1:t_dyn),1);
Se_t(1:t_dyn-1)=(1+g)*Ae_t(2:t_dyn)-Ae_t(1:t_dyn-1);
Sav_rate_e_t(1:t_dyn-1)=Se_t(1:t_dyn-1)./Ye_disp_t(1:t_dyn-1);

% aggregate saving rate
Sav_rate_ur_t(1:t_dyn-1)=(Sw_t(1:t_dyn-1)+Swr_t(1:t_dyn-1))./(Yw_disp_t(1:t_dyn-1)+Ywr_disp_t(1:t_dyn-1)); % rural and urban workers
Sav_rate_ure_t(1:t_dyn-1)=(Sw_t(1:t_dyn-1)+Swr_t(1:t_dyn-1)+Se_t(1:t_dyn-1))./(Yw_disp_t(1:t_dyn-1)+Ywr_disp_t(1:t_dyn-1)+Ye_disp_t(1:t_dyn-1)); % entrepreneurs











