% variables in the reform experiment

%% ------ 1. Aggregate Income, Consumption and Asset of Workers  --------
Yw_ss=w_ss*H_ss;
Aw_ss=(aw_p_ss(1:J)*Nw_p_ss(1:J)'+aw_np_ss(1:J)*Nw_np_ss(1:J)');
Aw_young_ss=(aw_p_ss(1:Jw-1)*Nw_p_ss(1:Jw-1)'+aw_np_ss(1:Jw-1)*Nw_np_ss(1:Jw-1)');
ratio_Aw_Yw_ss=Aw_ss/Yw_ss;
ratio_Aw_young_Yw_ss=Aw_young_ss/Yw_ss;


for t=1:t_dyn
    Aw_t(t)=aw_p_t(1:J,t)'*Nw_p_t(1:J,t)+aw_np_t(1:J,t)'*Nw_np_t(1:J,t);
    Aw_young_t(t)=aw_p_t(1:Jw-1,t)'*Nw_p_t(1:Jw-1,t)+aw_np_t(1:Jw-1,t)'*Nw_np_t(1:Jw-1,t);
    Awr_t(t)=awr_t(1:J,t)'*Nr_t(1:J,t);
    Awr_young_t(t)=awr_t(1:Jw-1,t)'*Nr_t(1:Jw-1,t);
end

Awr_ss=Awr_t(t_dyn);

% aggregat consumption
for t=1:t_dyn-1
    Ce_t(t)=ce_t(1:J,t)'*Ne_t(1:J,t);
    Cw_t(t)=cw_p_t(1:J,t)'*Nw_p_t(1:J,t)+cw_np_t(1:J,t)'*Nw_np_t(1:J,t);
    Cwr_t(t)=cwr_t(1:J,t)'*Nr_t(1:J,t);
end



%% -------- 2. Private Foreign Reserve, Excluding Government Wealth -----------------

% AE in solve_dynamic.m, Ae in variables_eq.m
saving_bank_ur_t=Ae_t-AE_t+Aw_t+Awr_t+KE_stor_t; % manager saving, worker saving, E firm extra capital go to bank
loan_ur_t=KF_t+KE_prod_t-AE_t+Kr_t; % loan to F firm and part of E firm's capital
Bp_t(1:t_dyn)=saving_bank_ur_t(1:t_dyn)-loan_ur_t(1:t_dyn); % government debt are issued as bonds


%% -------- 3. Government asset, Consumption and Savings, and Foreign Surplus with Government Asset ------------
Ag_pen_t(1:t_dyn)=-gov_debt_t(1:t_dyn); % asset in the pension system
Ag_t=Ag_extra_netKg_t+Ag_pen_t; % total government asset
Cg_t(1:t_dyn)=r*Ag_extra_netKg_t(1:t_dyn)+Yg_t(1:t_dyn)-Sg_extra_t(1:t_dyn); % government consumption
B_t(1:t_dyn)=Bp_t(1:t_dyn)+Ag_pen_t(1:t_dyn)+Ag_extra_netKg_t(1:t_dyn); % Kg is both in asset and capital, so it cancels out


%% --------- 4. Savings ----------
% Sw_t, Swr_t, Se_t already calculated in variables_eq_ur.m
SE_t(1:t_dyn-1)=(1+g)*AE_t(2:t_dyn)-AE_t(1:t_dyn-1); % E firm owners saving
Sg_pen_t(1:t_dyn-1)=(1+g)*Ag_pen_t(2:t_dyn)-Ag_pen_t(1:t_dyn-1); % pension fund saving


% Savings
S_t(1:t_dyn-1)=Sw_t(1:t_dyn-1)+Se_t(1:t_dyn-1)+dep*K_t(1:t_dyn-1); % urban
Sr_t(1:t_dyn-1)=Swr_t(1:t_dyn-1)+dep*Kr_t(1:t_dyn-1); % rural
Sg_t(1:t_dyn-1)=Sg_extra_t(1:t_dyn-1)+Sg_pen_t(1:t_dyn-1); % government

% Second way, use output and consumption
S2_t(1:t_dyn-1)=(1-tau_g)*Y_t(1:t_dyn-1)+r*B_t(1:t_dyn-1).*Yur_t(1:t_dyn-1)-iceberg_t(1:t_dyn-1)-Ce_t(1:t_dyn-1)-Cw_t(1:t_dyn-1);
Sg2_t(1:t_dyn-1)=Yg_t(1:t_dyn-1)-Cg_t(1:t_dyn-1);
Sr2_t(1:t_dyn-1)=(1-tau_gr)*Yr_t(1:t_dyn-1)-iceberg_r_t(1:t_dyn-1)-Cwr_t(1:t_dyn-1);

% household saving
Sh_t(1:t_dyn-1)=Sw_t(1:t_dyn-1)+Se_t(1:t_dyn-1)-SE_t(1:t_dyn-1);
% firm saving
Sf_t(1:t_dyn-1)=SE_t(1:t_dyn-1)+dep*K_t(1:t_dyn-1);
% private
Sp_t(1:t_dyn-1)=Sh_t(1:t_dyn-1)+Sf_t(1:t_dyn-1);

% rural sector
Sh_r_t(1:t_dyn-1)=Swr_t(1:t_dyn-1);
Sf_r_t(1:t_dyn-1)=dep*Kr_t(1:t_dyn-1);
Sp_r_t(1:t_dyn-1)=Sh_r_t(1:t_dyn-1)+Sf_r_t(1:t_dyn-1);



%% --------------- 5. Average Labor earnings -------------------
for t=1:t_dyn
    % average wage income
    ave_wageincome_t(t)=(yw_p_t(1:Jw-1,t)'/(1-tau_w_t(t))*Nw_p_t(1:Jw-1,t)+yw_np_t(1:Jw-1,t)'*Nw_np_t(1:Jw-1,t))/sum(Nw_p_t(1:Jw-1,t)+Nw_np_t(1:Jw-1,t));
    % average productivity
    ave_prod_t(t)=(prod_jt(1:Jw-1,t)'*(Nw_p_t(1:Jw-1,t)+Nw_np_t(1:Jw-1,t)))/sum(Nw_p_t(1:Jw-1,t)+Nw_np_t(1:Jw-1,t));
    % average labor supply
    ave_h_t(t)=(h_p_t(1:Jw-1,t)'*Nw_p_t(1:Jw-1,t)+h_np_t(1:Jw-1,t)'*Nw_np_t(1:Jw-1,t))/sum(Nw_p_t(1:Jw-1,t)+Nw_np_t(1:Jw-1,t));
end
% average wage income per efficient worker
ave_wageincome_netprod_t=ave_wageincome_t./ave_prod_t;

% --------- growth of wage and labor income
t1=t_dyn;
growth_w_t(2:t1)=w_t(2:t1)./w_t(1:t1-1)-1;
growth_ave_yw_netprod_t(2:t1)=ave_wageincome_netprod_t(2:t1)./ave_wageincome_netprod_t(1:t1-1)-1;
growth_ave_yw_t(2:t1)=ave_wageincome_t(2:t1)./ave_wageincome_t(1:t1-1)-1;
growth_prod_t(2:t1)=ave_prod_t(2:t1)./ave_prod_t(1:t1-1)-1;



%% ------------------- 6. Year Specific Replacement Rate ------------------------------
% pension payments per person over labor income per person, as the
% replacement rate in each year
replace_w_t(1:t_dyn)=(pension_total_t(1:t_dyn)./Nw_retire_p_t(1:t_dyn))./(tax_total_t(1:t_dyn)./tau_w_t(1:t_dyn)./Nw_labor_p_t(1:t_dyn));
replace_w_lastyear_t(2:t_dyn)=(pension_total_t(2:t_dyn)./Nw_retire_p_t(2:t_dyn))./(tax_total_t(1:t_dyn-1)./tau_w_t(1:t_dyn-1)./Nw_labor_p_t(1:t_dyn-1));
replace_w_aveyw_t(1:t_dyn)=(pension_total_t(1:t_dyn)./Nw_retire_p_t(1:t_dyn))./ave_wageincome_t(1:t_dyn);
