% parameters related to time, or starting year

% load data from data_benchmark
% and then adjust it

%% -------------- Year -------------------
year_data=2013; % data start from year 2000
year_start=2013; % our model start from year 2013
t_start=1+year_start-year_data; % now the first year is equavalent to t_start year in the data

%% ----- demography ------
load(name_data_2013, 'age_start', 'age_end', 'J', 'Jw', 'Je' )
load(name_data_2013, 't_dyn_bm2' ) 
t_dyn=t_dyn_bm2-(year_start-year_data);  % short dynamics
t_end=t_dyn+100; % from t_dyn to t_end, all variables are in steady state

% survival rate to age j from period j-1, these are constant now, but will
% change in the future
load(name_data_2013, 'lam_jt_bm2','lam_jss', 'lamr_jt_bm2')
lam_jt=lam_jt_bm2(:,t_start:t_end); % we need more information than t_dyn
lamr_jt=lamr_jt_bm2(:,t_start:t_end);


%% ----- N_t, N_ss -----
load(name_data_2013, 'N_t_bm2', 'Ne_t_bm2', 'Nw_t_bm2', 'Nr_t_bm2')
load(name_data_2013, 'pop_total_t_bm2', 'pop_labor_t_bm2', 'pop_ur_total_t_bm2','pop_ur_labor_t_bm2','pop_r_total_t_bm2')
% cut from t_start
N_t=N_t_bm2(:,t_start:t_start+t_dyn-1);

N_total_t(1)=sum(N_t(1:J,1));
for t=2:t_dyn
    N_total_t(t)=sum(N_t(1:J,t));
    N_growth_t(t)=N_total_t(t)/N_total_t(t-1)-1;
end
Ne_t=Ne_t_bm2(:,t_start:t_start+t_dyn-1);
Nw_t=Nw_t_bm2(:,t_start:t_start+t_dyn-1);
Nr_t=Nr_t_bm2(:,t_start:t_start+t_dyn-1);

pop_total_t=pop_total_t_bm2(:,t_start:t_start+t_dyn-1);
pop_labor_t=pop_labor_t_bm2(:,t_start:t_start+t_dyn-1);
pop_ur_total_t=pop_ur_total_t_bm2(:,t_start:t_start+t_dyn-1);
pop_ur_labor_t=pop_ur_labor_t_bm2(:,t_start:t_start+t_dyn-1);
pop_r_total_t=pop_r_total_t_bm2(:,t_start:t_start+t_dyn-1);

load(name_data_2013, 'Perc_w_p_coh_bm2')
% entrepreneur ratio
% covered by pension or not
Perc_w_p_coh=Perc_w_p_coh_bm2(:,t_start:t_start+t_dyn-1+J-1);
Perc_w_np_coh=1-Perc_w_p_coh;


for t=1:t_dyn
% population gaining labor income
Ne_labor_t(t)=sum(Ne_t(1:Je-1,t));
Nw_labor_t(t)=sum(Nw_t(1:Jw-1,t));
Nr_labor_t(t)=sum(Nr_t(1:Jw-1,t));
% population gaining capital
Ne_retire_t(t)=sum(Ne_t(Je:J,t));
Nw_retire_t(t)=sum(Nw_t(Jw:J,t));

end

for t=1:t_dyn
    for j=1:J
        % for different age
        Nw_p_t(j,t)=Nw_t(j,t)*Perc_w_p_coh(J-j+t);
        Nw_np_t(j,t)=Nw_t(j,t)*Perc_w_np_coh(J-j+t);
    end
    Nw_labor_p_t(t)=sum(Nw_p_t(1:Jw-1,t));
    Nw_labor_np_t(t)=sum(Nw_np_t(1:Jw-1,t));
    Nw_retire_p_t(t)=sum(Nw_p_t(Jw:J,t));
    Nw_retire_np_t(t)=sum(Nw_np_t(Jw:J,t));
end

% test if N_t converges (growth allowed)
check_N_converge=max(N_t(1:J,t_dyn)./sum(N_t(1:J,t_dyn)) - N_t(1:J,t_dyn-1)./sum(N_t(1:J,t_dyn-1)));

% N_ss is the distribution, ( sum normalize to 1, diffrent from sum(N_t(t)))
N_growth_ss=sum(N_t(1:J,t_dyn))/sum(N_t(1:J,t_dyn-1))-1;
N_ss=N_t(1:J,t_dyn)'/sum(N_t(1:J,t_dyn));
Ne_ss=Ne_t(1:J,t_dyn)'/sum(Ne_t(1:J,t_dyn));
Nw_ss=Nw_t(1:J,t_dyn)'/sum(Nw_t(1:J,t_dyn));
% percentage gaining labor income
Ne_labor_ss=sum(Ne_ss(1:Je-1));
Nw_labor_ss=sum(Nw_ss(1:Jw-1));
% percentage only gaining capital income
Ne_retire_ss=sum(Ne_ss(Je:J));
Nw_retire_ss=sum(Nw_ss(Jw:J));

Perc_w_p_ss=Perc_w_p_coh(t_dyn+J-1);
Perc_w_np_ss=1-Perc_w_p_ss;

Nw_p_ss=Nw_ss*Perc_w_p_ss;
Nw_np_ss=Nw_ss*Perc_w_np_ss;
Nw_labor_p_ss=Nw_labor_ss*Perc_w_p_ss;
Nw_labor_np_ss=Nw_labor_ss*Perc_w_np_ss;
Nw_retire_p_ss=Nw_retire_ss*Perc_w_p_ss;
Nw_retire_np_ss=Nw_retire_ss*Perc_w_np_ss;


%% ----- Productivity Profile -----
load(name_data_2013, 'prod_jss', 'prod_t_bm2')
% prod_jss should be normalized already
% sum(prod_jss)/(Jw-1);
% 
prod_jt=prod_t_bm2(:,t_start:t_start+t_dyn-1);



%% ----- Transition of Economic Parameters ------
load(name_data_2013,'Z_ss', 'rl_ss')
load(name_data_2013,'Z_t_bm2', 'rl_t_bm2')
Z_t=Z_t_bm2(t_start:t_start+t_dyn-1);
rl_t=rl_t_bm2(t_start:t_start+t_dyn-1);

load(name_data_2013, 'psai_ss','eta_ss','chi_ss') 
load(name_data_2013, 'bet_w_coh_bm2', 'bet_e_coh_bm2','psai_t_bm2', 'eta_t_bm2', 'chi_t_bm2') 
bet_w_coh(1:t_dyn+J-1)=bet_w_coh_bm2(t_start:t_start-1+t_dyn+J-1);
bet_w_coh(t_dyn+J:t_start-1+t_dyn+J)=bet_w_coh(t_dyn+J-1)*ones(1,t_start);
bet_e_coh(1:t_dyn+J-1)=bet_e_coh_bm2(t_start:t_start-1+t_dyn+J-1);
bet_e_coh(t_dyn+J:t_start-1+t_dyn+J)=bet_e_coh(t_dyn+J-1)*ones(1,t_start);
psai_t=psai_t_bm2(t_start:t_start+t_dyn-1);
eta_t=eta_t_bm2(t_start:t_start+t_dyn-1);
chi_t=chi_t_bm2(t_start:t_start+t_dyn-1);


%% ----------- pre pension base -----------
load(name_data_2013,'T_pre_bm2','p_base_t_bm2','p_base_pre_t_bm2')
% p_base_pre_t(T_pre-t_start+1:T_pre)=p_base_t_bm2(1:t_start);
% p_base_pre_t(1:T_pre-t_start+1)=p_base_pre_t_bm2(t_start:T_pre);
% because T_pre<t_start
T_pre=T_pre_bm2+t_start-1;
p_base_pre_t(1:T_pre+t_start-1)=[p_base_pre_t_bm2(1:T_pre) p_base_t_bm2(1:t_start-1)];
% p_base_pre_t(T_pre-t_start+2:T_pre)=p_base_t_bm2(1:t_start-1);
% p_base_pre_t(1:T_pre-t_start+1)=p_base_pre_t_bm2(t_start:T_pre);

