%% -------------- Year -------------------
year_start=2000;


%% ----- demography ------
load data_demography
age_start=22; % entering market at age_ini, in the model, j=1
% age_end=100; % last period of life
age_end=100; % last period of life
J=age_end-age_start+1;
Jw=60-age_start+1; % workers retire at age 60
Je=50-age_start+1; % entrepreneurs start firm at age 50
% t_dyn=200;  % end of the dynamics
t_dyn=500; 
t_end=t_dyn+100; % from t_dyn to t_end, all variables are in steady state

% survival rate to age j from period j-1
load data_mort
lam(1)=1; % no need for survival rate to j=1 from 0
% data_mort contains mortality rate from age 0, so the age_ini+1 element
% corresponds to mortality rate of age_ini, which is the survival rate from
% age_ini to age_ini+1, in other words, from 1st period to j=2
lam(2:J)=1-data_mort(age_start+1:age_start+J-1); % survivial rate to j-1 from j
lam_prod(1)=1; % cummulative survivial rate to j from 1
for j=2:J
    lam_prod(j)=prod(lam(2:j));
end




%% ----- N_t, N_ss -----
index_N_t_data=1; % 1, load from data; 0, self test
index_N_t_mig=1; % 1, migration; 0, without migration

if index_N_t_data==0
    pop_simu_simple;
    N_ori_t=N_t;
 else % load from data
    if index_N_t_mig==1 % data with migration
        for t=1:t_dyn
            N_t(1:J,t)=N_t_mig(t,1:J);
            N_ori_t(1:J,t)=N_t_ori(t,1:J);
        end
    else
        for t=1:t_dyn
            N_t(1:J,t)=N_t_no_mig(t,1:J);
            N_ori_t(1:J,t)=N_t(1:J,t);
        end
    end
end
N_total_t(1)=sum(N_t(1:J,1));
for t=2:t_dyn
    N_total_t(t)=sum(N_t(1:J,t));
    N_growth_t(t)=N_total_t(t)/N_total_t(t-1)-1;
end

% entrepreneur ratio
Perc_e=0.05; % percentage of entrepreneur in original urban population
Ne_t=N_ori_t*Perc_e; % only original urban people can be entrepreneur
Nw_t=N_ori_t*(1-Perc_e)+(N_t-N_ori_t); % all the migrants are workers
% covered by pension
Perc_w_p=0.6;
Perc_w_np=1-Perc_w_p;


for t=1:t_dyn
% population gaining labor income
Ne_labor_t(t)=sum(Ne_t(1:Je-1,t));
Nw_labor_t(t)=sum(Nw_t(1:Jw-1,t));
% population gaining capital
Ne_retire_t(t)=sum(Ne_t(Je:J,t));
Nw_retire_t(t)=sum(Nw_t(Jw:J,t));

Nw_labor_p_t(t)=Nw_labor_t(t)*Perc_w_p;
Nw_labor_np_t(t)=Nw_labor_t(t)*Perc_w_np;
Nw_retire_p_t(t)=Nw_retire_t(t)*Perc_w_p;
Nw_retire_np_t(t)=Nw_retire_t(t)*Perc_w_np;

% for different age
Nw_p_t(1:J,t)=Nw_t(1:J,t)*Perc_w_p;
Nw_np_t(1:J,t)=Nw_t(1:J,t)*Perc_w_np;

end

% test if N_t converges (growth allowed)
check_N_converge=max(N_t(1:J,t_dyn)./sum(N_t(1:J,t_dyn)) - N_t(1:J,t_dyn-1)./sum(N_t(1:J,t_dyn-1)))

% N_ss is the distribution, ( sum normalize to 1, diffrent from sum(N_t(t)))
N_growth_ss=sum(N_t(1:J,t_dyn))/sum(N_t(1:J,t_dyn-1))-1;
N_ss=N_t(1:J,t_dyn)'/sum(N_t(1:J,t_dyn));
N_ori_ss=N_ori_t(1:J,t_dyn)'/sum(N_t(1:J,t_dyn));
Ne_ss=N_ori_ss*Perc_e;
Nw_ss=N_ori_ss*(1-Perc_e)+(N_ss-N_ori_ss);
% percentage gaining labor income
Ne_labor_ss=sum(Ne_ss(1:Je-1));
Nw_labor_ss=sum(Nw_ss(1:Jw-1));
% percentage only gaining capital income
Ne_retire_ss=sum(Ne_ss(Je:J));
Nw_retire_ss=sum(Nw_ss(Jw:J));

Nw_p_ss=Nw_ss*Perc_w_p;
Nw_np_ss=Nw_ss*Perc_w_np;
Nw_labor_p_ss=Nw_labor_ss*Perc_w_p;
Nw_labor_np_ss=Nw_labor_ss*Perc_w_np;
Nw_retire_p_ss=Nw_retire_ss*Perc_w_p;
Nw_retire_np_ss=Nw_retire_ss*Perc_w_np;




%% ----- Productivity Profile -----
% y=0.1210*z-0.0002*z^2-0.0011*z*x+0.308*x-0.0042*x^2+0.000026*x^3;
% z=1 means x=25 at 1957
% we use x=25 at 2007, means z=51
% contains growth information, shall we -g*x??
z=51;
for j=1:Jw-1
%     x=22+j-1;
%     prod_jss(j)=exp(0.1210*z-0.0002*z^2-0.0011*z*x+0.308*x-0.0042*x^2+0.000026*x^3);
    % try set prod grows to 2 times than the initial before retirement
    prod_jss(j)=1+(j-1)/(Jw-1-1);
end
% normalize to 1 (roughly)
temp_prod_sum=sum(prod_jss(1:Jw-1).*N_ss(1:Jw-1));
prod_jss=prod_jss/temp_prod_sum;

% set prod_jt the same as prod_jss
prod_jt(1:Jw-1,1:t_dyn)=prod_jss(1:Jw-1)'*ones(1,t_dyn);




%% ----- Z_t  xi_t ------
% Z is technology denomiated by growth
Z_t=ones(1,t_end);

% xi is the iceberg cost
xi_ini=0.069;
t_xi=15;
for t=1:t_xi
    xi_t(1:t)=xi_ss+(xi_ini-xi_ss)*(1-((t-1)/t_xi)^2.95);
end
xi_t(t_xi+1:t_dyn)=xi_ss;
rl_t=r./(1-xi_t);
