% all the figures in the paper

%% ---------------------- 1. Demography ---------------------

load('../Demography1_MigrationProjection/data_migration');

figure
subplot(2,1,1)
plot([age_min:age_max],(pop_u_f_t(:,year_end-year_ini+1)+pop_r_f_t(:,year_end-year_ini+1)),'-','color','r','linewidth',2)
hold on
plot([age_min:age_max],pop2005(:,3)+pop2005(:,4),'-.','color','b','linewidth',2)
hold off
xlabel('Age')
title('Panel a: Female Population')
legend('Simulation','Data')
subplot(2,1,2)
plot([age_min:age_max],(pop_u_m_t(:,year_end-year_ini+1)+pop_r_m_t(:,year_end-year_ini+1)),'-','color','r','linewidth',2)
hold on
plot([age_min:age_max],(pop2005(:,1)+pop2005(:,2)-pop2005(:,3)-pop2005(:,4)),'-.','color','b','linewidth',2)
hold off
xlabel('Age')
title('Panel b: Male Population')
legend('Simulation','Data')
print( '-dpng', '-r300', ['pop_simu_data_gender.png']);
print( '-depsc2', ['pop_simu_data_gender.eps']);


load('../Demography2_PopulationProjection/data_NoNormalization')

close all;
year_start=2000;

index_gtext=0; % =1 if text are added into the figure manually, =0 not
%  ----------- migration rate over time

pos_fromleft=200;
pos_frombottom=50;
figure('Position',[pos_fromleft pos_frombottom 800 600])
x_fig=age_mig_min+1:age_mig_max;
y1_fig=100*mig_rate_m(age_mig_min+2:age_mig_max+1);
y2_fig=100*mig_rate_f(age_mig_min+2:age_mig_max+1);
plot(x_fig,y1_fig,'LineWidth',3);
hold on
plot(x_fig,y2_fig,'-.','LineWidth',3,'color','black');
xlabel('Age')
ylabel('Emigration Rate (Percent)')

x_text=26;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text)-1.6;
text(x_text,y1_text,'Males', 'VerticalAlignment','bottom');
text(x_text,y2_text,'Females','VerticalAlignment','top');


print('-dpng','-r300', ['migration_rate_notitle.png']);
print('-depsc2','-r100','migration_rate_notitle.eps');

title({'\fontsize{12} Emigration Rates from Rural Areas by Age and Gender'; ...
    '\fontsize{10} as a Share of Each Cohort'})

print('-dpng','-r300', ['migration_rate.png']);
print('-depsc2','-r100','migration_rate.eps');
% epswrite('migration_rate2','resolution',1200);

% -------- population breakdown
t_fig=101;
x_fig=2000:2000+t_fig-1;   
y1_fig=pop_t_mig_sum(1:t_fig)/1e9;
y2_fig=pop_u_t_mig_sum(1:t_fig)/1e9;
y3_fig=pop_r_t_mig_sum(1:t_fig)/1e9;
y12_fig=pop_t_sum(1:t_fig)/1e9;
y22_fig=pop_u_t_sum(1:t_fig)/1e9;
y32_fig=pop_r_t_sum(1:t_fig)/1e9;
% total, rural and urban population
figure('Position',[pos_fromleft pos_frombottom 800 600])
plot(x_fig,y1_fig,'color','b','LineWidth',3);
hold on
plot(x_fig,y2_fig,'color','black','LineWidth',3);
hold on
plot(x_fig,y3_fig,'color','r','LineWidth',3);
hold on
plot(x_fig,y12_fig,'-.','color','b','LineWidth',3);
hold on
plot(x_fig,y22_fig,'-.','color','black','LineWidth',3);
hold on
plot(x_fig,y32_fig,'-.','color','r','LineWidth',3);
xlabel('Year')
ylabel('Population Size (Billions)')

x_text=2050;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text)-0.03;
y2_text=y2_fig(i_x_text)+0.01;
y3_text=y3_fig(i_x_text);
y12_text=y12_fig(i_x_text)+0.06;
y22_text=y22_fig(i_x_text);
y32_text=y32_fig(i_x_text);
text(x_text,y1_text,'Total', 'VerticalAlignment','top');
text(x_text,y2_text,'Urban','VerticalAlignment','bottom');
text(x_text,y3_text,'Rural','VerticalAlignment','bottom');
text(x_text,y12_text,'Total (counterfactual)', 'VerticalAlignment','top');
text(x_text,y22_text,'Urban (counterfactual)','VerticalAlignment','bottom');
text(x_text,y32_text,'Rural (counterfactual)','VerticalAlignment','bottom');


print( '-depsc2','pop_total_rural_urban_notitle.eps');
print('-dpng','-r300','pop_total_rural_urban_notitle.png');

title('\fontsize{14} Population Dynamics of China')
print( '-depsc2','pop_total_rural_urban.eps');
print('-dpng','-r300','pop_total_rural_urban.png');



% write to excel
g_pop_u(2:t_fig)=pop_u_t_mig_sum(2:t_fig)./pop_u_t_mig_sum(1:t_fig-1)-1;
g_pop_r(2:t_fig)=pop_r_t_mig_sum(2:t_fig)./pop_r_t_mig_sum(1:t_fig-1)-1;
xls_pop_growth=[x_fig(2:t_fig)' g_pop_u(2:t_fig)' g_pop_r(2:t_fig)'];
% xlswrite('pop_growth.xls', xls_pop_growth)
% -------- old age dependency ratio

old1=65;
old2=80;
old3=60;
age3=15;
age4=64;
age5=18;
age6=59;
t_fig2=401;
for t=1:t_fig2
    per_60_t(t)=sum(pop_t_mig(old3+1:101,t))/pop_t_mig_sum(t);
    per_60_u_t(t)=sum(pop_u_t_mig(old3+1:101,t))/pop_u_t_mig_sum(t);
    per_60_r_t(t)=sum(pop_r_t_mig(old3+1:101,t))/pop_r_t_mig_sum(t);
    
    per_60_t_nomig(t)=sum(pop_t(old3+1:101,t))/pop_t_sum(t);
    per_60_u_t_nomig(t)=sum(pop_u_t(old3+1:101,t))/pop_u_t_sum(t);
    per_60_r_t_nomig(t)=sum(pop_r_t(old3+1:101,t))/pop_r_t_sum(t);
    
    per_65_t(t)=sum(pop_t_mig(old1+1:101,t))/pop_t_mig_sum(t);
    per_65_u_t(t)=sum(pop_u_t_mig(old1+1:101,t))/pop_u_t_mig_sum(t);
    per_65_r_t(t)=sum(pop_r_t_mig(old1+1:101,t))/pop_r_t_mig_sum(t);
    
    per_80_t(t)=sum(pop_t_mig(old2+1:101,t))/pop_t_mig_sum(t);
    per_80_u_t(t)=sum(pop_u_t_mig(old2+1:101,t))/pop_u_t_mig_sum(t);
    per_80_r_t(t)=sum(pop_r_t_mig(old2+1:101,t))/pop_r_t_mig_sum(t);
    
    pop_15_64_t(t)=sum(pop_t_mig(age3+1:age4+1,t));
    pop_15_64_u_t(t)=sum(pop_u_t_mig(age3+1:age4+1,t));
    pop_15_64_r_t(t)=sum(pop_r_t_mig(age3+1:age4+1,t));
    
    per_15_64_t(t)=sum(pop_t_mig(age3+1:age4+1,t))/pop_t_mig_sum(t);
    per_15_64_u_t(t)=sum(pop_u_t_mig(age3+1:age4+1,t))/pop_u_t_mig_sum(t);
    per_15_64_r_t(t)=sum(pop_r_t_mig(age3+1:age4+1,t))/pop_r_t_mig_sum(t);
    
    per_18_59_t(t)=sum(pop_t_mig(age5+1:age6+1,t))/pop_t_mig_sum(t);
    per_18_59_u_t(t)=sum(pop_u_t_mig(age5+1:age6+1,t))/pop_u_t_mig_sum(t);
    per_18_59_r_t(t)=sum(pop_r_t_mig(age5+1:age6+1,t))/pop_r_t_mig_sum(t);
    
    per_18_59_t_nomig(t)=sum(pop_t(age5+1:age6+1,t))/pop_t_sum(t);
    per_18_59_u_t_nomig(t)=sum(pop_u_t(age5+1:age6+1,t))/pop_u_t_sum(t);
    per_18_59_r_t_nomig(t)=sum(pop_r_t(age5+1:age6+1,t))/pop_r_t_sum(t);
    
    
    dep_ratio_t(t)=(1-per_15_64_t(t))/per_15_64_t(t);
    dep_ratio_u_t(t)=(1-per_15_64_u_t(t))/per_15_64_u_t(t);
    dep_ratio_r_t(t)=(1-per_15_64_r_t(t))/per_15_64_r_t(t);
    
    dep_ratio_t_fz(t)=per_60_t(t)/per_18_59_t(t);
    dep_ratio_u_t_fz(t)=per_60_u_t(t)/per_18_59_u_t(t);
    dep_ratio_r_t_fz(t)=per_60_r_t(t)/per_18_59_r_t(t);
    
    dep_ratio_t_fz_nomig(t)=per_60_t_nomig(t)/per_18_59_t_nomig(t);
    dep_ratio_u_t_fz_nomig(t)=per_60_u_t_nomig(t)/per_18_59_u_t_nomig(t);
    dep_ratio_r_t_fz_nomig(t)=per_60_r_t_nomig(t)/per_18_59_r_t_nomig(t);
       
    dep_ratio_old_t(t)=per_65_t(t)/per_15_64_t(t);
    dep_ratio_old_u_t(t)=per_65_u_t(t)/per_15_64_u_t(t);
    dep_ratio_old_r_t(t)=per_65_r_t(t)/per_15_64_r_t(t);
end


y1_fig=dep_ratio_u_t_fz(1:t_fig);
y12_fig=dep_ratio_u_t_fz_nomig(1:t_fig);
y2_fig=dep_ratio_r_t_fz(1:t_fig);
y22_fig=dep_ratio_r_t_fz_nomig(1:t_fig);
width_line=3;

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
plot(x_fig,y1_fig,'LineWidth',width_line);
hold on
plot(x_fig,y12_fig,'-.','LineWidth',width_line);
hold on
plot(x_fig,y2_fig,'color','black','LineWidth',width_line);
hold on
plot(x_fig,y22_fig,'-.','color','black','LineWidth',width_line);
hold off
% axis('tight')
% axis([x_fig(1) x_fig(length(x_fig)) 0 1.1*max(dep_ratio_old_t(1:t_fig))])
% axis([x_fig(1) x_fig(length(x_fig)) 0 0.5])
xlabel('Year')
ylabel('Ratio Population 60+ / Population 18-59')

x_text=2035;
x2_text=2035;
x22_text=2052;
i_x_text=x_text-x_fig(1)+1;
i_x2_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text)-0.01;
y12_text=y12_fig(i_x2_text)+0.2;
y22_text=y22_fig(i_x_text)-0.02;
dev_y22_text=0.1;
text(x_text,y1_text,'Urban', 'VerticalAlignment','top');
text(x_text,y2_text,'Rural','VerticalAlignment','top');
text(x2_text,y12_text,'Urban (counterfactual)', 'VerticalAlignment','bottom');
text(x22_text,y22_text-dev_y22_text,' Rural (counterfactual)','VerticalAlignment','middle');
[figx figy]=dsxy2figxy([x22_text-1 x_text+1],[y22_text-dev_y22_text+0.02 y22_text]);
% [figx figy]=dsxy2figxy([x_text x22_text],[y22_text y22_text]);
annotation('arrow', figx, figy)


print( '-dpng', '-r300', ['old_dependency_notitle.png']);
print( '-depsc2', ['old_dependency_notitle.eps']);

title('\fontsize{14} Projected Old-age Dependency Ratios')
print( '-dpng', '-r300', ['old_dependency.png']);
print( '-depsc2', ['old_dependency.eps']);



%% ------------------------- 2. Calibration ------------------------

% -------- actual replacement rate ------------------
load('../Pension1_BaselineScenario/data_benchmark')
t_fig=16;
x_fig=year_start:year_start+t_fig-1;
replace_actual_t(1:t_dyn)=pension_total_t(1:t_dyn)./Nw_retire_p_t(1:t_dyn)./p_base_t(1:t_dyn);
y_fig=replace_actual_t(1:t_fig);

width_line=3;

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
% semilogy(x_fig,100*(1+g).^([1:t_fig]-1).*ave_yw_netprod_t(1:t_fig)./ave_yw_netprod_t(1),'LineWidth',width_line);
plot(x_fig,y_fig,'LineWidth',width_line);

% set(gca,'YTick',[100,200,400,800,1600,3200])
xlabel('Year')
title('\fontsize{14} Actual Replacement Rate')
axis tight


print -dpng 'replacement_rate_actual.png'
print( '-depsc2', 'replacement_rate_actual.eps');





%% -------- labor earning

load('../Pension1_BaselineScenario/data_benchmark')

t_wage1=t_2013;
t_wage2=t_2031;
t_wage3=t_2040;

    
g_w_step_t(1:t_wage1)=growth_w_0013;
g_w_step_t(t_wage1+1:t_wage2)=growth_w_1331;
g_w_step_t(t_wage2+1:t_wage3)=growth_w_3140;
g_w_step_t(t_wage3+1:t_dyn)=0;
    
w_step_t(1)=w_t(1);
for t=2:t_dyn
    w_step_t(t)=w_step_t(t-1)*(1+g_w_step_t(t));
end


t_fig=101;
x_fig=year_start:year_start+t_fig-1;
y1_fig=100*(1+g).^([1:t_fig]-1).*w_t(1:t_fig)./w_t(1);
y2_fig=100*(1+g).^([1:t_fig]-1).*w_step_t(1:t_fig)./w_step_t(1);

width_line=3;

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
semilogy(x_fig,y1_fig,'-.','color','r','LineWidth',width_line);
hold on
semilogy(x_fig,y2_fig,'color','b','LineWidth',width_line);
set(gca,'YTick',[100,200,400,800,1600,3200])
xlabel('Year')
ylabel('Wage Rate (Log Scale)')
axis tight


print -dpng 'wage_notitle.png'
print( '-depsc2', ['wage_notitle.eps']);
title('\fontsize{14} Wage Rate Conditional on Human Capital')

print -dpng 'wage.png'
print( '-depsc2', ['wage.eps']);


%%  ------------ wage rate: rural urban

load('../Pension1_BaselineScenario/data_benchmark')
    


t_fig=101;
x_fig=year_start:year_start+t_fig-1;
y1_fig=100*(1+g).^([1:t_fig]-1).*wr_t(1:t_fig)./wr_t(1);
y2_fig=100*(1+g).^([1:t_fig]-1).*w_t(1:t_fig)./wr_t(1);
width_line=3;

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
semilogy(x_fig,y1_fig,'LineWidth',width_line);
set(gca,'YTick',[100,200,400,800,1600,3200])
hold on
semilogy(x_fig,y2_fig,'-.','LineWidth',width_line);
set(gca,'YTick',[100,200,400,800,1600,3200])
xlabel('Year')
ylabel('Wage Rate (Log Scale)')

axis tight
x_text=2035;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text);
text(x_text,y1_text,'Rural', 'VerticalAlignment','top');
text(x_text,y2_text,'Urban','VerticalAlignment','top');

print -dpng 'wage_rate_ruralurban_notitle.png'
print( '-depsc2', ['wage_rate_ruralurban_notitle.eps']);

title('\fontsize{14} Wage Rate in Rural and Urban Sectors')
print -dpng 'wage_rate_ruralurban.png'
print( '-depsc2', ['wage_rate_ruralurban.eps']);



%% ----------------------- 3. Pension Reforms ----------------------


% delayed reform
    load('../Pension1_BaselineScenario/data_delayedreform')
    name_data_2000='../Pension1_BaselineScenario/data_benchmark';
    name_data_compare='../Pension1_BaselineScenario/data_benchmark_2013';


for t_fig=[111]


pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])

subplot(3,1,1)
coh_fig=139;
if year_start==2000
    x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    plot(x_fig,replace_w_coh(1:coh_fig),'LineWidth',2)
    axis([x_fig(1) x_fig(coh_fig) 0.2 0.8]);
elseif year_start==2013
%     load(name_data_2000,'replace_w_coh_bm');
    bm2=load(name_data_compare,'replace_w_coh');
    year_start_bm=2000;
    dif_year=year_start-year_start_bm;
%     x_fig=year_start_bm-(J-Jw):year_start_bm-(J-Jw)+coh_fig-1;
%     y1_fig=[replace_w_coh_bm(1:dif_year) replace_w_coh(1:coh_fig-dif_year)];
%     y2_fig=[replace_w_coh_bm(1:dif_year) bm2.replace_w_coh(1:coh_fig-dif_year)];
    x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    y1_fig=[replace_w_coh(1:coh_fig)];
    y2_fig=[bm2.replace_w_coh(1:coh_fig)];
    width_line=2;
%     x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
    hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
    plot(x_fig,y2_fig,'-.','LineWidth',width_line)
    hold off
    axis([x_fig(1) x_fig(coh_fig) 0.2 0.8]);
    % axis('tight');
    if strcmp(fig_name,'fullyfunded')==1 || strcmp(fig_name,'fullyfunded_ruralpension')==1;
        axis([x_fig(1) x_fig(coh_fig) 0 0.8]);
    end
end
xlabel('Year of Retirement')
title(['\fontsize{10} Panel a: Replacement Rate by Year of Retirement'])
% temp=[x_fig;replace_w_coh(1:coh_fig)]; % 1997 and 2012

subplot(3,1,2)
if year_start==2000
    x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,tax_total_t(1:t_fig)./Y_t(1:t_fig),'LineWidth',2)
%     plot(x_fig,tax_total_t(1:t_fig)./Yur_t(1:t_fig),'LineWidth',2)
    plot(x_fig,(tax_total_t(1:t_fig)+tax_total_r_t(1:t_fig))./Yw_t(1:t_fig),'LineWidth',2)
    hold on 
%     plot(x_fig,pension_total_t(1:t_fig)./Y_t(1:t_fig),'color','k','LineWidth',2)
%     plot(x_fig,pension_total_t(1:t_fig)./Yur_t(1:t_fig),'color','k','LineWidth',2)
    plot(x_fig,(pension_total_t(1:t_fig)+pension_total_r_t(1:t_fig))./Yw_t(1:t_fig),'color','k','LineWidth',2)
    hold off
elseif year_start==2013
    bm=load(name_data_2000,'tax_total_t','Yw_t','pension_total_t','pension_total_r_t');
    bm2=load(name_data_compare,'tax_total_t','Yw_t','pension_total_t','pension_total_r_t');
       
    x_fig=year_start_bm:year_start_bm+t_fig-1;
    y1_fig=[bm.tax_total_t(1:dif_year)./bm.Yw_t(1:dif_year) (tax_total_t(1:t_fig-dif_year)+tax_total_r_t(1:t_fig-dif_year))./Yw_t(1:t_fig-dif_year)];
    y2_fig=[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (pension_total_t(1:t_fig-dif_year)+pension_total_r_t(1:t_fig-dif_year))./Yw_t(1:t_fig-dif_year)];
    y22_fig=[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (bm2.pension_total_t(1:t_fig-dif_year)+bm2.pension_total_r_t(1:t_fig-dif_year))./bm2.Yw_t(1:t_fig-dif_year)];
    width_line=2;
    
%     x_fig=year_start:year_start+t_fig-1;
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ (tax_total_t(1:t_fig)+tax_total_r_t(1:t_fig))./Yw_t(1:t_fig)],'LineWidth',2)
    hold on
%     plot(x_fig,tax_total_t_bm(1:t_fig)./Yw_t_bm(1:t_fig),'-.','LineWidth',2)
%     hold on
    plot(x_fig,y2_fig,'color','k','LineWidth',width_line)
%     plot(x_fig,[ (pension_total_t(1:t_fig)+pension_total_r_t(1:t_fig))./Yw_t(1:t_fig)],'color','k','LineWidth',2)
    hold on
%     plot(x_fig,[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (bm2.pension_total_t(1:t_fig-dif_year)+bm2.pension_total_r_t(1:t_fig-dif_year))./bm2.Yw_t(1:t_fig-dif_year)],'-.','color','k','LineWidth',2)
    plot(x_fig,y22_fig,'-.','color','k','LineWidth',width_line)
    hold off
end
hold off
% axis( 'auto y')
% axis([year_start year_start+t_fig-1 0.1 1]);
axis([x_fig(1) x_fig(t_fig) min(y2_fig)-0.01 max(y2_fig)+0.03]);
xlabel('Year')
% title('Tax Revenue / Urban GDP and Pension Payments / Urban GDP')
x1_text=2015;
x2_text=2050;
x22_text=2040;
i1_x_text=x1_text-x_fig(1)+1;
i2_x_text=x2_text-x_fig(1)+1;
i22_x_text=x22_text-x_fig(1)+1;
y1_text=y1_fig(i1_x_text);
y2_text=y2_fig(i2_x_text)+0.01;
y22_text=y22_fig(i22_x_text);
text(x1_text,y1_text,'Tax revenue', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Expenditures (Delayed Reform)','VerticalAlignment','bottom');
text(x22_text,y22_text,'Expenditures (Benchmark Reform)','VerticalAlignment','top');
title('\fontsize{10} Panel b: Tax Revenue and Pension Expenditures as Shares of Urban Earnings')

subplot(3,1,3)
if year_start==2000
    x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,gov_debt_t(1:t_fig)./Y_t(1:t_fig),'LineWidth',2)
%     plot(x_fig,gov_debt_t(1:t_fig)./Yur_t(1:t_fig),'LineWidth',2)
    plot(x_fig,gov_debt_t(1:t_fig)./Yw_t(1:t_fig),'LineWidth',2)
elseif year_start==2013
    bm=load(name_data_2000,'gov_debt_t','Yw_t');
    bm2=load(name_data_compare,'gov_debt_t','Yw_t');
    x_fig=year_start_bm:year_start_bm+t_fig-1;
    y1_fig=[bm.gov_debt_t(1:dif_year)./bm.Yw_t(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Yw_t(1:t_fig-dif_year)];
    y2_fig=[bm.gov_debt_t(1:dif_year)./bm.Yw_t(1:dif_year) bm2.gov_debt_t(1:t_fig-dif_year)./bm2.Yw_t(1:t_fig-dif_year)];
%     x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,[gov_debt_t_bm(1:dif_year)./Y_t_bm(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Y_t(1:t_fig-dif_year)],'LineWidth',2)
%     plot(x_fig,[gov_debt_t_bm(1:dif_year)./Yur_t_bm(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Yur_t(1:t_fig-dif_year)],'LineWidth',2)
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ gov_debt_t(1:t_fig)./Yw_t(1:t_fig)],'LineWidth',2)
    hold on
        plot(x_fig,y2_fig,'-.','LineWidth',width_line)
%     plot(x_fig,[ bm2.gov_debt_t(1:t_fig)./bm2.Yw_t(1:t_fig)],'-.','LineWidth',2)
    hold off
end
% axis( 'auto y')
% axis([year_start year_start+t_fig-1])
axis('tight');
xlabel('Year')
title('\fontsize{10} Panel c: Government Debt as a Share of Urban Earnings')
x_text=2065;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text);
text(x_text,y1_text,['Debt (' initialcaps(name_fig_title2) ')'], 'VerticalAlignment','top');
text(x_text,y2_text,'Debt (Benchmark Reform)','VerticalAlignment','bottom');

print('-dpng','-r300',['pension_' fig_name  '.png'])
print('-depsc2',['pension_' fig_name '.eps'])


end 

%% ---- delayed reform optimal year loop ------------

 load('../Pension1_BaselineScenario/data_loop_t_reform')
figure

x_fig=grid_reform(1:n_reform);
y1_fig=(ev_p_sum_t_reform(1:n_fig))*100;
y2_fig=(ev_p_sum_rg_t_reform(1:n_fig))*100;

plot(x_fig,y1_fig,'color','b','LineWidth',2);
hold on
plot(x_fig,y2_fig,'-.','color','b','LineWidth',2);
hold off
axis tight

x_text=2065;
i_x_text=find(x_fig>=x_text,1,'first');
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text);
text(x_text,y1_text,['High Discount Rate'], 'VerticalAlignment','top');
text(x_text,y2_text,'Low Discount Rate','VerticalAlignment','bottom');

xlabel('Period T of Reform Implementation')
ylabel('Welfare Gain \omega (in Percent)')
% gtext({'High Discount Rate';'Low Discount Rate'})


print( '-dpng', '-r300', ['equivalence_variation_t_reform_notitle.png']);
print( '-depsc2', ['equivalence_variation_t_reform_notitle.eps']);


title(['Welfare Gains of Delaying the Reform (Utilitarian Planner)'])
print( '-dpng', '-r300', ['equivalence_variation_t_reform.png']);
print( '-depsc2', ['equivalence_variation_t_reform.eps']);

%%  delayed reform 2100
load('../Pension1_BaselineScenario/data_delayedreform_2100')
name_data_2000='../Pension1_BaselineScenario/data_benchmark';
name_data_compare='../Pension1_BaselineScenario/data_benchmark_2013';


for t_fig=[111]


pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])

subplot(3,1,1)
coh_fig=139;
if year_start==2000
    x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    plot(x_fig,replace_w_coh(1:coh_fig),'LineWidth',2)
    axis([x_fig(1) x_fig(coh_fig) 0.2 0.8]);
elseif year_start==2013
    load(name_data_2000,'replace_w_coh_bm');
    bm2=load(name_data_compare,'replace_w_coh');
    year_start_bm=2000;
    dif_year=year_start-year_start_bm;
%     x_fig=year_start_bm-(J-Jw):year_start_bm-(J-Jw)+coh_fig-1;
%     y1_fig=[replace_w_coh_bm(1:dif_year) replace_w_coh(1:coh_fig-dif_year)];
%     y2_fig=[replace_w_coh_bm(1:dif_year) bm2.replace_w_coh(1:coh_fig-dif_year)];
    x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    y1_fig=[replace_w_coh(1:coh_fig)];
    y2_fig=[bm2.replace_w_coh(1:coh_fig)];
    width_line=2;
%     x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
    hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
    plot(x_fig,y2_fig,'-.','LineWidth',width_line)
    hold off
    axis([x_fig(1) x_fig(coh_fig) 0.2 0.8]);
    % axis('tight');
    if strcmp(fig_name,'fullyfunded')==1 || strcmp(fig_name,'fullyfunded_ruralpension')==1;
        axis([x_fig(1) x_fig(coh_fig) 0 0.8]);
    end
end
xlabel('Year of Retirement')
title(['\fontsize{10} Panel a: Replacement Rate by Year of Retirement'])
%temp=[x_fig;replace_w_coh(1:coh_fig)]; % 1997 and 2012

subplot(3,1,2)
if year_start==2000
    x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,tax_total_t(1:t_fig)./Y_t(1:t_fig),'LineWidth',2)
%     plot(x_fig,tax_total_t(1:t_fig)./Yur_t(1:t_fig),'LineWidth',2)
    plot(x_fig,(tax_total_t(1:t_fig)+tax_total_r_t(1:t_fig))./Yw_t(1:t_fig),'LineWidth',2)
    hold on 
%     plot(x_fig,pension_total_t(1:t_fig)./Y_t(1:t_fig),'color','k','LineWidth',2)
%     plot(x_fig,pension_total_t(1:t_fig)./Yur_t(1:t_fig),'color','k','LineWidth',2)
    plot(x_fig,(pension_total_t(1:t_fig)+pension_total_r_t(1:t_fig))./Yw_t(1:t_fig),'color','k','LineWidth',2)
    hold off
elseif year_start==2013
    bm=load(name_data_2000,'tax_total_t','Yw_t','pension_total_t','pension_total_r_t');
    bm2=load(name_data_compare,'tax_total_t','Yw_t','pension_total_t','pension_total_r_t');
       
    x_fig=year_start_bm:year_start_bm+t_fig-1;
    y1_fig=[bm.tax_total_t(1:dif_year)./bm.Yw_t(1:dif_year) (tax_total_t(1:t_fig-dif_year)+tax_total_r_t(1:t_fig-dif_year))./Yw_t(1:t_fig-dif_year)];
    y2_fig=[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (pension_total_t(1:t_fig-dif_year)+pension_total_r_t(1:t_fig-dif_year))./Yw_t(1:t_fig-dif_year)];
    y22_fig=[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (bm2.pension_total_t(1:t_fig-dif_year)+bm2.pension_total_r_t(1:t_fig-dif_year))./bm2.Yw_t(1:t_fig-dif_year)];
    
%     x_fig=year_start:year_start+t_fig-1;
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ (tax_total_t(1:t_fig)+tax_total_r_t(1:t_fig))./Yw_t(1:t_fig)],'LineWidth',2)
    hold on
%     plot(x_fig,tax_total_t_bm(1:t_fig)./Yw_t_bm(1:t_fig),'-.','LineWidth',2)
%     hold on
    plot(x_fig,y2_fig,'color','k','LineWidth',width_line)
%     plot(x_fig,[ (pension_total_t(1:t_fig)+pension_total_r_t(1:t_fig))./Yw_t(1:t_fig)],'color','k','LineWidth',2)
    hold on
%     plot(x_fig,[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (bm2.pension_total_t(1:t_fig-dif_year)+bm2.pension_total_r_t(1:t_fig-dif_year))./bm2.Yw_t(1:t_fig-dif_year)],'-.','color','k','LineWidth',2)
    plot(x_fig,y22_fig,'-.','color','k','LineWidth',width_line)
    hold off
end
hold off
% axis( 'auto y')
% axis([year_start year_start+t_fig-1 0.1 1]);
% axis('tight');
axis([x_fig(1) x_fig(t_fig) min(y2_fig)-0.01 max(y2_fig)+0.05]);
xlabel('Year')
% title('Tax Revenue / Urban GDP and Pension Payments / Urban GDP')
x1_text=2015;
x2_text=2060;
x22_text=2045;
i1_x_text=x1_text-x_fig(1)+1;
i2_x_text=x2_text-x_fig(1)+1;
i22_x_text=x22_text-x_fig(1)+1;
y1_text=y1_fig(i1_x_text);
y2_text=y2_fig(i2_x_text)+0.06;
y22_text=y22_fig(i22_x_text);
text(x1_text,y1_text,'Tax revenue', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Expenditures (Delayed Reform until 2100)','VerticalAlignment','top');
text(x22_text,y22_text,'Expenditures (Benchmark Reform)','VerticalAlignment','top');
title('\fontsize{10} Panel b: Tax Revenue and Pension Expenditures as Shares of Urban Earnings')


subplot(3,1,3)
if year_start==2000
    x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,gov_debt_t(1:t_fig)./Y_t(1:t_fig),'LineWidth',2)
%     plot(x_fig,gov_debt_t(1:t_fig)./Yur_t(1:t_fig),'LineWidth',2)
    plot(x_fig,gov_debt_t(1:t_fig)./Yw_t(1:t_fig),'LineWidth',2)
elseif year_start==2013
    bm=load(name_data_2000,'gov_debt_t','Yw_t');
    bm2=load(name_data_compare,'gov_debt_t','Yw_t');
    x_fig=year_start_bm:year_start_bm+t_fig-1;
    y1_fig=[bm.gov_debt_t(1:dif_year)./bm.Yw_t(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Yw_t(1:t_fig-dif_year)];
    y2_fig=[bm.gov_debt_t(1:dif_year)./bm.Yw_t(1:dif_year) bm2.gov_debt_t(1:t_fig-dif_year)./bm2.Yw_t(1:t_fig-dif_year)];
%     x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,[gov_debt_t_bm(1:dif_year)./Y_t_bm(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Y_t(1:t_fig-dif_year)],'LineWidth',2)
%     plot(x_fig,[gov_debt_t_bm(1:dif_year)./Yur_t_bm(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Yur_t(1:t_fig-dif_year)],'LineWidth',2)
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ gov_debt_t(1:t_fig)./Yw_t(1:t_fig)],'LineWidth',2)
    hold on
        plot(x_fig,y2_fig,'-.','LineWidth',width_line)
%     plot(x_fig,[ bm2.gov_debt_t(1:t_fig)./bm2.Yw_t(1:t_fig)],'-.','LineWidth',2)
    hold off
end
% axis( 'auto y')
% axis([year_start year_start+t_fig-1])
axis('tight');
xlabel('Year')
title('\fontsize{10} Panel c: Government Debt as a Share of Urban Earnings')
x_text=2073;
x2_text=2065;
i_x_text=x_text-x_fig(1)+1;
i2_x_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text)+0.1;
y2_text=y2_fig(i_x_text);
text(x_text,y1_text,['Debt (Delayed Reform until 2100)'], 'VerticalAlignment','top');
text(x2_text,y2_text,'Debt (Benchmark Reform)','VerticalAlignment','bottom');

print('-dpng','-r300',['pension_' fig_name  '.png'])
print('-depsc2',['pension_' fig_name '.eps'])

end 

%% ------- fully funded
load('../Pension1_BaselineScenario/data_fullyfunded')
name_data_2000='../Pension1_BaselineScenario/data_benchmark';
name_data_compare='../Pension1_BaselineScenario/data_benchmark_2013';


for t_fig=[111]


pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])

width_line=2;
subplot(2,1,1)
if year_start==2000
    x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,tax_total_t(1:t_fig)./Y_t(1:t_fig),'LineWidth',2)
%     plot(x_fig,tax_total_t(1:t_fig)./Yur_t(1:t_fig),'LineWidth',2)
    plot(x_fig,(tax_total_t(1:t_fig)+tax_total_r_t(1:t_fig))./Yw_t(1:t_fig),'LineWidth',2)
    hold on 
%     plot(x_fig,pension_total_t(1:t_fig)./Y_t(1:t_fig),'color','k','LineWidth',2)
%     plot(x_fig,pension_total_t(1:t_fig)./Yur_t(1:t_fig),'color','k','LineWidth',2)
    plot(x_fig,(pension_total_t(1:t_fig)+pension_total_r_t(1:t_fig))./Yw_t(1:t_fig),'color','k','LineWidth',2)
    hold off
elseif year_start==2013
    bm=load(name_data_2000,'tax_total_t','Yw_t','pension_total_t','pension_total_r_t');
    bm2=load(name_data_compare,'tax_total_t','Yw_t','pension_total_t','pension_total_r_t');
       
    x_fig=year_start_bm:year_start_bm+t_fig-1;
    y1_fig=[bm.tax_total_t(1:dif_year)./bm.Yw_t(1:dif_year) (tax_total_t(1:t_fig-dif_year)+tax_total_r_t(1:t_fig-dif_year))./Yw_t(1:t_fig-dif_year)];
    y2_fig=[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (pension_total_t(1:t_fig-dif_year)+pension_total_r_t(1:t_fig-dif_year))./Yw_t(1:t_fig-dif_year)];
    y22_fig=[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (bm2.pension_total_t(1:t_fig-dif_year)+bm2.pension_total_r_t(1:t_fig-dif_year))./bm2.Yw_t(1:t_fig-dif_year)];
    
%     x_fig=year_start:year_start+t_fig-1;
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ (tax_total_t(1:t_fig)+tax_total_r_t(1:t_fig))./Yw_t(1:t_fig)],'LineWidth',2)
    hold on
%     plot(x_fig,tax_total_t_bm(1:t_fig)./Yw_t_bm(1:t_fig),'-.','LineWidth',2)
%     hold on
    plot(x_fig,y2_fig,'color','k','LineWidth',width_line)
%     plot(x_fig,[ (pension_total_t(1:t_fig)+pension_total_r_t(1:t_fig))./Yw_t(1:t_fig)],'color','k','LineWidth',2)
    hold on
%     plot(x_fig,[(bm.pension_total_t(1:dif_year)+bm.pension_total_r_t(1:dif_year))./bm.Yw_t(1:dif_year) (bm2.pension_total_t(1:t_fig-dif_year)+bm2.pension_total_r_t(1:t_fig-dif_year))./bm2.Yw_t(1:t_fig-dif_year)],'-.','color','k','LineWidth',2)
    plot(x_fig,y22_fig,'-.','color','k','LineWidth',width_line)
    hold off
end
hold off
% axis( 'auto y')
% axis([year_start year_start+t_fig-1 0.1 1]);
axis('tight');
xlabel('Year')
% title('Tax Revenue / Urban GDP and Pension Payments / Urban GDP')
x1_text=2010;
x2_text=2060;
i1_x_text=x1_text-x_fig(1)+1;
i2_x_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i1_x_text);
y2_text=y2_fig(i2_x_text);
y22_text=y22_fig(i2_x_text);
text(x1_text,y1_text,'Tax revenue', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Expenditures (FF Reform)','VerticalAlignment','bottom');
text(x2_text,y22_text,'Expenditures (Benchmark Reform)','VerticalAlignment','top');
title('\fontsize{10} Panel a: Tax Revenue and Pension Expenditures as Shares of Urban Earnings')


subplot(2,1,2)
if year_start==2000
    x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,gov_debt_t(1:t_fig)./Y_t(1:t_fig),'LineWidth',2)
%     plot(x_fig,gov_debt_t(1:t_fig)./Yur_t(1:t_fig),'LineWidth',2)
    plot(x_fig,gov_debt_t(1:t_fig)./Yw_t(1:t_fig),'LineWidth',2)
elseif year_start==2013
    bm=load(name_data_2000,'gov_debt_t','Yw_t');
    bm2=load(name_data_compare,'gov_debt_t','Yw_t');
    x_fig=year_start_bm:year_start_bm+t_fig-1;
    y1_fig=[bm.gov_debt_t(1:dif_year)./bm.Yw_t(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Yw_t(1:t_fig-dif_year)];
    y2_fig=[bm.gov_debt_t(1:dif_year)./bm.Yw_t(1:dif_year) bm2.gov_debt_t(1:t_fig-dif_year)./bm2.Yw_t(1:t_fig-dif_year)];
%     x_fig=year_start:year_start+t_fig-1;
%     plot(x_fig,[gov_debt_t_bm(1:dif_year)./Y_t_bm(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Y_t(1:t_fig-dif_year)],'LineWidth',2)
%     plot(x_fig,[gov_debt_t_bm(1:dif_year)./Yur_t_bm(1:dif_year) gov_debt_t(1:t_fig-dif_year)./Yur_t(1:t_fig-dif_year)],'LineWidth',2)
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ gov_debt_t(1:t_fig)./Yw_t(1:t_fig)],'LineWidth',2)
    hold on
        plot(x_fig,y2_fig,'-.','LineWidth',width_line)
%     plot(x_fig,[ bm2.gov_debt_t(1:t_fig)./bm2.Yw_t(1:t_fig)],'-.','LineWidth',2)
    hold off
end
% axis( 'auto y')
% axis([year_start year_start+t_fig-1])
axis('tight');
xlabel('Year')
title('\fontsize{10} Panel b: Government Debt as a Share of Urban Earnings')
x_text=2070;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text);
text(x_text,y1_text,['Debt (' initialcaps(name_fig_title2) ')'], 'VerticalAlignment','top');
text(x_text,y2_text,'Debt (Benchmark Reform)','VerticalAlignment','bottom');

print('-dpng','-r300',['pension_' fig_name  '.png'])
print('-depsc2',['pension_' fig_name '.eps'])

end 

%% ----------- PAYGO 


load('../Pension1_BaselineScenario/data_paygo')
name_data_2000='../Pension1_BaselineScenario/data_benchmark';
name_data_compare='../Pension1_BaselineScenario/data_benchmark_2013';


t_fig=111;

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])

subplot(2,1,1)
if year_start==2013
    bm=load(name_data_2000,'replace_w_coh','pension_total_t','tax_total_t','Nw_labor_p_t','Nw_retire_p_t','tau_w_t');
    bm2=load(name_data_compare,'replace_w_coh','pension_total_t','tax_total_t','Nw_labor_p_t','Nw_retire_p_t','tau_w_t');
    % year specific replacement rate
    bm.replace_w_t(1:t_dyn)=(bm.pension_total_t(1:t_dyn)./bm.Nw_retire_p_t(1:t_dyn))./(bm.tax_total_t(1:t_dyn)./bm.tau_w_t(1:t_dyn)./bm.Nw_labor_p_t(1:t_dyn));
    bm2.replace_w_t(1:t_dyn)=(bm2.pension_total_t(1:t_dyn)./bm2.Nw_retire_p_t(1:t_dyn))./(bm2.tax_total_t(1:t_dyn)./bm2.tau_w_t(1:t_dyn)./bm2.Nw_labor_p_t(1:t_dyn));
    year_start_bm=2000;
    dif_year=year_start-year_start_bm;
    x_fig=year_start_bm:year_start_bm+t_fig-1;
    y1_fig=[bm.replace_w_t(1:dif_year) replace_w_t(1:t_fig-dif_year)];
    y2_fig=[bm.replace_w_t(1:dif_year) bm2.replace_w_t(1:t_fig-dif_year)];
    width_line=2;
    plot(x_fig,y1_fig,'LineWidth',width_line)
    hold on
    plot(x_fig,y2_fig,'-.','LineWidth',width_line)
    hold off
    axis([x_fig(1) x_fig(t_fig) 0 1.5]);
%     axis tight;
end
x_text=2026;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text);
text(x_text,y1_text,'PAYGO', 'VerticalAlignment','bottom');
text(x_text,y2_text,'Benchmark','VerticalAlignment','bottom');
xlabel('Year')
title(['Panel a: Pension Payment / Labor Earnings by Year'])
temp=[x_fig;replace_w_t(1:t_fig)]; % 1997 and 2012

subplot(2,1,2)
% present value of pension as a ratio of the year retire

if year_start==2013
    bm2=load(name_data_compare,'pw_sum_coh','p_base_pre_t','p_base_t');
    bm2.p_base_retire_coh=[bm2.p_base_pre_t(T_pre-J+Jw:T_pre) bm2.p_base_t(1:t_dyn)];
    bm=load(name_data_2000,'pw_sum_coh','p_base_pre_t','p_base_t','year_start');
    diff_year=year_start-bm.year_start;
    p_base_retire_coh=[p_base_pre_t(T_pre-J+Jw:T_pre) p_base_t(1:t_dyn)];
        
    coh_fig=151-diff_year;
    x_fig=year_start-J+Jw:year_start-J+Jw+coh_fig-1;
    y1_fig=[pw_sum_coh(1:coh_fig)./p_base_retire_coh(1:coh_fig)];
    y2_fig=[bm2.pw_sum_coh(1:coh_fig)./bm2.p_base_retire_coh(1:coh_fig)];
    plot(x_fig,y1_fig,'LineWidth',width_line)
    hold on
    plot(x_fig,y2_fig,'-.','LineWidth',width_line)
    hold off
    axis([x_fig(1) x_fig(coh_fig) 0 ceil(max(pw_sum_coh(1:coh_fig)./p_base_retire_coh(1:coh_fig))/10)*10]);
%     axis('tight');
    x_text=2002;
    i_x_text=x_text-x_fig(1)+1;
    y1_text=y1_fig(i_x_text);
    y2_text=y2_fig(i_x_text);
    text(x_text,y1_text+1,'PAYGO', 'VerticalAlignment','bottom');
    text(x_text,y2_text,'Benchmark','VerticalAlignment','bottom');
end
xlabel('Year of Retirement')
title(['Panel b: Lifetime Pension / Average Labor Earnings in the Year of Retirement, by Cohort'])


print('-dpng','-r300',['pension_' fig_name  '.png'])
print('-depsc2',['pension_' fig_name '.eps'])




%% ------------------- Welfare Gain: Ramsey ------------------


load('../Pension1_BaselineScenario/data_Ramsey_FB','ev_p_coh','ev_np_coh','year_start','J','Jw','year_reform');
dr=load('../Pension1_BaselineScenario/data_delayedreform','ev_p_coh');
ff=load('../Pension1_BaselineScenario/data_fullyfunded','ev_p_coh');
pg=load('../Pension1_BaselineScenario/data_paygo','ev_p_coh');
    
figure
pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
year_fig_start=year_start+(Jw-J);
t_fig=1+2115-year_fig_start;
coh_fig_start=1+(J-Jw)+(year_fig_start-year_start);
x_fig=year_fig_start:year_fig_start+t_fig-1;
y1_fig=(ev_p_coh(coh_fig_start:coh_fig_start+t_fig-1))*100;
y2_fig=(dr.ev_p_coh(coh_fig_start:coh_fig_start+t_fig-1))*100;
y3_fig=(ff.ev_p_coh(coh_fig_start:coh_fig_start+t_fig-1))*100;
y4_fig=(pg.ev_p_coh(coh_fig_start:coh_fig_start+t_fig-1))*100;

plot(x_fig,y1_fig,'LineWidth',2)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
plot(x_fig,y2_fig,'-.','LineWidth',2,'color','r')
hold on
plot(x_fig,y3_fig,':','LineWidth',2,'color','k')
hold on
plot(x_fig,y4_fig,'-.','LineWidth',2,'color','magenta')
hold on
plot(x_fig,zeros(1,t_fig),':','color','k','LineWidth',1)
hold off
axis([x_fig(1) x_fig(length(x_fig)) -20 120]);
x_text=2020;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text)-5;
y2_text=y2_fig(i_x_text);
y3_text=y3_fig(i_x_text);
y4_text=y4_fig(i_x_text);
text(x_text,y1_text,'First Best', 'VerticalAlignment','top');
text(x_text,y2_text,'Delayed Reform','VerticalAlignment','bottom');
text(x_text,y3_text-5,'Fully Funded','VerticalAlignment','top');
text(x_text,y4_text,'PAYGO','VerticalAlignment','bottom');


xlabel('Year of Retirement')
ylabel(['Welfare Gain \omega (in Percent)'])


print('-dpng','-r300',['equivalence_variation_4panel_notitle.png'])
print('-depsc2',['equivalence_variation_4panel_notitle.eps'])

title('Welfare Gain (Equiv. Variation) by Year of Retirement')
print('-dpng','-r300',['equivalence_variation_4panel.png'])
print('-depsc2',['equivalence_variation_4panel.eps'])


%% ------------------- Labor Supply: Ramsey ------------------


load('../Pension1_BaselineScenario/data_Ramsey_FB','H_t','H_p_t','year_start','J','Jw','year_reform');
dr=load('../Pension1_BaselineScenario/data_delayedreform','H_t','H_p_t');
ff=load('../Pension1_BaselineScenario/data_fullyfunded','H_t','H_p_t');
pg=load('../Pension1_BaselineScenario/data_paygo','H_t','H_p_t');
    

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
year_fig_start=year_start;
t_fig=1+2100-year_fig_start;
x_fig=year_fig_start:year_fig_start+t_fig-1;
y1_fig=H_t(coh_fig_start:coh_fig_start+t_fig-1);
y2_fig=dr.H_t(coh_fig_start:coh_fig_start+t_fig-1);
y3_fig=ff.H_t(coh_fig_start:coh_fig_start+t_fig-1);
y4_fig=pg.H_t(coh_fig_start:coh_fig_start+t_fig-1);

plot(x_fig,y1_fig,'LineWidth',2)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
plot(x_fig,y2_fig,'-.','LineWidth',2,'color','r')
hold on
plot(x_fig,y3_fig,':','LineWidth',2,'color','magenta')
hold on
plot(x_fig,y4_fig,'-.','LineWidth',2,'color','k')
% hold on
% plot(x_fig,zeros(1,t_fig),':','color','k','LineWidth',1)
hold off
% axis([x_fig(1) x_fig(length(x_fig)) -20 120]);
axis tight
x1_text=2020;
x2_text=2055;
i_x1_text=x1_text-x_fig(1)+1;
i_x2_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i_x1_text);
y2_text=y2_fig(i_x2_text)-2;
y3_text=y3_fig(i_x1_text)+6e1;
y4_text=y4_fig(i_x2_text)+1;
text(x1_text,y1_text,'First Best', 'VerticalAlignment','top');
text(x2_text,y2_text,'Delayed Reform','VerticalAlignment','top');
text(x1_text,y3_text,'Fully Funded','VerticalAlignment','bottom');
text(x2_text,y4_text,'PAYGO','VerticalAlignment','bottom');


xlabel('Year')
ylabel(['Aggregate Labor Supply'])
title('Aggregate Labor Supply by Year')
print('-dpng','-r300',['H_t_compare.png'])
print('-depsc2',['H_t_compare.eps'])


% ----------- H_p_t --------------

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
year_fig_start=year_start;
t_fig=1+2100-year_fig_start;
x_fig=year_fig_start:year_fig_start+t_fig-1;
y1_fig=H_p_t(coh_fig_start:coh_fig_start+t_fig-1);
y2_fig=dr.H_p_t(coh_fig_start:coh_fig_start+t_fig-1);
y3_fig=ff.H_p_t(coh_fig_start:coh_fig_start+t_fig-1);
y4_fig=pg.H_p_t(coh_fig_start:coh_fig_start+t_fig-1);

plot(x_fig,y1_fig,'LineWidth',2)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
plot(x_fig,y2_fig,'-.','LineWidth',2,'color','r')
hold on
plot(x_fig,y3_fig,':','LineWidth',2,'color','magenta')
hold on
plot(x_fig,y4_fig,'-.','LineWidth',2,'color','k')
% hold on
% plot(x_fig,zeros(1,t_fig),':','color','k','LineWidth',1)
hold off
% axis([x_fig(1) x_fig(length(x_fig)) -20 120]);
axis tight
x1_text=2020;
x2_text=2055;
i_x1_text=x1_text-x_fig(1)+1;
i_x2_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i_x1_text);
y2_text=y2_fig(i_x2_text)-2;
y3_text=y3_fig(i_x1_text)+30;
y4_text=y4_fig(i_x2_text)+1;
text(x1_text,y1_text,'First Best', 'VerticalAlignment','top');
text(x2_text,y2_text,'Delayed Reform','VerticalAlignment','top');
text(x1_text,y3_text,'Fully Funded','VerticalAlignment','bottom');
text(x2_text,y4_text,'PAYGO','VerticalAlignment','bottom');


xlabel('Year')
ylabel(['Labor Supply of Workers with Pension'])
title('Labor Supply of Workers with Pension by Year')
print('-dpng','-r300',['H_p_t_compare.png'])
print('-depsc2',['H_p_t_compare.eps'])


% percentage change, H_t

bm2=load('../Pension1_BaselineScenario/data_benchmark_2013','H_t','H_p_t');


pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
year_fig_start=year_start;
t_fig=1+2100-year_fig_start;
x_fig=year_fig_start:year_fig_start+t_fig-1;
y1_fig=(H_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;
y2_fig=(dr.H_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;
y3_fig=(ff.H_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;
y4_fig=(pg.H_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;

plot(x_fig,y1_fig,'LineWidth',2)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
plot(x_fig,y2_fig,'-.','LineWidth',2,'color','r')
hold on
plot(x_fig,y3_fig,':','LineWidth',2,'color','magenta')
hold on
plot(x_fig,y4_fig,'-.','LineWidth',2,'color','k')
% hold on
% plot(x_fig,zeros(1,t_fig),':','color','k','LineWidth',1)
hold off
% axis([x_fig(1) x_fig(length(x_fig)) -20 120]);
axis tight
x1_text=2060;
x2_text=2060;
i_x1_text=x1_text-x_fig(1)+1;
i_x2_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i_x1_text);
y2_text=y2_fig(i_x2_text);
y3_text=y3_fig(i_x1_text);
y4_text=y4_fig(i_x2_text);
text(x1_text,y1_text,'First Best', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Delayed Reform','VerticalAlignment','top');
text(x1_text,y3_text,'Fully Funded','VerticalAlignment','bottom');
text(x2_text,y4_text,'PAYGO','VerticalAlignment','bottom');


xlabel('Year')
title('Labor Supply Difference from Benchmark, in Percent')
print('-dpng','-r300',['H_t_perc_compare.png'])
print('-depsc2',['H_t_perc_compare.eps'])


% ----------- H_p_t --------------
pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
year_fig_start=year_start;
t_fig=1+2100-year_fig_start;
x_fig=year_fig_start:year_fig_start+t_fig-1;
y1_fig=(H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;
y2_fig=(dr.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;
y3_fig=(ff.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;
y4_fig=(pg.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)-1)*100;

plot(x_fig,y1_fig,'LineWidth',2)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
plot(x_fig,y2_fig,'-.','LineWidth',2,'color','r')
hold on
plot(x_fig,y3_fig,':','LineWidth',2,'color','magenta')
hold on
plot(x_fig,y4_fig,'-.','LineWidth',2,'color','k')
% hold on
% plot(x_fig,zeros(1,t_fig),':','color','k','LineWidth',1)
hold off
% axis([x_fig(1) x_fig(length(x_fig)) -20 120]);
axis tight
x1_text=2060;
x2_text=2060;
i_x1_text=x1_text-x_fig(1)+1;
i_x2_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i_x1_text);
y2_text=y2_fig(i_x2_text);
y3_text=y3_fig(i_x1_text);
y4_text=y4_fig(i_x2_text);
text(x1_text,y1_text,'First Best', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Delayed Reform','VerticalAlignment','top');
text(x1_text,y3_text,'Fully Funded','VerticalAlignment','bottom');
text(x2_text,y4_text,'PAYGO','VerticalAlignment','bottom');


xlabel('Year')
title('Labor Supply of Workers with Pension, Difference from Benchmark, in Percent')
print('-dpng','-r300',['H_p_t_perc_compare.png'])
print('-depsc2',['H_p_t_perc_compare.eps'])



% ----------- ratio, H_p_t --------------
pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
year_fig_start=year_start;
t_fig=1+2100-year_fig_start;
x_fig=year_fig_start:year_fig_start+t_fig-1;
y1_fig=H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1);
y2_fig=dr.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1);
y3_fig=ff.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1);
y4_fig=pg.H_p_t(coh_fig_start:coh_fig_start+t_fig-1)./bm2.H_p_t(coh_fig_start:coh_fig_start+t_fig-1);

plot(x_fig,y1_fig,'LineWidth',2)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
plot(x_fig,y2_fig,'-.','LineWidth',2,'color','r')
hold on
plot(x_fig,y3_fig,':','LineWidth',2,'color','magenta')
hold on
plot(x_fig,y4_fig,'-.','LineWidth',2,'color','k')
% hold on
% plot(x_fig,zeros(1,t_fig),':','color','k','LineWidth',1)
hold off
% axis([x_fig(1) x_fig(length(x_fig)) -20 120]);
axis tight
x1_text=2060;
x2_text=2060;
i_x1_text=x1_text-x_fig(1)+1;
i_x2_text=x2_text-x_fig(1)+1;
y1_text=y1_fig(i_x1_text);
y2_text=y2_fig(i_x2_text);
y3_text=y3_fig(i_x1_text);
y4_text=y4_fig(i_x2_text);
text(x1_text,y1_text,'First Best', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Delayed Reform','VerticalAlignment','top');
text(x1_text,y3_text,'Fully Funded','VerticalAlignment','bottom');
text(x2_text,y4_text,'PAYGO','VerticalAlignment','bottom');


xlabel('Year')
title('Labor Supply of Workers with a Pension Relative to Benchmark Reform (2013-2100). ')
print('-dpng','-r300',['H_p_t_ratio_compare.png'])
print('-depsc2',['H_p_t_ratio_compare.eps'])


%% ---------------------------- Ramsey Figures --------------------------

% delayed reform
load('../Pension1_BaselineScenario/data_Ramsey_FB');
Ramsey=load('../Pension1_BaselineScenario/data_Ramsey','replace_w_coh','ev_p_coh');
Ramsey_2Constraints=load('../Pension1_BaselineScenario/data_Ramsey_2Constraints','replace_w_coh','ev_p_coh');

t_fig=111;

pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])

subplot(2,1,1)

coh_fig=111;
year_retire_start=2000;
coh_start=1+(year_retire_start-(year_start+Jw-J));
x_fig=year_retire_start:year_retire_start+coh_fig-1;
y1_fig=replace_w_coh(coh_start:coh_start+coh_fig-1);
y2_fig=Ramsey.replace_w_coh(coh_start:coh_start+coh_fig-1);
y3_fig=Ramsey_2Constraints.replace_w_coh(coh_start:coh_start+coh_fig-1);

width_line=2;
plot(x_fig,y1_fig,'LineWidth',width_line)
hold on
plot(x_fig,y2_fig,'--','color','r','LineWidth',width_line)
hold on
plot(x_fig,y3_fig,'-.','color','black','LineWidth',width_line)
hold off
axis('tight');
x_text=2010;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text)-1;
y3_text=y3_fig(i_x_text);
text(x_text,y1_text,'First Best', 'VerticalAlignment','bottom');
text(x_text,y2_text,'Ramsey 2nd Best','VerticalAlignment','top');
text(x_text,y3_text,'Ramsey Max 60%','VerticalAlignment','top');

xlabel('Year of Retirement')
title(['\fontsize{10} Panel a: Replacement Rates in Theory-driven Reforms'])

subplot(2,1,2)
y1_fig=(ev_p_coh(coh_start:coh_start+coh_fig-1))*100;
y2_fig=(Ramsey.ev_p_coh(coh_start:coh_start+coh_fig-1))*100;
y3_fig=(Ramsey_2Constraints.ev_p_coh(coh_start:coh_start+coh_fig-1))*100;

width_line=2;
plot(x_fig,y1_fig,'LineWidth',width_line)
hold on
plot(x_fig,y2_fig,'--','color','r','LineWidth',width_line)
hold on
plot(x_fig,y3_fig,'-.','color','black','LineWidth',width_line)
hold off
axis('tight');
xlabel('Year of Retirement')
% ylabel('Welfare Gain \omega (in Percent)');
title(['\fontsize{10} Panel b: Welfare Gains of Theory-driven Reforms'])

x1_text=2040;
x2_text=2020;
x3_text=2020;
i_x1_text=x1_text-x_fig(1)+1;
i_x2_text=x2_text-x_fig(1)+1;
i_x3_text=x3_text-x_fig(1)+1;
y1_text=y1_fig(i_x1_text);
y2_text=y2_fig(i_x2_text)-55;
y3_text=y3_fig(i_x3_text);
text(x1_text,y1_text,'First Best', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Ramsey 2nd Best','VerticalAlignment','top');
text(x3_text,y3_text,'Ramsey Max 60%','VerticalAlignment','top');

print('-dpng','-r300',['pension_theory_driven.png'])
print('-depsc2',['pension_theory_driven.eps'])




%% ------------------------- 4. Other Resutls: GDP etc. --------------------------------
load ('../Pension1_BaselineScenario/data_benchmark')


t_start_data=1;


index_gtext=0;


pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
subplot(2,1,1)

x_fig=year_start:year_start+t_fig-1;
y1_fig(2:t_fig)=g+growth_yur_t_ma(2:t_fig);
y2_fig(2:t_fig)=g+growth_yur_pw_t_ma(2:t_fig);
plot(x_fig(2:t_fig),y1_fig(2:t_fig),'color','b','LineWidth',2);
hold on
plot(x_fig(2:t_fig),y2_fig(2:t_fig),'-.','color','b','LineWidth',2);
hold off
xlabel('Year')
ylabel('Annual Growth Rate')
title('\fontsize{12} Panel a: Growth Rates of GDP per Capita and GDP per Worker')
axis tight
x_text=2020;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text+7);
y2_text=y2_fig(i_x_text);
text(x_text,y1_text,'GDPpc', 'VerticalAlignment','top');
text(x_text,y2_text,'GDPpw','VerticalAlignment','bottom');

subplot(2,1,2)
y1_fig=gdppc_CN2(t_start_data:t_start_data+t_fig-1);
y2_fig=gdppc_US(t_start_data:t_start_data+t_fig-1);
% plot(x_fig,gdppc_CN2(t_start_data:t_start_data+t_fig-1),'LineWidth',2);
semilogy(x_fig,y1_fig,'LineWidth',2);
hold on
% plot(x_fig,gdppc_US(t_start_data:t_start_data+t_fig-1),'-.','LineWidth',2);
semilogy(x_fig,y2_fig,'-.','LineWidth',2);
hold off
set(gca,'YTick',[7500, 15000, 30000, 60000, 120000],'YTickLabel',{'7500', '15000', '30000', '60000', '120000'})
% set(gca,'YTick',[5e3],'YTickLabel',{'5'})
xlabel('Year')
ylabel('GDP per Capita (Log Scale)')
title('\fontsize{12} Panel b: Projected GDP per Capita, US versus China')
axis tight
x_text=2020;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x_text+5);
text(x_text,y1_text,'China', 'VerticalAlignment','top');
text(x_text,y2_text,'USA','VerticalAlignment','bottom');

% mtit('GDP per capita and GDP per worker dynamics','xoff',0,'yoff',0.04)
print( '-dpng', '-r300', ['growth_pc_pw_cn2_us.png']);
print( '-depsc2', ['growth_pc_pw_cn2_us.eps']);



% ratio_gdppc_CN2_US=gdppc_CN2./gdppc_US;

% write to excel
xls_gdppc_growth=[x_fig(2:t_fig)' g+growth_yur_t_ma(2:t_fig)'];
% xlswrite('gdppc_growth.xls', xls_gdppc_growth)


%% ----------------------- Education ----------------------
clearvars -except i_fig index_mac
edu2000=[
2000	2.4326	1930
2000	2.4326	1935
2000	4.2273	1940
2000	5.1129	1945
2000	5.6267	1950
2000	6.2066	1955
2000	7.2279	1960
2000	8.2793	1965
2000	8.4025	1970
2000	8.7528	1975
2000	9.4492	1980
2000	9.4751	1985
];

% year	yr_sch	birthyearto
edu2010=[
2010	4.3405	1940
2010	5.1131	1945
2010	5.6268	1950
2010	6.2055	1955
2010	7.2277	1960
2010	8.2787	1965
2010	8.4101	1970
2010	8.7637	1975
2010	9.4868	1980
2010	10.3744	1985
2010	10.7796	1990
2010	11.1107	1995
];

% cohort with birthyearto represents the cohorts born between birthyearto-4
% to birthyearto, so we say this is the value for cohort born in
% birthyearto-2, and do linear projection for other cohorts
% take cohorts born 1930-1975 from 2000, 1980-1990 from 2010
birthyearto_2000start=1930;
birthyearto_2000end=1975;
step_year=5;
diff_2000_2010=2; % 10 years
n_2000=1+(birthyearto_2000end-birthyearto_2000start)/5;
birthyearto_2010start=birthyearto_2000end+step_year;
birthyearto_2010end=1990;
n_2010=1+(birthyearto_2010end-birthyearto_2010start)/5;

% edu_coh_temp(1,:) saves cohorts' birthyearto
% edu_coh_temp(2,:) saves edu

edu_coh_temp(1,:)=[birthyearto_2000start:step_year:birthyearto_2000end, birthyearto_2010start:step_year:birthyearto_2010end];
% use the middle year birthyearto-2 to represent the cohort
% birthyearto-4:birthyearto
edu_coh_temp(1,:)=edu_coh_temp(1,:)-2;
edu_coh_temp(2,1:n_2000)=edu2000(1:n_2000,2);
edu_coh_temp(2,n_2000+1:n_2000+n_2010)=edu2010(n_2000-diff_2000_2010+1:n_2000-diff_2000_2010+n_2010,2);

% edu_coh_fig(1,:)=birthyearto_2000start-2:birthyearto_2010end-2;
edu_coh_fig(1,:)=birthyearto_2000start:2010;
edu_coh_fig(2,:)=interp1(edu_coh_temp(1,:),edu_coh_temp(2,:),edu_coh_fig(1,:),'linear','extrap');
edu_coh_fig(2,:)=min(edu_coh_fig(2,:),12*ones(1,length(edu_coh_fig(2,:))));


pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])
% scatter(edu_coh_temp(1,:),edu_coh_temp(2,:))
scatter(edu_coh_temp(1,:),edu_coh_temp(2,:),100,'filled')
% scatter(edu_coh_temp(1,:),edu_coh_temp(2,:),'color','b')
hold on
plot(edu_coh_fig(1,:),edu_coh_fig(2,:),'LineWidth',3)
xlabel('Year of Birth')
ylabel('Years of Schooling')

axis([min(edu_coh_fig(1,:)), max(edu_coh_fig(1,:)), 0.8*min(edu_coh_fig(2,:)), 1.05*max(edu_coh_fig(2,:))])

print( '-dpng', '-r300', ['edu_cohorts_notitle.png']);
print( '-depsc2', ['edu_cohorts_notitle.eps']);

title('\fontsize{14} Years of Schooling by Cohort')
print( '-dpng', '-r300', ['edu_cohorts.png']);
print( '-depsc2', ['edu_cohorts.eps']);


%% --------------------- Migration
clearvars -except i_fig index_mac
load('../Demography4_LowMigration/data_NoNormalization');
baseline=load('../Demography2_PopulationProjection/data_NoNormalization');


mig_f_t_sum=sum(mig_f_t,1);
mig_m_t_sum=sum(mig_m_t,1);
mig_t_sum=mig_f_t_sum+mig_m_t_sum;
baseline.mig_f_t_sum=sum(baseline.mig_f_t,1);
baseline.mig_m_t_sum=sum(baseline.mig_m_t,1);
baseline.mig_t_sum=baseline.mig_f_t_sum+baseline.mig_m_t_sum;


figure;
t_fig=101;
x_fig=2001:2000+t_fig-1;   
y1_fig=mig_t_sum(2:t_fig)/1e6;
y2_fig=baseline.mig_t_sum(2:t_fig)/1e6;
% total, rural and urban population

plot(x_fig,y1_fig,'color','b','LineWidth',3);
hold on
plot(x_fig,y2_fig,'-.','color','b','LineWidth',3);
xlabel('Year')

x_text=2010;
i_x_text=x_text-x_fig(1)+1;
y1_text=y1_fig(i_x_text)-2.7;
y2_text=y2_fig(i_x_text)+0.5;
text(x_text,y1_text,'Slow Migration', 'VerticalAlignment','top');
text(x_text,y2_text,'Baseline','VerticalAlignment','bottom');

print( '-depsc2','migration_slowmigration_notitle.eps');
print('-dpng','-r300','migration_slowmigration_notitle.png');

title('\fontsize{14} Migrants per Year (Millions)')
print( '-depsc2','migration_slowmigration.eps');
print('-dpng','-r300','migration_slowmigration.png');



%% ------------------------- Welfare Gain: Comparison -----------------------
Compare_SlowConvergence_LowGrowth_LowFertility;
Compare_PerfectForesight;


%% ------------------------ Two Tier System, Delayed Reform ------------------------------

% delayed reform
load('../Pension9_TwoTierSystem/data_delayedreform')
name_data_2000='../Pension9_TwoTierSystem/data_benchmark';
name_data_compare='../Pension9_TwoTierSystem/data_benchmark_2013';
Baseline.dr=load('../Pension1_BaselineScenario/data_delayedreform','ev_p_coh');

t=111;


pos_fromleft=200; pos_frombottom=50; figure('Position',[pos_fromleft pos_frombottom 800 600])

subplot(2,1,1)
coh_fig=139;
if year_start==2000
    x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    plot(x_fig,replace_w_coh(1:coh_fig),'LineWidth',2)
    axis([x_fig(1) x_fig(coh_fig) 0.2 0.8]);
elseif year_start==2013
%     load(name_data_2000,'replace_w_coh_bm');
    bm2=load(name_data_compare,'replace_w_coh');
    year_start_bm=2000;
    dif_year=year_start-year_start_bm;
%     x_fig=year_start_bm-(J-Jw):year_start_bm-(J-Jw)+coh_fig-1;
%     y1_fig=[replace_w_coh_bm(1:dif_year) replace_w_coh(1:coh_fig-dif_year)];
%     y2_fig=[replace_w_coh_bm(1:dif_year) bm2.replace_w_coh(1:coh_fig-dif_year)];
    x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    y1_fig=[replace_w_coh(1:coh_fig)];
    y2_fig=[bm2.replace_w_coh(1:coh_fig)];
    width_line=2;
%     x_fig=year_start-(J-Jw):year_start-(J-Jw)+coh_fig-1;
    plot(x_fig,y1_fig,'LineWidth',width_line)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
    hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
    plot(x_fig,y2_fig,'-.','LineWidth',width_line)
    hold off
    axis([x_fig(1) x_fig(coh_fig) 0.2 0.8]);
    % axis('tight');
    if strcmp(fig_name,'fullyfunded')==1 || strcmp(fig_name,'fullyfunded_ruralpension')==1;
        axis([x_fig(1) x_fig(coh_fig) 0 0.8]);
    end
end
xlabel('Year of Retirement')
title(['\fontsize{10} Panel a: Replacement Rate by Year of Retirement'])
% temp=[x_fig;replace_w_coh(1:coh_fig)]; % 1997 and 2012



subplot(2,1,2)
year_fig_start=year_start+(Jw-J);
t_fig=1+2115-year_fig_start;
coh_fig_start=1+(J-Jw)+(year_fig_start-year_start);
x_fig=year_fig_start:year_fig_start+t_fig-1;
y1_fig=(ev_p_coh(coh_fig_start:coh_fig_start+t_fig-1))*100;
y2_fig=(Baseline.dr.ev_p_coh(coh_fig_start:coh_fig_start+t_fig-1))*100;

plot(x_fig,y1_fig,'LineWidth',2)
%     plot(x_fig,[ replace_w_coh(1:coh_fig)],'LineWidth',2)
hold on
%     plot(x_fig,[ bm2.replace_w_coh(1:coh_fig)],'-.','LineWidth',2)
plot(x_fig,y2_fig,'-.','LineWidth',2,'color','b')
hold on
plot(x_fig,zeros(1,t_fig),':','color','k','LineWidth',1)
hold off
axis([x_fig(1) x_fig(length(x_fig)) -10 40]);
x_text=2018;
x2_text=2033;
i_x_text=x_text-x_fig(1);
i_x2_text=x2_text-x_fig(1);
y1_text=y1_fig(i_x_text);
y2_text=y2_fig(i_x2_text)+0.5;
text(x_text,y1_text,'Two-pillar: Delayed', 'VerticalAlignment','bottom');
text(x2_text,y2_text,'Baseline: Delayed','VerticalAlignment','bottom');

title(['\fontsize{10} Panel b: Welfare Gains of Delayed Reforms by Year of Retirement'])

print('-dpng','-r300',['pension_twopillar_' fig_name  '.png'])
print('-depsc2',['pension_twopillar_' fig_name '.eps'])




